<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
															xmlns:xlink="http://www.w3.org/1999/xlink"
															xmlns:fo="http://www.w3.org/1999/XSL/Format"
>
<!-- 	********************************************************************************************
			MiLCA XSLT Stylesheet
			Fragen und Anregungen: Maik Stuehrenberg, JLU Giessen
			maik.stuehrenberg@uni-giessen.de
			zuletzt geaendert am: 08-12-2003, 14:45
			Copyright (c) 2003 Maik Stührenberg (JLU Gießen).
			Permission is granted to copy, distribute and/or modify this document under the terms of the GNU Free Documentation License, Version 1.2 or any later version published by the Free Software Foundation;
			with no Invariant Sections, no Front-Cover Texts, and no Back-Cover Texts.
			A copy of the license is included in the file entitled "fdl.txt".
			******************************************************************************************** -->

	<xsl:output method="xml"
							encoding="UTF-8"
							indent="yes"/>

	<xsl:param name="include-optional-paragraphs" select="Yes"/>
	
	<xsl:param name="fop" select="Yes"/>

	<xsl:param name="chapter_page" select="No"/>
	
	<xsl:strip-space elements="*"/>
	<xsl:preserve-space elements="xsl:text"/>

	<xsl:variable name="bib">
		<xsl:value-of select="generate-id()"/>
	</xsl:variable>

	<xsl:variable name="gloss">
		<xsl:value-of select="generate-id()"/>
	</xsl:variable>

<!-- LearningObject -->
	<xsl:template match="LearningObject">
		<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">
			<fo:layout-master-set>
				<fo:simple-page-master master-name="title"
															 page-height="297mm"
															 page-width="210mm"
															 margin-bottom="15mm"
															 margin-left="20mm"
															 margin-right="25mm"
															 margin-top="20mm">
					<fo:region-body margin-top="40mm"
													margin-bottom="32mm"/>
				</fo:simple-page-master>
				<fo:simple-page-master master-name="a4"
															 page-height="297mm"
															 page-width="210mm"
															 margin-bottom="7mm"
															 margin-left="25mm"
															 margin-right="25mm"
															 margin-top="15mm">
					<fo:region-body margin-top="15mm"
													margin-bottom="28mm"/>
					<fo:region-before extent="15mm"/>
					<fo:region-after extent="16mm"/>
				</fo:simple-page-master>
			</fo:layout-master-set>
			<xsl:choose>
				<xsl:when test="MetaData/General/@AggregationLevel>=3">
					<fo:page-sequence master-reference="title" language="de" widows="2">
						<fo:flow flow-name="xsl-region-body">
							<fo:block font-size="24pt"
												font-family="serif"
												line-height="32pt"
												font-weight="bold"
												text-align="center">
								<xsl:value-of select="MetaData/General/Title"/>
							</fo:block>
							<fo:block font-size="12pt"
												font-family="serif"
												line-height="18pt"
												text-align="center"
												space-after="50mm">
								<xsl:for-each select="MetaData/Lifecycle/Contribute/Entity">
									<xsl:if test="../@Role='Author'">
										<xsl:choose>
											<xsl:when test="vCard">
												<xsl:value-of select="vCard/FN"/>
											</xsl:when>
											<xsl:otherwise>
												<xsl:value-of select="."/>
											</xsl:otherwise>
										</xsl:choose>
										<xsl:if test="position()!=last()">
											<xsl:text>, </xsl:text>
										</xsl:if>
									</xsl:if>
								</xsl:for-each>
							</fo:block>
							<fo:block font-size="14pt"
												font-weight="bold"
												font-family="serif"
												line-height="18pt"
												text-align="center">
								<xsl:text>Zusammenfassung:</xsl:text>
							</fo:block>
							<fo:block font-size="12pt"
												font-family="serif"
												line-height="18pt"
												text-align="justify"
												text-align-last="start"
												space-after="12pt">
								<xsl:value-of select="MetaData/General/Description"/>
							</fo:block>
						</fo:flow>
					</fo:page-sequence>
					<fo:page-sequence master-reference="a4" initial-page-number="1" language="de" widows="2">
						<fo:flow flow-name="xsl-region-body">
							<fo:block font-size="18pt"
												font-family="serif"
												line-height="27pt"
												text-align="justify">
								<xsl:text>Inhaltsverzeichnis</xsl:text>
							</fo:block>
							<fo:table width="160mm" table-layout="fixed">
								<fo:table-column column-width="18mm"/>
								<fo:table-column column-width="134mm"/>
								<fo:table-column column-width="8mm"/>
								<fo:table-body font-family="serif">
<!-- erster Durchlauf: TOC -->
									<xsl:for-each select="//Content/LearningObject">
										<xsl:choose>
											<xsl:when test="MetaData/General/@AggregationLevel>1">
												<fo:table-row>
													<fo:table-cell>
														<xsl:choose>
															<xsl:when test="MetaData/General/@AggregationLevel=3">
																<fo:block text-align="start" font-size="12pt" line-height="18pt" font-weight="bold">
																	<xsl:number count="Content/LearningObject[MetaData/General/@AggregationLevel>=2]" level="multiple"/>
																</fo:block>
															</xsl:when>
															<xsl:when test="MetaData/General/@AggregationLevel=2">
																<fo:block text-align="start" font-size="10pt" line-height="15pt" font-weight="bold">
																	<xsl:number count="Content/LearningObject[MetaData/General/@AggregationLevel>=2]" level="multiple"/>
																</fo:block>
															</xsl:when>
														</xsl:choose>
													</fo:table-cell>
													<fo:table-cell>
														<xsl:choose>
															<xsl:when test="MetaData/General/@AggregationLevel>2">
																<fo:block text-align="start" font-size="12pt" line-height="18pt" font-weight="bold">
																	<xsl:value-of select="MetaData/General/Title"/>
																</fo:block>
															</xsl:when>
															<xsl:otherwise>
																<fo:block text-align="start" font-size="10pt" line-height="15pt" font-weight="bold">
																	<xsl:value-of select="MetaData/General/Title"/>
																</fo:block>
															</xsl:otherwise>
														</xsl:choose>
													</fo:table-cell>
													<fo:table-cell>
														<fo:block text-align="end" font-size="12pt" line-height="18pt" font-weight="bold">
															<fo:page-number-citation>
																<xsl:choose>
																	<xsl:when test="MetaData/General/@AggregationLevel=3">
																		<xsl:attribute name="ref-id">
																			<xsl:value-of select="descendant-or-self::Content/LearningObject[MetaData/General/@AggregationLevel=2][1]/MetaData/General/Identifier/@Entry"/>
																		</xsl:attribute>
																	</xsl:when>
																	<xsl:otherwise>
																		<xsl:attribute name="ref-id">
																			<xsl:value-of select="MetaData/General/Identifier/@Entry"/>
																		</xsl:attribute>
																	</xsl:otherwise>
																</xsl:choose>
															</fo:page-number-citation>
														</fo:block>
													</fo:table-cell>
												</fo:table-row>
												<fo:table-row>
													<fo:table-cell>
														<fo:block/>
													</fo:table-cell>
													<fo:table-cell>
														<xsl:choose>
															<xsl:when test="MetaData/General/@AggregationLevel>2">
																<fo:block text-align="start" start-indent="5mm" font-size="10pt" line-height="15pt" font-style="italic">
																	<xsl:value-of select="MetaData/General/Description"/>
																</fo:block>
															</xsl:when>
															<xsl:otherwise>
																<fo:block/>
															</xsl:otherwise>
														</xsl:choose>
													</fo:table-cell>
												</fo:table-row>
											</xsl:when>
										</xsl:choose>
									</xsl:for-each>
								</fo:table-body>
							</fo:table>
						</fo:flow>
					</fo:page-sequence>
<!-- zweiter Durchlauf: Inhalt -->
					<xsl:for-each select="//LearningObject">
						<xsl:choose>
							<xsl:when test="MetaData/General/@AggregationLevel=3 and position()>1 and $chapter_page='Yes'">
								<fo:page-sequence master-reference="title" language="de" widows="2">
									<fo:flow flow-name="xsl-region-body">
										<fo:block font-size="24pt"
															font-family="serif"
															line-height="32pt"
															font-weight="bold"
															text-align="center">
											<xsl:number count="Content/LearningObject[MetaData/General/@AggregationLevel>=2]" level="multiple"/>
											<xsl:text>. </xsl:text>
											<xsl:value-of select="MetaData/General/Title"/>
										</fo:block>
										<fo:block font-size="14pt"
															font-weight="bold"
															font-family="serif"
															line-height="18pt"
															text-align="center">
											<xsl:text>Zusammenfassung:</xsl:text>
										</fo:block>
										<fo:block font-size="12pt"
															font-family="serif"
															line-height="18pt"
															text-align="justify"
															text-align-last="start"
															space-after="12pt">
											<xsl:value-of select="MetaData/General/Description"/>
										</fo:block>
									</fo:flow>
								</fo:page-sequence>
							</xsl:when>
							<xsl:when test="MetaData/General/@AggregationLevel=2">
								<fo:page-sequence master-reference="a4" language="de" widows="2">
									<fo:static-content flow-name="xsl-region-before">
										<fo:block font-size="12pt"
															font-family="serif"
															font-style="italic"
															text-align="start">
											<xsl:number count="Content/LearningObject[MetaData/General/@AggregationLevel>=2]" level="multiple"/>
											<xsl:text>. </xsl:text>
											<xsl:value-of select="ancestor::LearningObject[MetaData/General/@AggregationLevel=3][1]/MetaData/General/Title"/>
											<xsl:text> - </xsl:text>
											<xsl:value-of select="MetaData/General/Title"/>
											<fo:block>
												<fo:leader leader-pattern="rule" leader-length="155mm" rule-thickness="1pt" color="black"/>
											</fo:block>
										</fo:block>
									</fo:static-content>
									<fo:static-content flow-name="xsl-region-after">
										<fo:block font-size="12pt" text-align="end">
											<fo:page-number/>
										</fo:block>
									</fo:static-content>
									<fo:flow flow-name="xsl-region-body">
										<fo:block font-size="12pt"
															font-family="serif"
															line-height="18pt"
															font-weight="bold"
															text-align="start">
											<xsl:attribute name="id">
												<xsl:value-of select="MetaData/General/Identifier/@Entry"/>
											</xsl:attribute>
											<xsl:number count="Content/LearningObject[MetaData/General/@AggregationLevel>=2]" level="multiple"/>
											<xsl:text>. </xsl:text>
											<xsl:value-of select="MetaData/General/Title"/>
										</fo:block>
										<xsl:apply-templates/>
									</fo:flow>
								</fo:page-sequence>
							</xsl:when>
						</xsl:choose>
					</xsl:for-each>
					<xsl:if test="Bibliography">
						<fo:page-sequence master-reference="a4" language="de" widows="2">
							<fo:static-content flow-name="xsl-region-before">
								<fo:block font-size="12pt"
													font-family="serif"
													font-style="italic"
													text-align="start">
									<xsl:choose>
										<xsl:when test="MetaData/General/Language='de'">
											<xsl:text>Literaturangaben </xsl:text>
										</xsl:when>
										<xsl:otherwise>
											<xsl:text>Bibliography </xsl:text>
										</xsl:otherwise>
									</xsl:choose>
									<fo:block>
										<fo:leader leader-pattern="rule" leader-length="155mm" rule-thickness="1pt" color="black"/>
									</fo:block>
								</fo:block>
							</fo:static-content>
							<fo:static-content flow-name="xsl-region-after">
								<fo:block font-size="12pt" text-align="end">
									<fo:page-number/>
								</fo:block>
							</fo:static-content>
							<fo:flow flow-name="xsl-region-body">
								<xsl:apply-templates select="Bibliography"/>
							</fo:flow>
						</fo:page-sequence>
					</xsl:if>
					<xsl:if test="Test">
						<fo:page-sequence master-reference="a4" language="de" widows="2">
							<fo:static-content flow-name="xsl-region-before">
								<fo:block font-size="12pt"
													font-family="serif"
													font-style="italic"
													text-align="start">
									<xsl:choose>
										<xsl:when test="MetaData/General/Language='de'">
											<xsl:text>Aufgaben </xsl:text>
										</xsl:when>
										<xsl:otherwise>
											<xsl:text>Exercises </xsl:text>
										</xsl:otherwise>
									</xsl:choose>
									<fo:block>
										<fo:leader leader-pattern="rule" leader-length="155mm" rule-thickness="1pt" color="black"/>
									</fo:block>
								</fo:block>
							</fo:static-content>
							<fo:static-content flow-name="xsl-region-after">
								<fo:block font-size="12pt" text-align="end">
									<fo:page-number/>
								</fo:block>
							</fo:static-content>
							<fo:flow flow-name="xsl-region-body">
								<xsl:apply-templates select="Test"/>
							</fo:flow>
						</fo:page-sequence>
					</xsl:if>
					<xsl:if test="Glossary">
						<fo:page-sequence master-reference="a4" language="de" widows="2">
							<fo:static-content flow-name="xsl-region-before">
								<fo:block font-size="12pt"
													font-family="serif"
													font-style="italic"
													text-align="start">
									<xsl:choose>
										<xsl:when test="MetaData/General/Language='de'">
											<xsl:text>Glossar </xsl:text>
										</xsl:when>
										<xsl:otherwise>
											<xsl:text>Glossary </xsl:text>
										</xsl:otherwise>
									</xsl:choose>
									<fo:block>
										<fo:leader leader-pattern="rule" leader-length="155mm" rule-thickness="1pt" color="black"/>
									</fo:block>
								</fo:block>
							</fo:static-content>
							<fo:static-content flow-name="xsl-region-after">
								<fo:block font-size="12pt" text-align="end">
									<fo:page-number/>
								</fo:block>
							</fo:static-content>
							<fo:flow flow-name="xsl-region-body">
								<xsl:apply-templates select="Glossary"/>
							</fo:flow>
						</fo:page-sequence>
					</xsl:if>
				</xsl:when>
				<xsl:when test="MetaData/General/@AggregationLevel=2">
					<fo:page-sequence master-reference="a4" language="de" widows="2">
						<fo:static-content flow-name="xsl-region-before">
							<fo:block font-size="12pt"
												font-family="serif"
												font-style="italic"
												text-align="start">
								<xsl:number count="Content/LearningObject[MetaData/General/@AggregationLevel>=2]" level="multiple"/>
								<xsl:text>. </xsl:text>
								<xsl:value-of select="MetaData/General/Title"/>
								<fo:block>
									<fo:leader leader-pattern="rule" leader-length="155mm" rule-thickness="1pt" color="black"/>
								</fo:block>
							</fo:block>
						</fo:static-content>
						<fo:static-content flow-name="xsl-region-after">
							<fo:block font-size="12pt" text-align="end">
								<fo:page-number/>
							</fo:block>
						</fo:static-content>
						<fo:flow flow-name="xsl-region-body">
							<fo:block font-size="12pt"
												font-family="serif"
												line-height="18pt"
												font-weight="bold"
												text-align="start">
								<xsl:attribute name="id">
									<xsl:value-of select="MetaData/General/Identifier/@Entry"/>
								</xsl:attribute>
								<xsl:number count="Content/LearningObject[MetaData/General/@AggregationLevel>=2]" level="multiple"/>
								<xsl:text>. </xsl:text>
								<xsl:value-of select="MetaData/General/Title"/>
							</fo:block>
							<xsl:apply-templates/>
						</fo:flow>
					</fo:page-sequence>
				</xsl:when>
			</xsl:choose>
		</fo:root>
	</xsl:template>

	<xsl:template match="MetaData"/>

	<xsl:template match="Content/LearningObject">
		<xsl:choose>
			<xsl:when test="MetaData/General/@AggregationLevel>=2">
				<fo:block>
					<xsl:value-of select="MetaData/General/Title"/>
				</fo:block>
				<xsl:apply-templates/>
			</xsl:when>
			<xsl:when test="MetaData/General/@AggregationLevel=1">
				<xsl:choose>
					<xsl:when test="MetaData/Technical/@Format='image-gif' or MetaData/Technical/@Format='image-jpeg' or MetaData/Technical/@Format='image-png' or MetaData/Technical/@Format='image-svg-xml'">
						<xsl:call-template name="images"/>
					</xsl:when>
					<xsl:otherwise>
						<fo:block>
							<xsl:text>Multimedia-Objekt</xsl:text>
						</fo:block>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="images">
		<xsl:choose>
			<xsl:when test="MetaData/Technical/@Format='image-svg-xml' and $fop='No'">
				<fo:block>
					<fo:external-graphic>
						<xsl:attribute name="src">
							<xsl:value-of select="concat('url(',concat(substring-before(MetaData/Technical/Location,'.'),'.',translate(substring-after(MetaData/Technical/Location,'.'),'svg','png')),')')"/>
						</xsl:attribute>
					</fo:external-graphic>
				</fo:block>
				<fo:block font-family="sans-serif"
									font-size="12pt"
									font-weight="bold"
									line-height="14pt"
									text-align="start">
					<xsl:choose>
						<xsl:when test="MetaData/General/Language='de'">
							<xsl:text>Abbildung: </xsl:text>
						</xsl:when>
						<xsl:otherwise>
							<xsl:text>Figure: </xsl:text>
						</xsl:otherwise>
					</xsl:choose>
					<xsl:apply-templates select="MetaData/General/Title"/>
				</fo:block>
				<fo:block font-family="sans-serif"
									font-size="10pt"
									line-height="12pt"
									text-align="start"
									space-after="10pt">
					<xsl:apply-templates select="MetaData/General/Description"/>
				</fo:block>
			</xsl:when>
			<xsl:when test="MetaData/Technical/@Format='application-x-shockwave-flash'">
				<fo:block>
					<fo:external-graphic>
						<xsl:attribute name="src">
							<xsl:value-of select="concat('url(',concat(substring-before(MetaData/Technical/Location,'.'),'.',translate(substring-after(MetaData/Technical/Location,'.'),'swf','png')),')')"/>
						</xsl:attribute>
					</fo:external-graphic>
				</fo:block>
				<fo:block font-family="sans-serif"
									font-size="12pt"
									font-weight="bold"
									line-height="14pt"
									text-align="start">
					<xsl:choose>
						<xsl:when test="MetaData/General/Language='de'">
							<xsl:text>Abbildung: </xsl:text>
						</xsl:when>
						<xsl:otherwise>
							<xsl:text>Figure: </xsl:text>
						</xsl:otherwise>
					</xsl:choose>
					<xsl:apply-templates select="MetaData/General/Title"/>
				</fo:block>
				<fo:block font-family="sans-serif"
									font-size="10pt"
									line-height="12pt"
									text-align="start"
									space-after="10pt">
					<xsl:apply-templates select="MetaData/General/Description"/>
				</fo:block>
			</xsl:when>
			<xsl:otherwise>	
				<fo:block>
					<fo:external-graphic>
						<xsl:attribute name="src">
							<xsl:value-of select="concat('url(',MetaData/Technical/Location,')')"/>
						</xsl:attribute>
					</fo:external-graphic>
				</fo:block>
				<fo:block font-family="sans-serif"
									font-size="12pt"
									font-weight="bold"
									line-height="14pt"
									text-align="start">
					<xsl:choose>
						<xsl:when test="MetaData/General/Language='de'">
							<xsl:text>Abbildung: </xsl:text>
						</xsl:when>
						<xsl:otherwise>
							<xsl:text>Figure: </xsl:text>
						</xsl:otherwise>
					</xsl:choose>
					<xsl:apply-templates select="MetaData/General/Title"/>
				</fo:block>
				<fo:block font-family="sans-serif"
									font-size="10pt"
									line-height="12pt"
									text-align="start"
									space-after="10pt">
					<xsl:apply-templates select="MetaData/General/Description"/>
				</fo:block>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template match="Text">
		<xsl:apply-templates/>
	</xsl:template>

	<xsl:template match="Test">
		<fo:block	font-size="16pt"
							line-height="24pt"
							font-weight="bold"
							break-before="page">
			<xsl:text>Aufgabe</xsl:text>
		</fo:block>
		<xsl:for-each select="TestItem">
			<fo:block space-after="5mm">
				<fo:block font-family="serif" font-weight="bold">
					<xsl:choose>
						<xsl:when test="../../MetaData/General/Language='de'">
							<xsl:text>Frage </xsl:text>
						</xsl:when>
						<xsl:otherwise>
							<xsl:text>Question </xsl:text>
						</xsl:otherwise>
					</xsl:choose>
					<xsl:number count="TestItem"/>
				</fo:block>
				<xsl:apply-templates select="Question"/>
				<xsl:for-each select="Answer"/>
			</fo:block>
		</xsl:for-each>
	</xsl:template>

	<xsl:template match="Question/LearningObject">
		<xsl:choose>
			<xsl:when test="MetaData/General/@AggregationLevel=1">
				<xsl:choose>
					<xsl:when test="MetaData/Technical/@Format='image-gif' or MetaData/Technical/@Format='image-jpeg' or MetaData/Technical/@Format='image-png'">
						<fo:block>
							<fo:external-graphic>
								<xsl:attribute name="src">
									<xsl:value-of select="concat('url(',MetaData/Technical/Location,')')"/>
								</xsl:attribute>
							</fo:external-graphic>
						</fo:block>
						<fo:block font-family="sans-serif"
											font-size="12pt"
											font-weight="bold"
											line-height="14pt"
											text-align="start">
							<xsl:choose>
								<xsl:when test="MetaData/General/Language='de'">
									<xsl:text>Abbildung: </xsl:text>
								</xsl:when>
								<xsl:otherwise>
									<xsl:text>Figure: </xsl:text>
								</xsl:otherwise>
							</xsl:choose>
							<xsl:apply-templates select="MetaData/General/Title"/>
						</fo:block>
						<fo:block font-family="sans-serif"
											font-size="10pt"
											line-height="12pt"
											text-align="start"
											space-after="10pt">
							<xsl:apply-templates select="MetaData/General/Description"/>
						</fo:block>
					</xsl:when>
					<xsl:when test="MetaData/Technical/@Format='image-svg-xml'">
						<fo:block>
							<fo:external-graphic>
								<xsl:attribute name="src">
									<xsl:value-of select="concat('url(',concat(substring-before(MetaData/Technical/Location,'.'),'.',translate(substring-after(MetaData/Technical/Location,'.'),'svg','png')),')')"/>
								</xsl:attribute>
							</fo:external-graphic>
						</fo:block>
						<fo:block font-family="sans-serif"
											font-size="12pt"
											font-weight="bold"
											line-height="14pt"
											text-align="start">
							<xsl:choose>
								<xsl:when test="MetaData/General/Language='de'">
									<xsl:text>Abbildung: </xsl:text>
								</xsl:when>
								<xsl:otherwise>
									<xsl:text>Figure: </xsl:text>
								</xsl:otherwise>
							</xsl:choose>
							<xsl:apply-templates select="MetaData/General/Title"/>
						</fo:block>
						<fo:block font-family="sans-serif"
											font-size="10pt"
											line-height="12pt"
											text-align="start"
											space-after="10pt">
							<xsl:apply-templates select="MetaData/General/Description"/>
						</fo:block>
					</xsl:when>
				</xsl:choose>
			</xsl:when>
		</xsl:choose>
	</xsl:template>

	<xsl:template match="Paragraph">
		<xsl:choose>
			<xsl:when test="$include-optional-paragraphs='No' and @Optional='Yes'">
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="@Characteristic='Headline'">
						<fo:block font-size="12pt"
											font-family="serif"
											font-weight="bold"
											line-height="18pt"
											text-align="justify"
											text-align-last="start"
											space-before="2mm"
											space-after="0mm"
											hyphenate="true"
											hyphenation-character="-"
											keep-with-next="always">
							<xsl:attribute name="language">
								<xsl:choose>
									<xsl:when test="@Language">
										<xsl:value-of select="@Language"/>
									</xsl:when>
									<xsl:otherwise>
										<xsl:value-of select="//MetaData/General/Language"/>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:attribute>
							<xsl:apply-templates/>
						</fo:block>
					</xsl:when>
					<xsl:when test="@Characteristic='Mnemonic'">
						<fo:block background-color="#cccccc"
											border-style="solid"
											margin-left="20px"
											margin-right="20px"
											margin-top="20px"
											margin-bottom="20px"
											padding="10px"
											font-size="12pt"
											font-family="serif"
											font-weight="bold"
											line-height="18pt"
											text-align="justify"
											text-align-last="start"
											space-before="0mm"
											space-after.optimum="2mm"
											space-after.minimum="0mm"
											hyphenate="true"
											hyphenation-character="-">
							<xsl:attribute name="language">
								<xsl:choose>
									<xsl:when test="@Language">
										<xsl:value-of select="@Language"/>
									</xsl:when>
									<xsl:otherwise>
										<xsl:value-of select="//MetaData/General/Language"/>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:attribute>
							<xsl:apply-templates/>
						</fo:block>
					</xsl:when>
					<xsl:otherwise>
						<fo:block font-size="12pt"
											font-family="serif"
											line-height="18pt"
											text-align="justify"
											text-align-last="start"
											space-before="0mm"
											space-after.optimum="2mm"
											space-after.minimum="0mm"
											hyphenate="true"
											hyphenation-character="-"
											keep-with-next="always">
							<xsl:attribute name="language">
								<xsl:choose>
									<xsl:when test="@Language">
										<xsl:value-of select="@Language"/>
									</xsl:when>
									<xsl:otherwise>
										<xsl:value-of select="//MetaData/General/Language"/>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:attribute>
							<xsl:apply-templates/>
						</fo:block>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template match="List">
		<fo:block font-size="12pt" font-family="serif" line-height="18pt">
			<xsl:choose>
				<xsl:when test="@Type='Ordered'">
					<xsl:for-each select="Title">
						<fo:block>
							<xsl:apply-templates/>
						</fo:block>
					</xsl:for-each>
					<fo:list-block>
						<xsl:for-each select="Item">
							<fo:list-item>
								<fo:list-item-label end-indent="label-end()">
									<fo:block>
										<xsl:number count="Item"/>
										<xsl:text>.</xsl:text>
									</fo:block>
								</fo:list-item-label>
								<fo:list-item-body start-indent="body-start()">
									<fo:block font-size="12pt" font-family="serif" line-height="18pt">
										<xsl:apply-templates/>
									</fo:block>
								</fo:list-item-body>
							</fo:list-item>
						</xsl:for-each>
					</fo:list-block>
				</xsl:when>
				<xsl:otherwise>
					<xsl:for-each select="Title">
						<fo:block>
							<xsl:apply-templates/>
						</fo:block>
					</xsl:for-each>
					<fo:list-block>
						<xsl:for-each select="Item">
							<fo:list-item>
								<fo:list-item-label end-indent="label-end()">
									<fo:block>&#8226;</fo:block>
								</fo:list-item-label>
								<fo:list-item-body start-indent="body-start()">
									<fo:block>
										<xsl:apply-templates/>
									</fo:block>
								</fo:list-item-body>
							</fo:list-item>
						</xsl:for-each>
					</fo:list-block>
				</xsl:otherwise>
			</xsl:choose>
		</fo:block>
	</xsl:template>

	<xsl:template match="Link">
		<xsl:value-of select="."/>
		<fo:footnote>
			<fo:inline font-size="8pt" vertical-align="super">
				<xsl:number count="Link" level="any"/>
			</fo:inline>
			<fo:footnote-body margin-left="0cm">
				<fo:list-block>
					<fo:list-item>
						<fo:list-item-label end-indent="label-end()">
							<fo:block font-size="8pt" vertical-align="super">
								<xsl:number count="Link" level="any"/>
							</fo:block>
						</fo:list-item-label>
						<fo:list-item-body start-indent="body-start()">
							<fo:block font-size="10pt">
								<xsl:value-of select="@xlink:href"/>
								<xsl:if test="@Last_Visit">
									<xsl:choose>
										<xsl:when test="ancestor::LearningObject[1]/MetaData/General/Language='de'">
											<xsl:text> - Zuletzt besucht: </xsl:text>
											<xsl:value-of select="@Last_Visit"/>
										</xsl:when>
										<xsl:otherwise>
											<xsl:text> - Last Visit: </xsl:text>
											<xsl:value-of select="@Last_Visit"/>
										</xsl:otherwise>
									</xsl:choose>
								</xsl:if>
							</fo:block>
						</fo:list-item-body>
					</fo:list-item>
				</fo:list-block>
			</fo:footnote-body>
		</fo:footnote>
	</xsl:template>

	<xsl:template match="Emph">
		<fo:inline font-style="italic">
			<xsl:apply-templates/>
		</fo:inline>
	</xsl:template>

	<xsl:template match="Strong">
		<fo:inline font-weight="bold" font-style="italic">
			<xsl:apply-templates/>
		</fo:inline>
	</xsl:template>

	<xsl:template match="Example">
		<fo:block font-weight="bold">
			<xsl:attribute name="id">
				<xsl:value-of select="@Id"/>
			</xsl:attribute>
			<xsl:choose>
				<xsl:when test="//MetaData/General/Language='de'">
					<xsl:text>Beispiel </xsl:text>
				</xsl:when>
				<xsl:otherwise>
					<xsl:text>Example</xsl:text>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:number count="Example" level="any"/>
			<xsl:text>: </xsl:text>
			<xsl:value-of select="translate(@Id,'_',' ')"/>
			<xsl:text> </xsl:text>
		</fo:block>
		<xsl:apply-templates/>
	</xsl:template>

	<xsl:template match="Example/*">
		<fo:block>
			<xsl:if test="Code">
				<xsl:attribute name="text-align">
					<xsl:text>start</xsl:text>
				</xsl:attribute>
			</xsl:if>
			<xsl:choose>
				<xsl:when test="../@Status='Ill-formed'">
					<xsl:text>* </xsl:text>
				</xsl:when>
				<xsl:when test="../@Status='Questionable'">
					<xsl:text>? </xsl:text>
				</xsl:when>
			</xsl:choose>
			<xsl:apply-templates/>
		</fo:block>
	</xsl:template>

	<xsl:template match="Code">
		<xsl:choose>
			<xsl:when test="@Display='Inline'">
				<fo:inline font-family="monospace">
					<xsl:apply-templates/>
				</fo:inline>
			</xsl:when>
			<xsl:when test="@Display='Block'">
				<fo:block font-family="monospace"
									text-align="start">
					<xsl:choose>
						<xsl:when test="CodeElem">
							<xsl:for-each select="CodeElem">
								<fo:block>
									<xsl:value-of select="."/>
								</fo:block>
							</xsl:for-each>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="."/>
						</xsl:otherwise>
					</xsl:choose>
				</fo:block>
			</xsl:when>
		</xsl:choose>
	</xsl:template>

	<xsl:template match="Quotation">
		<xsl:choose>
			<xsl:when test="@Type='Block'">
				<fo:block>
					<fo:inline>
						<xsl:text>"</xsl:text>
						<xsl:value-of select="."/>
						<xsl:text>" </xsl:text>
						<xsl:if test="@Reference_to">
							<xsl:text>[</xsl:text>
							<xsl:choose>
								<xsl:when test="id(@Reference_to)/Author">
									<xsl:for-each select="id(@Reference_to)/Author">
										<xsl:apply-templates select="Family"/>
										<xsl:choose>
											<xsl:when test="position()!=last()">
												<xsl:text>, </xsl:text>
											</xsl:when>
										</xsl:choose>
									</xsl:for-each>
								</xsl:when>
								<xsl:when test="id(@Reference_to)/Editor">
									<xsl:for-each select="id(@Reference_to)/Editor">
										<xsl:apply-templates select="Family"/>
										<xsl:choose>
											<xsl:when test="position()!=last()">
												<xsl:text>, </xsl:text>
											</xsl:when>
										</xsl:choose>
									</xsl:for-each>
								</xsl:when>
								<xsl:when test="id(@Reference_to)/Organization">
									<xsl:apply-templates select="id(@Reference_to)/Organization"/>
								</xsl:when>
							</xsl:choose>
							<xsl:text>, </xsl:text>
							<xsl:apply-templates select="id(@Reference_to)/Year"/>
							<xsl:if test="@Page">
								<xsl:text>, S. </xsl:text>
								<xsl:apply-templates select="@Page"/>
							</xsl:if>
							<xsl:text>]</xsl:text>
						</xsl:if>
					</fo:inline>
				</fo:block>
			</xsl:when>
			<xsl:otherwise>
				<fo:inline>
					<xsl:text>"</xsl:text>
					<xsl:value-of select="."/>
					<xsl:text>" </xsl:text>
					<xsl:if test="@Reference_to">
						<xsl:text>[</xsl:text>
						<xsl:choose>
							<xsl:when test="id(@Reference_to)/Author">
								<xsl:for-each select="id(@Reference_to)/Author">
									<xsl:apply-templates select="Family"/>
									<xsl:choose>
										<xsl:when test="position()!=last()">
											<xsl:text>, </xsl:text>
										</xsl:when>
									</xsl:choose>
								</xsl:for-each>
							</xsl:when>
							<xsl:when test="id(@Reference_to)/Editor">
								<xsl:for-each select="id(@Reference_to)/Editor">
									<xsl:apply-templates select="Family"/>
									<xsl:choose>
										<xsl:when test="position()!=last()">
											<xsl:text>, </xsl:text>
										</xsl:when>
									</xsl:choose>
								</xsl:for-each>
							</xsl:when>
							<xsl:when test="id(@Reference_to)/Organization">
								<xsl:apply-templates select="id(@Reference_to)/Organization"/>
							</xsl:when>
						</xsl:choose>
						<xsl:text>, </xsl:text>
						<xsl:apply-templates select="id(@Reference_to)/Year"/>
						<xsl:if test="@Page">
							<xsl:text>, S. </xsl:text>
							<xsl:apply-templates select="@Page"/>
						</xsl:if>
						<xsl:text>]</xsl:text>
					</xsl:if>
				</fo:inline>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

<!-- Table: Problem: die Konvertierung nach XSL-FO funktioniert wunderbar, allerdings kann FOP -->
<!-- die erzeugten Tabellen noch nicht anzeigen, da er eine vorgegebene Anzahl an Table-Column benoetigt -->
<!-- auch table-and-caption wird noch nicht unterstuetzt -->
	<xsl:template match="Table">
		<xsl:choose>
			<xsl:when test="HeaderCaption">
				<fo:table-and-caption caption-side="before">
					<fo:table-caption>
						<fo:block>
							<xsl:apply-templates select="HeaderCaption"/>
						</fo:block>
					</fo:table-caption>
					<xsl:choose>
						<xsl:when test="@Width">
							<fo:table inline-progression-dimension="{@Width}mm" table-layout="fixed">
								<xsl:call-template name="tables"/>
							</fo:table>
						</xsl:when>
						<xsl:otherwise>
							<fo:table inline-progression-dimension="200mm" table-layout="fixed">
								<xsl:call-template name="tables"/>
							</fo:table>
						</xsl:otherwise>
					</xsl:choose>
				</fo:table-and-caption>
			</xsl:when>
			<xsl:when test="FooterCaption">
				<fo:table-and-caption caption-side="after">
					<fo:table-caption>
						<fo:block>
							<xsl:apply-templates select="FooterCaption"/>
						</fo:block>
					</fo:table-caption>
					<xsl:choose>
						<xsl:when test="@Width">
							<fo:table inline-progression-dimension="{@Width}mm" table-layout="fixed">
								<xsl:call-template name="tables"/>
							</fo:table>
						</xsl:when>
						<xsl:otherwise>
							<fo:table inline-progression-dimension="200mm" table-layout="fixed">
								<xsl:call-template name="tables"/>
							</fo:table>
						</xsl:otherwise>
					</xsl:choose>
				</fo:table-and-caption>
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="@Width">
						<fo:table inline-progression-dimension="{@Width}mm" table-layout="fixed">
							<xsl:call-template name="tables"/>
						</fo:table>
					</xsl:when>
					<xsl:otherwise>
						<fo:table inline-progression-dimension="200mm" table-layout="fixed">
							<xsl:call-template name="tables"/>
						</fo:table>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="tables">
		<xsl:for-each select="TableRow[1]/TableData">
			<fo:table-column/>
		</xsl:for-each>
		<fo:table-body>
			<xsl:for-each select="TableRow">
				<fo:table-row>
					<xsl:for-each select="TableData">
						<xsl:choose>
							<xsl:when test="../../@Border">
								<fo:table-cell>
									<xsl:attribute name="border">
										<xsl:text>solid black </xsl:text>
										<xsl:value-of select="concat(../../@Border,'px')"/>
									</xsl:attribute>
									<fo:block>
										<xsl:value-of select="."/>
									</fo:block>
								</fo:table-cell>
							</xsl:when>
							<xsl:otherwise>
								<fo:table-cell>
									<fo:block>
										<xsl:value-of select="."/>
									</fo:block>
								</fo:table-cell>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
				</fo:table-row>
			</xsl:for-each>
		</fo:table-body>
	</xsl:template>

	<xsl:template match="Bibliography">
		<fo:block	font-size="16pt"
							line-height="24pt"
							font-weight="bold"
							break-before="page">
			<xsl:choose>
				<xsl:when test="../MetaData/General/Language='de'">
					<xsl:text>Literaturangaben</xsl:text>
				</xsl:when>
				<xsl:otherwise>
					<xsl:text>Bibliography</xsl:text>
				</xsl:otherwise>
			</xsl:choose>
		</fo:block>
		<xsl:if test="Bibitem/@Type='Article'">
			<xsl:choose>
				<xsl:when test="../MetaData/General/Language='de'">
					<fo:block font-family="serif"
										font-size="12pt"
										font-weight="bold"
										line-height="18pt"
										space-after="12pt">
						<xsl:text>Artikel</xsl:text>
					</fo:block>
				</xsl:when>
				<xsl:when test="../MetaData/General/Language='en'">
					<fo:block font-family="serif"
										font-size="12pt"
										font-weight="bold"
										line-height="18pt"
										space-after="12pt">
						<xsl:text>Articles</xsl:text>
					</fo:block>
				</xsl:when>
			</xsl:choose>
			<xsl:for-each select="Bibitem[@Type='Article']">
				<xsl:sort select="(Author[1]/Family | Editor[1]/Family | Organization)[1]"/>
				<fo:block font-family="serif"
									font-size="12pt"
									line-height="18pt"
									space-after="12pt">
					<xsl:apply-templates select="."/>
				</fo:block>
			</xsl:for-each>
		</xsl:if>
		<xsl:if test="Bibitem/@Type='AV'">
			<fo:block font-family="serif"
									font-size="12pt"
									font-weight="bold"
									line-height="18pt"
									space-after="12pt">
				<xsl:text>AV</xsl:text>
			</fo:block>
			<xsl:for-each select="Bibitem[@Type='AV']">
				<xsl:sort select="(Author[1]/Family | Editor[1]/Family | Organization)[1]"/>
				<fo:block font-family="serif"
									font-size="12pt"
									line-height="18pt"
									space-after="12pt">
					<xsl:apply-templates select="."/>
				</fo:block>
			</xsl:for-each>
		</xsl:if>
		<xsl:if test="Bibitem/@Type='Book'">
			<xsl:choose>
				<xsl:when test="../MetaData/General/Language='de'">
					<fo:block font-family="serif"
									font-size="12pt"
									font-weight="bold"
									line-height="18pt"
									space-after="12pt">
						<xsl:text>Bücher</xsl:text>
					</fo:block>
				</xsl:when>
				<xsl:when test="../MetaData/General/Language='en'">
					<fo:block font-family="serif"
									font-size="12pt"
									font-weight="bold"
									line-height="18pt"
									space-after="12pt">
						<xsl:text>Books</xsl:text>
					</fo:block>
				</xsl:when>
			</xsl:choose>
			<xsl:for-each select="Bibitem[@Type='Book']">
				<xsl:sort select="(Author[1]/Family | Editor[1]/Family | Organization)[1]"/>
				<fo:block font-family="serif"
									font-size="12pt"
									line-height="18pt"
									space-after="12pt">
					<xsl:apply-templates select="."/>
				</fo:block>
			</xsl:for-each>
		</xsl:if>
		<xsl:if test="Bibitem/@Type='Dissertation'">
			<fo:block font-family="serif"
									font-size="12pt"
									font-weight="bold"
									line-height="18pt"
									space-after="12pt">
				<xsl:text>Dissertation</xsl:text>
			</fo:block>
			<xsl:for-each select="Bibitem[@Type='Dissertation']">
				<xsl:sort select="(Author[1]/Family | Editor[1]/Family | Organization)[1]"/>
				<fo:block font-family="serif"
									font-size="12pt"
									line-height="18pt"
									space-after="12pt">
					<xsl:apply-templates select="."/>
				</fo:block>
			</xsl:for-each>
		</xsl:if>
		<xsl:if test="Bibitem/@Type='Inbook'">
			<xsl:choose>
				<xsl:when test="../MetaData/General/Language='de'">
					<fo:block font-family="serif"
									font-size="12pt"
									font-weight="bold"
									line-height="18pt"
									space-after="12pt">
						<xsl:text>Kapitel</xsl:text>
					</fo:block>
				</xsl:when>
				<xsl:when test="../MetaData/General/Language='en'">
					<fo:block font-family="serif"
									font-size="12pt"
									font-weight="bold"
									line-height="18pt"
									space-after="12pt">
						<xsl:text>Inbook</xsl:text>
					</fo:block>
				</xsl:when>
			</xsl:choose>
			<xsl:for-each select="Bibitem[@Type='Inbook']">
				<xsl:sort select="(Author[1]/Family | Editor[1]/Family | Organization)[1]"/>
				<fo:block font-family="serif"
									font-size="12pt"
									line-height="18pt"
									space-after="12pt">
					<xsl:apply-templates select="."/>
				</fo:block>
			</xsl:for-each>
		</xsl:if>
		<xsl:if test="Bibitem/@Type='Incollection'">
			<xsl:choose>
				<xsl:when test="../MetaData/General/Language='de'">
					<fo:block font-family="serif"
									font-size="12pt"
									font-weight="bold"
									line-height="18pt"
									space-after="12pt">
						<xsl:text>Artikel</xsl:text>
					</fo:block>
				</xsl:when>
				<xsl:when test="../MetaData/General/Language='en'">
					<fo:block font-family="serif"
									font-size="12pt"
									font-weight="bold"
									line-height="18pt"
									space-after="12pt">
						<xsl:text>Incollection</xsl:text>
					</fo:block>
				</xsl:when>
			</xsl:choose>
			<xsl:for-each select="Bibitem[@Type='Incollection']">
				<xsl:sort select="(Author[1]/Family | Editor[1]/Family | Organization)[1]"/>
				<fo:block font-family="serif"
									font-size="12pt"
									line-height="18pt"
									space-after="12pt">
					<xsl:apply-templates select="."/>
				</fo:block>
			</xsl:for-each>
		</xsl:if>
		<xsl:if test="Bibitem/@Type='Inproceedings'">
			<xsl:choose>
				<xsl:when test="../MetaData/General/Language='de'">
					<fo:block font-family="serif"
									font-size="12pt"
									font-weight="bold"
									line-height="18pt"
									space-after="12pt">
						<xsl:text>Beiträge</xsl:text>
					</fo:block>
				</xsl:when>
				<xsl:when test="../MetaData/General/Language='en'">
					<fo:block font-family="serif"
									font-size="12pt"
									font-weight="bold"
									line-height="18pt"
									space-after="12pt">
						<xsl:text>Inproceedings</xsl:text>
					</fo:block>
				</xsl:when>
			</xsl:choose>
			<xsl:for-each select="Bibitem[@Type='Inproceedings']">
				<xsl:sort select="(Author[1]/Family | Editor[1]/Family | Organization)[1]"/>
				<fo:block font-family="serif"
									font-size="12pt"
									line-height="18pt"
									space-after="12pt">
					<xsl:apply-templates select="."/>
				</fo:block>
			</xsl:for-each>
		</xsl:if>
		<xsl:if test="Bibitem/@Type='Internet'">
			<fo:block font-family="serif"
									font-size="12pt"
									font-weight="bold"
									line-height="18pt"
									space-after="12pt">
				<xsl:text>Internet</xsl:text>
			</fo:block>
			<xsl:for-each select="Bibitem[@Type='Internet']">
				<xsl:sort select="(Author[1]/Family | Editor[1]/Family | Organization)[1]"/>
				<fo:block font-family="serif"
									font-size="12pt"
									line-height="18pt"
									space-after="12pt">
					<xsl:apply-templates select="."/>
				</fo:block>
			</xsl:for-each>
		</xsl:if>
		<xsl:if test="Bibitem/@Type='Journalarticle'">
			<xsl:choose>
				<xsl:when test="../MetaData/General/Language='de'">
					<fo:block font-family="serif"
									font-size="12pt"
									font-weight="bold"
									line-height="18pt"
									space-after="12pt">
						<xsl:text>Zeitschriftenartikel</xsl:text>
					</fo:block>
				</xsl:when>
				<xsl:when test="../MetaData/General/Language='en'">
					<fo:block font-family="serif"
									font-size="12pt"
									font-weight="bold"
									line-height="18pt"
									space-after="12pt">
						<xsl:text>Journalarticle</xsl:text>
					</fo:block>
				</xsl:when>
			</xsl:choose>
			<xsl:for-each select="Bibitem[@Type='Journalarticle']">
				<xsl:sort select="(Author[1]/Family | Editor[1]/Family | Organization)[1]"/>
				<fo:block font-family="serif"
									font-size="12pt"
									line-height="18pt"
									space-after="12pt">
					<xsl:apply-templates select="."/>
				</fo:block>
			</xsl:for-each>
		</xsl:if>
		<xsl:if test="Bibitem/@Type='Manual'">
			<xsl:choose>
				<xsl:when test="../MetaData/General/Language='de'">
					<fo:block font-family="serif"
									font-size="12pt"
									font-weight="bold"
									line-height="18pt"
									space-after="12pt">
						<xsl:text>Handbuch</xsl:text>
					</fo:block>
				</xsl:when>
				<xsl:when test="../MetaData/General/Language='en'">
					<fo:block font-family="serif"
									font-size="12pt"
									font-weight="bold"
									line-height="18pt"
									space-after="12pt">
						<xsl:text>Manual</xsl:text>
					</fo:block>
				</xsl:when>
			</xsl:choose>
			<xsl:for-each select="Bibitem[@Type='Manual']">
				<xsl:sort select="(Author[1]/Family | Editor[1]/Family | Organization)[1]"/>
				<fo:block font-family="serif"
									font-size="12pt"
									line-height="18pt"
									space-after="12pt">
					<xsl:apply-templates select="."/>
				</fo:block>
			</xsl:for-each>
		</xsl:if>
		<xsl:if test="Bibitem/@Type='Mastersthesis'">
			<xsl:choose>
				<xsl:when test="../MetaData/General/Language='de'">
					<fo:block font-family="serif"
									font-size="12pt"
									font-weight="bold"
									line-height="18pt"
									space-after="12pt">
						<xsl:text>Diplom- oder Magisterarbeiten</xsl:text>
					</fo:block>
				</xsl:when>
				<xsl:when test="../MetaData/General/Language='en'">
					<fo:block font-family="serif"
									font-size="12pt"
									font-weight="bold"
									line-height="18pt"
									space-after="12pt">
						<xsl:text>Mastersthesis</xsl:text>
					</fo:block>
				</xsl:when>
			</xsl:choose>
			<xsl:for-each select="Bibitem[@Type='Mastersthesis']">
				<xsl:sort select="(Author[1]/Family | Editor[1]/Family | Organization)[1]"/>
				<fo:block font-family="serif"
									font-size="12pt"
									line-height="18pt"
									space-after="12pt">
					<xsl:apply-templates select="."/>
				</fo:block>
			</xsl:for-each>
		</xsl:if>
		<xsl:if test="Bibitem/@Type='Newspaperarticle'">
			<xsl:choose>
				<xsl:when test="../MetaData/General/Language='de'">
					<fo:block font-family="serif"
									font-size="12pt"
									font-weight="bold"
									line-height="18pt"
									space-after="12pt">
						<xsl:text>Zeitungsartikel</xsl:text>
					</fo:block>
				</xsl:when>
				<xsl:when test="../MetaData/General/Language='en'">
					<fo:block font-family="serif"
									font-size="12pt"
									font-weight="bold"
									line-height="18pt"
									space-after="12pt">
						<xsl:text>Newspaperarticle</xsl:text>
					</fo:block>
				</xsl:when>
			</xsl:choose>
			<xsl:for-each select="Bibitem[@Type='Newspaperarticle']">
				<xsl:sort select="(Author[1]/Family | Editor[1]/Family | Organization)[1]"/>
				<fo:block font-family="serif"
									font-size="12pt"
									line-height="18pt"
									space-after="12pt">
					<xsl:apply-templates select="."/>
				</fo:block>
			</xsl:for-each>
		</xsl:if>
		<xsl:if test="Bibitem/@Type='Phdthesis'">
			<xsl:choose>
				<xsl:when test="../MetaData/General/Language='de'">
					<fo:block font-family="serif"
									font-size="12pt"
									font-weight="bold"
									line-height="18pt"
									space-after="12pt">
						<xsl:text>Doktorarbeiten</xsl:text>
					</fo:block>
				</xsl:when>
				<xsl:when test="../MetaData/General/Language='en'">
					<fo:block font-family="serif"
									font-size="12pt"
									font-weight="bold"
									line-height="18pt"
									space-after="12pt">
						<xsl:text>Phdthesis</xsl:text>
					</fo:block>
				</xsl:when>
			</xsl:choose>
			<xsl:for-each select="Bibitem[@Type='Phdthesis']">
				<xsl:sort select="(Author[1]/Family | Editor[1]/Family | Organization)[1]"/>
				<fo:block font-family="serif"
									font-size="12pt"
									line-height="18pt"
									space-after="12pt">
					<xsl:apply-templates select="."/>
				</fo:block>
			</xsl:for-each>
		</xsl:if>
		<xsl:if test="Bibitem/@Type='Proceedings'">
			<xsl:choose>
				<xsl:when test="../MetaData/General/Language='de'">
					<fo:block font-family="serif"
									font-size="12pt"
									font-weight="bold"
									line-height="18pt"
									space-after="12pt">
						<xsl:text>Protokolle und Berichte</xsl:text>
					</fo:block>
				</xsl:when>
				<xsl:when test="../MetaData/General/Language='en'">
					<fo:block font-family="serif"
									font-size="12pt"
									font-weight="bold"
									line-height="18pt"
									space-after="12pt">
						<xsl:text>Proceedings</xsl:text>
					</fo:block>
				</xsl:when>
			</xsl:choose>
			<xsl:for-each select="Bibitem[@Type='Proceedings']">
				<xsl:sort select="(Author[1]/Family | Editor[1]/Family | Organization)[1]"/>
				<fo:block font-family="serif"
									font-size="12pt"
									line-height="18pt"
									space-after="12pt">
					<xsl:apply-templates select="."/>
				</fo:block>
			</xsl:for-each>
		</xsl:if>
		<xsl:if test="Bibitem/@Type='Techreport'">
			<xsl:choose>
				<xsl:when test="../MetaData/General/Language='de'">
					<fo:block font-family="serif"
									font-size="12pt"
									font-weight="bold"
									line-height="18pt"
									space-after="12pt">
						<xsl:text>Technische Reports</xsl:text>
					</fo:block>
				</xsl:when>
				<xsl:when test="../MetaData/General/Language='en'">
					<fo:block font-family="serif"
									font-size="12pt"
									font-weight="bold"
									line-height="18pt"
									space-after="12pt">
						<xsl:text>Techreport</xsl:text>
					</fo:block>
				</xsl:when>
			</xsl:choose>
			<xsl:for-each select="Bibitem[@Type='Techreport']">
				<xsl:sort select="(Author[1]/Family | Editor[1]/Family | Organization)[1]"/>
				<fo:block font-family="serif"
									font-size="12pt"
									line-height="18pt"
									space-after="12pt">
					<xsl:apply-templates select="."/>
				</fo:block>
			</xsl:for-each>
		</xsl:if>
		<xsl:if test="Bibitem/@Type='Unpublished'">
			<xsl:choose>
				<xsl:when test="../MetaData/General/Language='de'">
					<fo:block font-family="serif"
									font-size="12pt"
									font-weight="bold"
									line-height="18pt"
									space-after="12pt">
						<xsl:text>Unveröffentlicht</xsl:text>
					</fo:block>
				</xsl:when>
				<xsl:when test="../MetaData/General/Language='en'">
					<fo:block font-family="serif"
									font-size="12pt"
									font-weight="bold"
									line-height="18pt"
									space-after="12pt">
						<xsl:text>Unpublished</xsl:text>
					</fo:block>
				</xsl:when>
			</xsl:choose>
			<xsl:for-each select="Bibitem[@Type='Unpublished']">
				<xsl:sort select="(Author[1]/Family | Editor[1]/Family | Organization)[1]"/>
				<fo:block font-family="serif"
									font-size="12pt"
									line-height="18pt"
									space-after="12pt">
					<xsl:apply-templates select="."/>
				</fo:block>
			</xsl:for-each>
		</xsl:if>
	</xsl:template>

	<xsl:template match="Bibitem">
<!-- ab hier muss angepasst werden auf DIN 1505 Verwendung -->
<!-- Unterscheidung selbst- vs unselbständig -->
<!-- Named Templates Author und Author_Editor einbauen -->
		<xsl:choose>
		<!-- bibliographisch selbständig -->
			<xsl:when test="@Type='AV' or @Type='Book' or @Type='Dissertation' or @Type='Internet' or @Type='Manual' or @Type='Mastersthesis' or @Type='Phdthesis' or @Type='Techreport'">
				<!-- Formatierung für Monografien und Sammelwerke nach DIN 1505, Teil 2 -->
				<!-- Verfasserangabe ; Herausgeber (Hrsg.) ; wichtige Mitarbeiter, Bearbeiter (Mitarb.) ; Körperschaftl. Urheber (Hrsg.): Sachtitel [kursiv] : Zusatz zum Sachtitel [kursiv] / weniger wichtige beteiligte Personen (Bearb.). Bandangabe, Teilbandzählung : Sachtitel d. Bandes [kursiv]. Auflage. erster Erscheinungsort : erster Verlag, Erscheinungsjahr Gesamttitel mit Zählung. - ergänzende Angaben. - ISBN -->
				<!-- Verfasser -->
				<xsl:choose>
					<xsl:when test="Author and Editor">
						<xsl:call-template name="Authors"/>
						<xsl:text> ; </xsl:text>
						<xsl:call-template name="Editors"/>
					</xsl:when>
					<xsl:when test="Editor and not(Author)">
						<xsl:call-template name="Editors"/>
					</xsl:when>
					<xsl:when test="Author and not(Editor)">
						<xsl:call-template name="Authors"/>
					</xsl:when>
				</xsl:choose>
				<!-- Mitarbeiter kennt die DTD nicht -->
				<!-- Körperschaftliche Herausgeber -->
				<xsl:if test="Organization">
					<xsl:if test="preceding-sibling::Author | Editor">
						<xsl:text> ; </xsl:text>
					</xsl:if>
					<xsl:apply-templates select="Organization"/>
					<xsl:text> (Hrsg.)</xsl:text>
				</xsl:if>
				<!-- Sachtitel -->
				<xsl:text>: </xsl:text>
				<fo:inline font-style="italic">
					<xsl:apply-templates select="Title"/>
				</fo:inline>
				<!-- Zusatz zum Sachtitel kennt die DTD nicht -->
				<!-- Bearbeiter/weniger wichtige beteiligte Personen kennt die DTD nicht -->
				<!-- Bandangabe -->
				<xsl:if test="Volume">
					<xsl:text>. </xsl:text>
					<xsl:apply-templates select="Volume"/>
				</xsl:if>
				<xsl:if test="Number">
					<xsl:text>, </xsl:text>
					<xsl:choose>
						<xsl:when test="ancestor::LearningObject[1]/MetaData/General/Language='de'">
							<xsl:text>Nr. </xsl:text>
							<xsl:apply-templates select="Number"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:text>No. </xsl:text>
							<xsl:apply-templates select="Number"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:if>
				<!-- Sachtitel des Teilbandes -->
				<xsl:if test="Booktitle">
					<xsl:text> : </xsl:text>
					<fo:inline font-style="italic">
						<xsl:apply-templates select="Booktitle"/>
					</fo:inline>
				</xsl:if>
				<!-- Auflage -->
				<xsl:if test="Edition">
					<xsl:text>. </xsl:text>
					<xsl:value-of select="Edition"/>
				</xsl:if>
				<!-- erster Erscheinungsort -->
				<xsl:if test="Address">
					<xsl:text>. </xsl:text>
					<xsl:value-of select="Address[1]"/>
				</xsl:if>
				<!-- erster Verlag -->
				<xsl:if test="Publisher">
					<xsl:text> : </xsl:text>
					<xsl:value-of select="Publisher[1]"/>
				</xsl:if>
				<!-- Erscheinungsjahr -->
				<xsl:text>, </xsl:text>
				<xsl:value-of select="Year"/>
				<!-- ISBN -->
				<xsl:if test="ISBN">
					<xsl:text>. - ISBN </xsl:text>
					<xsl:value-of select="ISBN"/>
				</xsl:if>
				<!-- URL -->
				<xsl:for-each select="URL">
					<fo:block/>
					<xsl:value-of select="."/>
					<xsl:if test="position()!=last()">
						<xsl:text>, </xsl:text>
					</xsl:if>
				</xsl:for-each>
			</xsl:when>				
			<!-- bibliographisch unselbständig -->
			<xsl:when test="@Type='Article' or @Type='Inbook' or @Type='Incollection' or @Type='Inproceedings' or @Type='Journalarticle' or @Type='Newspaperarticle' or @Type='Proceedings' or @Type='Unpublished'">
				<!-- Verfasser -->
				<xsl:choose>
					<xsl:when test="Author and Editor">
						<xsl:call-template name="Authors"/>
						<!-- Sachtitel -->
						<xsl:text>: </xsl:text>
						<fo:inline font-style="italic">
							<xsl:apply-templates select="Title"/>
						</fo:inline>
						<xsl:choose>
							<xsl:when test="Booktitle">
								<xsl:text>. In: </xsl:text>
								<xsl:call-template name="Editors"/>
								<xsl:text> </xsl:text>
								<fo:inline font-style="italic">
									<xsl:apply-templates select="Booktitle"/>
								</fo:inline>
							</xsl:when>
							<xsl:when test="Journal">
								<xsl:text>. In: </xsl:text>
								<fo:inline font-style="italic">
									<xsl:apply-templates select="Journal"/>
								</fo:inline>
								<!-- Bandangabe -->
								<xsl:if test="Volume">
									<xsl:text>. </xsl:text>
									<xsl:apply-templates select="Volume"/>
								</xsl:if>
								<xsl:if test="Number">
									<xsl:text> </xsl:text>
									<xsl:choose>
										<xsl:when test="ancestor::LearningObject[1]/MetaData/General/Language='de'">
											<xsl:text>Nr. </xsl:text>
											<xsl:apply-templates select="Number"/>
										</xsl:when>
										<xsl:otherwise>
											<xsl:text>No. </xsl:text>
											<xsl:apply-templates select="Number"/>
										</xsl:otherwise>
									</xsl:choose>
								</xsl:if>
							</xsl:when>
						</xsl:choose>
					</xsl:when>
					<xsl:when test="Editor and not(Author)">
						<xsl:call-template name="Editors"/>
						<!-- Sachtitel -->
						<xsl:text>: </xsl:text>
						<fo:inline font-style="italic">
							<xsl:apply-templates select="Title"/>
						</fo:inline>
						<xsl:choose>
							<xsl:when test="Booktitle">
								<xsl:text>. In: </xsl:text>
								<xsl:call-template name="Editors"/>
								<xsl:text> </xsl:text>
								<fo:inline font-style="italic">
									<xsl:apply-templates select="Booktitle"/>
								</fo:inline>
							</xsl:when>
							<xsl:when test="Journal">
								<xsl:text>. In: </xsl:text>
								<fo:inline font-style="italic">
									<xsl:apply-templates select="Journal"/>
								</fo:inline>
								<!-- Bandangabe -->
								<xsl:if test="Volume">
									<xsl:text>. </xsl:text>
									<xsl:apply-templates select="Volume"/>
								</xsl:if>
								<xsl:if test="Number">
									<xsl:text> </xsl:text>
									<xsl:choose>
										<xsl:when test="ancestor::LearningObject[1]/MetaData/General/Language='de'">
											<xsl:text>Nr. </xsl:text>
											<xsl:apply-templates select="Number"/>
										</xsl:when>
										<xsl:otherwise>
											<xsl:text>No. </xsl:text>
											<xsl:apply-templates select="Number"/>
										</xsl:otherwise>
									</xsl:choose>
								</xsl:if>
							</xsl:when>
						</xsl:choose>
					</xsl:when>
					<xsl:when test="Author and not(Editor)">
						<xsl:call-template name="Authors"/>
						<!-- Sachtitel -->
						<xsl:text>: </xsl:text>
						<fo:inline font-style="italic">
							<xsl:apply-templates select="Title"/>
						</fo:inline>
						<xsl:choose>
							<xsl:when test="Booktitle">
								<xsl:text>. In: </xsl:text>
								<xsl:call-template name="Editors"/>
								<xsl:text> </xsl:text>
								<fo:inline font-style="italic">
									<xsl:apply-templates select="Booktitle"/>
								</fo:inline>
							</xsl:when>
							<xsl:when test="Journal">
								<xsl:text>. In: </xsl:text>
								<fo:inline font-style="italic">
									<xsl:apply-templates select="Journal"/>
								</fo:inline>
								<!-- Bandangabe -->
								<xsl:if test="Volume">
									<xsl:text>. </xsl:text>
									<xsl:apply-templates select="Volume"/>
								</xsl:if>
								<xsl:if test="Number">
									<xsl:text> </xsl:text>
									<xsl:choose>
										<xsl:when test="ancestor::LearningObject[1]/MetaData/General/Language='de'">
											<xsl:text>Nr. </xsl:text>
											<xsl:apply-templates select="Number"/>
										</xsl:when>
										<xsl:otherwise>
											<xsl:text>No. </xsl:text>
											<xsl:apply-templates select="Number"/>
										</xsl:otherwise>
									</xsl:choose>
								</xsl:if>
							</xsl:when>
						</xsl:choose>
					</xsl:when>
				</xsl:choose>
				<!-- Zusatz zum Sachtitel kennt die DTD nicht -->
				<!-- Angabe des Teils kennt die DTD nicht -->
				<!-- Gesamttitelangabe kennt die DTD nicht -->				
				<!-- Erscheinungsjahr -->
				<!-- erster Erscheinungsort -->
				<xsl:if test="Address">
					<xsl:text>. </xsl:text>
					<xsl:value-of select="Address[1]"/>
				</xsl:if>
				<!-- erster Verlag -->
				<xsl:if test="Publisher">
					<xsl:text> : </xsl:text>
					<xsl:value-of select="Publisher[1]"/>
				</xsl:if>
				<xsl:text>, </xsl:text>
				<xsl:value-of select="Year"/>
				<!-- Seitenzählung -->
				<xsl:if test="Pages">
					<xsl:text>, </xsl:text>
					<xsl:choose>
						<xsl:when test="ancestor::LearningObject[1]/MetaData/General/Language='de'">
							<xsl:text>S. </xsl:text>
							<xsl:apply-templates select="Pages"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:text>pp </xsl:text>
							<xsl:apply-templates select="Pages"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:if>
				<xsl:for-each select="URL">
					<fo:block/>
					<xsl:value-of select="."/>
					<xsl:if test="position()!=last()">
						<xsl:text>, </xsl:text>
					</xsl:if>
				</xsl:for-each>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="Authors">
		<xsl:for-each select="Author">
			<xsl:apply-templates select="Family"/>
			<xsl:if test="Given | Other | Suffix">
				<xsl:text>, </xsl:text>
				<xsl:apply-templates select="Given"/>
				<xsl:if test="Other">
					<xsl:text> </xsl:text>
					<xsl:apply-templates select="Other"/>
				</xsl:if>
				<xsl:if test="Suffix">
					<xsl:text>, </xsl:text>
					<xsl:apply-templates select="Suffix"/>
				</xsl:if>
			</xsl:if>
			<xsl:if test="position()!=last()">
				<xsl:text> ; </xsl:text>
			</xsl:if>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template name="Editors">
		<xsl:for-each select="Editor">
			<xsl:apply-templates select="Family"/>
			<xsl:if test="Given | Other | Suffix">
				<xsl:text>, </xsl:text>
				<xsl:apply-templates select="Given"/>
				<xsl:if test="Other">
					<xsl:text> </xsl:text>
					<xsl:apply-templates select="Other"/>
				</xsl:if>
				<xsl:if test="Suffix">
					<xsl:text>, </xsl:text>
					<xsl:apply-templates select="Suffix"/>
				</xsl:if>
			</xsl:if>
			<xsl:choose>
				<xsl:when test="position()=last()">
					<xsl:choose>
						<xsl:when test="ancestor::LearningObject[1]/MetaData/General/Language='de'">
							<xsl:text> (Hrsg.)</xsl:text>
						</xsl:when>
						<xsl:otherwise>
							<xsl:text> (Ed.)</xsl:text>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:when>
				<xsl:otherwise>
					<xsl:text> ; </xsl:text>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template name="Authors_and_Editors">
<!-- Anmerkung: Template ist evtl. noch anzupassen. Im schlimmsten Fall werden je 2 Autoren und 2 Editoren angegeben, bevor abgekürzt wird. -->
		<xsl:choose>
			<xsl:when test="id(@Reference_to)/Author and id(@Reference_to)/Editor">
				<!-- erst die Autoren -->
				<xsl:choose>
					<xsl:when test="id(@Reference_to)/Author[last()>2]">
						<xsl:apply-templates select="id(@Reference_to)/Author[1]/Family"/>
						<xsl:if test="id(@Reference_to)/Author[1]/Given | id(@Reference_to)/Author[1]/Other | id(@Reference_to)/Author[1]/Suffix">
							<xsl:text>, </xsl:text>
							<xsl:apply-templates select="id(@Reference_to)/Author[1]/Given"/>
							<xsl:if test="id(@Reference_to)/Author/Other">
								<xsl:text> </xsl:text>
								<xsl:apply-templates select="id(@Reference_to)/Author[1]/Other"/>
							</xsl:if>
							<xsl:if test="id(@Reference_to)/Author/Suffix">
								<xsl:text>, </xsl:text>
								<xsl:apply-templates select="id(@Reference_to)/Author[1]/Suffix"/>
							</xsl:if>
						</xsl:if>
						<xsl:text> ; </xsl:text>
						<xsl:apply-templates select="id(@Reference_to)/Author[2]/Family"/>
						<xsl:if test="id(@Reference_to)/Author[2]/Given | id(@Reference_to)/Author[2]/Other | id(@Reference_to)/Author[2]/Suffix">
							<xsl:text>, </xsl:text>
							<xsl:apply-templates select="id(@Reference_to)/Author[2]/Given"/>
							<xsl:if test="id(@Reference_to)/Author[2]/Other">
								<xsl:text> </xsl:text>
								<xsl:apply-templates select="id(@Reference_to)/Author[2]/Other"/>
							</xsl:if>
							<xsl:if test="id(@Reference_to)/Author[2]/Suffix">
								<xsl:text>, </xsl:text>
								<xsl:apply-templates select="id(@Reference_to)/Author[2]/Suffix"/>
							</xsl:if>
						</xsl:if>		
						<xsl:text> et al.</xsl:text>
					</xsl:when>
					<xsl:otherwise>
						<xsl:for-each select="id(@Reference_to)/Author">
							<xsl:apply-templates select="Family"/>
							<xsl:if test="Given | Other | Suffix">
								<xsl:text>, </xsl:text>
								<xsl:apply-templates select="Given"/>
								<xsl:if test="Other">
									<xsl:text> </xsl:text>
									<xsl:apply-templates select="Other"/>
								</xsl:if>
								<xsl:if test="Suffix">
									<xsl:text>, </xsl:text>
									<xsl:apply-templates select="Suffix"/>
								</xsl:if>
							</xsl:if>
							<xsl:if test="position()!=last()">
								<xsl:text> ; </xsl:text>
							</xsl:if>
						</xsl:for-each>
					</xsl:otherwise>
				</xsl:choose>
				<xsl:text> in: </xsl:text>
				<!-- jetzt die Editoren -->
				<xsl:choose>
					<xsl:when test="id(@Reference_to)/Editor[last()>2]">
						<xsl:apply-templates select="id(@Reference_to)/Editor[1]/Family"/>
						<xsl:if test="id(@Reference_to)/Editor[1]/Given | id(@Reference_to)/Editor[1]/Other | id(@Reference_to)/Editor[1]/Suffix">
							<xsl:text>, </xsl:text>
							<xsl:apply-templates select="id(@Reference_to)/Editor[1]/Given"/>
							<xsl:if test="id(@Reference_to)/Editor/Other">
								<xsl:text> </xsl:text>
								<xsl:apply-templates select="id(@Reference_to)/Editor[1]/Other"/>
							</xsl:if>
							<xsl:if test="id(@Reference_to)/Editor/Suffix">
								<xsl:text>, </xsl:text>
								<xsl:apply-templates select="id(@Reference_to)/Editor[1]/Suffix"/>
							</xsl:if>
						</xsl:if>
						<xsl:text> ; </xsl:text>
						<xsl:apply-templates select="id(@Reference_to)/Editor[2]/Family"/>
						<xsl:if test="id(@Reference_to)/Editor[2]/Given | id(@Reference_to)/Editor[2]/Other | id(@Reference_to)/Editor[2]/Suffix">
							<xsl:text>, </xsl:text>
							<xsl:apply-templates select="id(@Reference_to)/Editor[2]/Given"/>
							<xsl:if test="id(@Reference_to)/Editor[2]/Other">
								<xsl:text> </xsl:text>
								<xsl:apply-templates select="id(@Reference_to)/Editor[2]/Other"/>
							</xsl:if>
							<xsl:if test="id(@Reference_to)/Editor[2]/Suffix">
								<xsl:text>, </xsl:text>
								<xsl:apply-templates select="id(@Reference_to)/Editor[2]/Suffix"/>
							</xsl:if>
						</xsl:if>
						<xsl:choose>
							<xsl:when test="ancestor::LearningObject[1]/MetaData/General/Language='de'">
								<xsl:text> et al. (Hrsg.)</xsl:text>
							</xsl:when>
							<xsl:otherwise>
								<xsl:text> et al. (Ed.)</xsl:text>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<xsl:for-each select="id(@Reference_to)/Editor">
							<xsl:apply-templates select="Family"/>
							<xsl:if test="Given | Other | Suffix">
								<xsl:text>, </xsl:text>
								<xsl:apply-templates select="Given"/>
								<xsl:if test="Other">
									<xsl:text> </xsl:text>
									<xsl:apply-templates select="Other"/>
								</xsl:if>
								<xsl:if test="Suffix">
									<xsl:text>, </xsl:text>
									<xsl:apply-templates select="Suffix"/>
								</xsl:if>
							</xsl:if>
							<xsl:choose>
								<xsl:when test="position()=last()">
									<xsl:choose>
										<xsl:when test="ancestor::LearningObject[1]/MetaData/General/Language='de'">
											<xsl:text> (Hrsg.)</xsl:text>
										</xsl:when>
										<xsl:otherwise>
											<xsl:text> (Ed.)</xsl:text>
										</xsl:otherwise>
									</xsl:choose>
								</xsl:when>
								<xsl:otherwise>
									<xsl:text> ; </xsl:text>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:for-each>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:when test="id(@Reference_to)/Editor and not(id(@Reference_to)/Author)">
				<!-- die Editoren -->
				<xsl:choose>
					<xsl:when test="id(@Reference_to)/Editor[last()>2]">
						<xsl:apply-templates select="id(@Reference_to)/Editor[1]/Family"/>
						<xsl:if test="id(@Reference_to)/Editor[1]/Given | id(@Reference_to)/Editor[1]/Other | id(@Reference_to)/Editor[1]/Suffix">
							<xsl:text>, </xsl:text>
							<xsl:apply-templates select="id(@Reference_to)/Editor[1]/Given"/>
							<xsl:if test="id(@Reference_to)/Editor/Other">
								<xsl:text> </xsl:text>
								<xsl:apply-templates select="id(@Reference_to)/Editor[1]/Other"/>
							</xsl:if>
							<xsl:if test="id(@Reference_to)/Editor/Suffix">
								<xsl:text>, </xsl:text>
								<xsl:apply-templates select="id(@Reference_to)/Editor[1]/Suffix"/>
							</xsl:if>
						</xsl:if>
						<xsl:text> ; </xsl:text>
						<xsl:apply-templates select="id(@Reference_to)/Editor[2]/Family"/>
						<xsl:if test="id(@Reference_to)/Editor[2]/Given | id(@Reference_to)/Editor[2]/Other | id(@Reference_to)/Editor[2]/Suffix">
							<xsl:text>, </xsl:text>
							<xsl:apply-templates select="id(@Reference_to)/Editor[2]/Given"/>
							<xsl:if test="id(@Reference_to)/Editor[2]/Other">
								<xsl:text> </xsl:text>
								<xsl:apply-templates select="id(@Reference_to)/Editor[2]/Other"/>
							</xsl:if>
							<xsl:if test="id(@Reference_to)/Editor[2]/Suffix">
								<xsl:text>, </xsl:text>
								<xsl:apply-templates select="id(@Reference_to)/Editor[2]/Suffix"/>
							</xsl:if>
						</xsl:if>
						<xsl:choose>
							<xsl:when test="ancestor::LearningObject[1]/MetaData/General/Language='de'">
								<xsl:text> et al. (Hrsg.)</xsl:text>
							</xsl:when>
							<xsl:otherwise>
								<xsl:text> et al. (Ed.)</xsl:text>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<xsl:for-each select="id(@Reference_to)/Editor">
							<xsl:apply-templates select="Family"/>
							<xsl:if test="Given | Other | Suffix">
								<xsl:text>, </xsl:text>
								<xsl:apply-templates select="Given"/>
								<xsl:if test="Other">
									<xsl:text> </xsl:text>
									<xsl:apply-templates select="Other"/>
								</xsl:if>
								<xsl:if test="Suffix">
									<xsl:text>, </xsl:text>
									<xsl:apply-templates select="Suffix"/>
								</xsl:if>
							</xsl:if>
							<xsl:choose>
								<xsl:when test="position()=last()">
									<xsl:choose>
										<xsl:when test="ancestor::LearningObject[1]/MetaData/General/Language='de'">
											<xsl:text> (Hrsg.)</xsl:text>
										</xsl:when>
										<xsl:otherwise>
											<xsl:text> (Ed.)</xsl:text>
										</xsl:otherwise>
									</xsl:choose>
								</xsl:when>
								<xsl:otherwise>
									<xsl:text> ; </xsl:text>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:for-each>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:when test="id(@Reference_to)/Author and not(id(@Reference_to)/Editor)">
				<!-- nur die Autoren -->
				<xsl:choose>
					<xsl:when test="id(@Reference_to)/Author[last()>2]">
						<xsl:apply-templates select="id(@Reference_to)/Author[1]/Family"/>
						<xsl:if test="id(@Reference_to)/Author[1]/Given | id(@Reference_to)/Author[1]/Other | id(@Reference_to)/Author[1]/Suffix">
							<xsl:text>, </xsl:text>
							<xsl:apply-templates select="id(@Reference_to)/Author[1]/Given"/>
							<xsl:if test="id(@Reference_to)/Author/Other">
								<xsl:text> </xsl:text>
								<xsl:apply-templates select="id(@Reference_to)/Author[1]/Other"/>
							</xsl:if>
							<xsl:if test="id(@Reference_to)/Author/Suffix">
								<xsl:text>, </xsl:text>
								<xsl:apply-templates select="id(@Reference_to)/Author[1]/Suffix"/>
							</xsl:if>
						</xsl:if>
						<xsl:text> ; </xsl:text>
						<xsl:apply-templates select="id(@Reference_to)/Author[2]/Family"/>
						<xsl:if test="id(@Reference_to)/Author[2]/Given | id(@Reference_to)/Author[2]/Other | id(@Reference_to)/Author[2]/Suffix">
							<xsl:text>, </xsl:text>
							<xsl:apply-templates select="id(@Reference_to)/Author[2]/Given"/>
							<xsl:if test="id(@Reference_to)/Author[2]/Other">
								<xsl:text> </xsl:text>
								<xsl:apply-templates select="id(@Reference_to)/Author[2]/Other"/>
							</xsl:if>
							<xsl:if test="id(@Reference_to)/Author[2]/Suffix">
								<xsl:text>, </xsl:text>
								<xsl:apply-templates select="id(@Reference_to)/Author[2]/Suffix"/>
							</xsl:if>
						</xsl:if>
						<xsl:text> et al.</xsl:text>
					</xsl:when>
					<xsl:otherwise>
						<xsl:for-each select="id(@Reference_to)/Author">
							<xsl:apply-templates select="Family"/>
							<xsl:if test="Given | Other | Suffix">
								<xsl:text>, </xsl:text>
								<xsl:apply-templates select="Given"/>
								<xsl:if test="Other">
									<xsl:text> </xsl:text>
									<xsl:apply-templates select="Other"/>
								</xsl:if>
								<xsl:if test="Suffix">
									<xsl:text>, </xsl:text>
									<xsl:apply-templates select="Suffix"/>
								</xsl:if>
							</xsl:if>
							<xsl:if test="position()!=last()">
								<xsl:text> ; </xsl:text>
							</xsl:if>
						</xsl:for-each>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:when test="id(@Reference_to)/Organization and not(id(@Reference_to)/Editor) and not(id(@Reference_to)/Author)">
				<xsl:for-each select="id(@Reference_to)/Organization">
					<xsl:apply-templates select="."/>
					<xsl:choose>
						<xsl:when test="position()=last()">
							<xsl:choose>
								<xsl:when test="ancestor::LearningObject[1]/MetaData/General/Language='de'">
									<xsl:text> (Hrsg.)</xsl:text>
								</xsl:when>
								<xsl:otherwise>
									<xsl:text> (Ed.)</xsl:text>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:when>
						<xsl:otherwise>
							<xsl:text> ; </xsl:text>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:for-each>
			</xsl:when>
		</xsl:choose>
	</xsl:template>	

	<xsl:template match="Glossary">
		<fo:block	font-size="16pt"
							line-height="24pt"
							font-weight="bold"
							break-before="page">
			<xsl:choose>
				<xsl:when test="../MetaData/General/Language='de'">
					<xsl:text>Glossar</xsl:text>
				</xsl:when>
				<xsl:otherwise>
					<xsl:text>Glossary</xsl:text>
				</xsl:otherwise>
			</xsl:choose>
		</fo:block>
		<fo:table table-layout="fixed">
			<fo:table-column column-width="35mm"/>
			<fo:table-column column-width="125mm"/>
			<fo:table-body font-size="12pt" font-family="serif">
				<xsl:for-each select="GlossaryItem">
					<xsl:sort select="GlossaryTerm"/>
					<fo:table-row line-height="16pt">
						<fo:table-cell>
							<fo:block text-align="start">
								<xsl:value-of select="GlossaryTerm"/>
							</fo:block>
						</fo:table-cell>
						<fo:table-cell>
							<fo:block text-align="start">
								<xsl:apply-templates select="Definition"/>
								<xsl:apply-templates select="Definitionlist"/>
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
				</xsl:for-each>
			</fo:table-body>
		</fo:table>
	</xsl:template>

	<xsl:template match="GlossaryTerm">
		<fo:inline font-size="8pt" color="red" vertical-align="super">&#8599;</fo:inline>
		<xsl:apply-templates/>
	</xsl:template>

	<xsl:template match="DefinitionList">
		<fo:block>
			<xsl:apply-templates/>
		</fo:block>
	</xsl:template>

	<xsl:template match="Reference">
		<fo:inline>
			<xsl:choose>
				<xsl:when test="@Type='LearningObject'">
					<xsl:choose>
						<xsl:when test="id(@Reference_to)/../@AggregationLevel=3">
							&quot;<xsl:value-of select="id(@Reference_to)/../Title"/>&quot;<xsl:text>, </xsl:text>
							<xsl:choose>
								<xsl:when test="../@Language='de'">
									<xsl:text>S. </xsl:text>
								</xsl:when>
								<xsl:when test="../@Language='en'">
									<xsl:text>p. </xsl:text>
								</xsl:when>
							</xsl:choose>
							<fo:page-number-citation>
								<xsl:attribute name="ref-id">
									<xsl:value-of select="id(@Reference_to)/../../../Content/LearningObject[1]/MetaData/General/Identifier/@Entry"/>
								</xsl:attribute>
							</fo:page-number-citation>
						</xsl:when>
						<xsl:when test="id(@Reference_to)/../@AggregationLevel=2">
							&quot;<xsl:value-of select="id(@Reference_to)/../Title"/>&quot;<xsl:text>, </xsl:text>
							<xsl:choose>
								<xsl:when test="../@Language='de'">
									<xsl:text>S. </xsl:text>
								</xsl:when>
								<xsl:when test="../@Language='en'">
									<xsl:text>p. </xsl:text>
								</xsl:when>
							</xsl:choose>
							<fo:page-number-citation>
								<xsl:attribute name="ref-id">
									<xsl:value-of select="@Reference_to"/>
								</xsl:attribute>
							</fo:page-number-citation>
						</xsl:when>
					</xsl:choose>
				</xsl:when>
				<xsl:when test="@Type='Example'">
					<xsl:choose>
						<xsl:when test="../@Language='de'">
							<fo:inline font-style="italic">Beispiel</fo:inline>
						</xsl:when>
						<xsl:otherwise>
							<fo:inline font-style="italic">Example</fo:inline>
					</xsl:otherwise>
					</xsl:choose>
					<fo:inline font-style="italic">: "</fo:inline>
					<fo:inline font-style="italic">
						<xsl:value-of select="translate(@Reference_to,'_',' ')"/>
						<xsl:apply-templates/>
						<xsl:text>"</xsl:text>
					</fo:inline>
				</xsl:when>
				<xsl:when test="@Type='RefTarget'">
					&quot;<xsl:value-of select="id(@Reference_to)"/>&quot;<xsl:text>, </xsl:text>
					<xsl:choose>
						<xsl:when test="../@Language='de'">
							<xsl:text>S. </xsl:text>
						</xsl:when>
						<xsl:when test="../@Language='en'">
							<xsl:text>p. </xsl:text>
						</xsl:when>
					</xsl:choose>
					<fo:page-number-citation>
						<xsl:attribute name="ref-id">
							<xsl:value-of select="@Reference_to"/>
						</xsl:attribute>
					</fo:page-number-citation>
				</xsl:when>
				<xsl:when test="@Type='BibliographyEntry'">
					<xsl:choose>
						<xsl:when test="id(@Reference_to)/Author">
							<xsl:for-each select="id(@Reference_to)/Author">
								<xsl:apply-templates select="Family"/>
								<xsl:choose>
									<xsl:when test="position()!=last()">
										<xsl:text>, </xsl:text>
									</xsl:when>
								</xsl:choose>
							</xsl:for-each>
						</xsl:when>
						<xsl:when test="id(@Reference_to)/Editor">
							<xsl:for-each select="id(@Reference_to)/Editor">
								<xsl:apply-templates select="Family"/>
								<xsl:choose>
									<xsl:when test="position()!=last()">
										<xsl:text>, </xsl:text>
									</xsl:when>
								</xsl:choose>
							</xsl:for-each>
							<xsl:text> (Hrsg.)</xsl:text>
						</xsl:when>
						<xsl:when test="id(@Reference_to)/Organization">
							<xsl:for-each select="id(@Reference_to)/Organization">
								<xsl:apply-templates select="."/>
								<xsl:choose>
									<xsl:when test="position()!=last()">
										<xsl:text>, </xsl:text>
									</xsl:when>
								</xsl:choose>
							</xsl:for-each>
							<xsl:text>, </xsl:text>
							<xsl:apply-templates select="id(@Reference_to)/Title"/>
						</xsl:when>
					</xsl:choose>
					<xsl:if test="id(@Reference_to)/Year">
						<xsl:text>, </xsl:text>
						<xsl:apply-templates select="id(@Reference_to)/Year"/>
					</xsl:if>
					<xsl:if test="@Page">
						<xsl:text>, S. </xsl:text>
						<xsl:apply-templates select="@Page"/>
					</xsl:if>
				</xsl:when>
			</xsl:choose>
		</fo:inline>
	</xsl:template>

	<xsl:template match="RefTarget">
		<fo:inline>
			<xsl:attribute name="id">
				<xsl:value-of select="@Id"/>
			</xsl:attribute>
			<xsl:apply-templates/>
		</fo:inline>
	</xsl:template>

	<xsl:template match="Comment"/>

</xsl:stylesheet>