<?xml version="1.0"?>
<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
															xmlns="http://www.w3.org/1999/xhtml"
															xmlns:xhtml="http://www.w3.org/1999/xhtml"
															xmlns:xlink="http://www.w3.org/1999/xlink"
															xmlns:date="http://exslt.org/dates-and-times"
															extension-element-prefixes="date"
>
	<xsl:output method="xml"
							media-type="text/xml"
							doctype-system="include/xhtml-math-svg-flat.dtd"
							doctype-public="-//W3C//DTD XHTML 1.1 plus MathML 2.0 plus SVG 1.1//EN"
							encoding="UTF-8"
							indent="no"/>
	<xsl:output name="text"
							method="text"
							media-type="text/plain"
							encoding="ISO-8859-1"/>

	<xsl:param name="include-optional-paragraphs" select="Yes"/>
	<xsl:param name="ILIAS" select="No"/>
	
<!--	********************************************************************************************
			MiLCA XSLT Stylesheet for transforming MiLCA XML LearningObjects to XHTML and ILIAS-HTML.
			Edited by Maik Stuehrenberg (JLU Giessen), feel free to send questions and comments to maik.stuehrenberg@uni-giessen.de 
			Last edited on 11-12-2003, 11:10.
			Copyright (c) 2002, 2003 by Maik Stuehrenberg (JLU Giessen)
			Permission is granted to copy, distribute and/or modify this document under the terms of the GNU Free Documentation License, Version 1.2 or any later version published by the Free Software Foundation;
			with no Invariant Sections, no Front-Cover Texts, and no Back-Cover Texts.
			A copy of the license is included in the file entitled "fdl.txt".
			******************************************************************************************** -->

	<xsl:strip-space elements="*"/>
	<xsl:preserve-space elements="xsl:text"/>

<!-- Template fuer das root-Element LearningObject -->
<!-- Die Verarbeitung erfolgt in mehreren Schritten: -->
<!-- 1. Erzeugung einer Ausgabedatei -->
<!-- 2. Erstellung eines Inhaltsverzeichnisses -->
<!-- Dabei wird jeweils nach dem AggregationLevel unterschieden -->
	<xsl:template match="LearningObject">
		<xsl:choose>
			<xsl:when test="MetaData/General/@AggregationLevel>=3">
<!-- Level 3 und hoeher erhalten ein Inhaltsverzeichnis -->
				<xsl:variable name="index" select="concat(string(MetaData/General/Identifier/@Entry),'.xhtml')"/>
				<xsl:result-document href="{$index}">
					<html>
						<head>
							<xsl:apply-templates select="MetaData"/>
							<xsl:choose>
								<xsl:when test="$ILIAS='Yes'"/>
								<xsl:otherwise>
									<link type="text/css" rel="stylesheet">
										<xsl:attribute name="href">
											<xsl:value-of select="LayoutInformation/@CSS-URL"/>
										</xsl:attribute>
									</link>
								</xsl:otherwise>
							</xsl:choose>
						</head>
						<body>
							<xsl:choose>
								<xsl:when test="$ILIAS='Yes'"/>
								<xsl:otherwise>
									<xsl:call-template name="nav_level3"/>
								</xsl:otherwise>
							</xsl:choose>
							<h1>
								<xsl:if test="$ILIAS='Yes'">
									<xsl:attribute name="style">
										<xsl:text>font-family:verdana,arial,sans-serif;</xsl:text>
									</xsl:attribute>
								</xsl:if>
								<xsl:apply-templates select="MetaData/General/Title"/>
							</h1>
							<div>
								<xsl:choose>
									<xsl:when test="$ILIAS='Yes'">
										<xsl:attribute name="style">
											<xsl:text>margin-left:5%; margin-right:5%; padding:10px; font-family:verdana,arial,sans-serif; font-weight:bold; background-color:#efefef;</xsl:text>
										</xsl:attribute>
									</xsl:when>
									<xsl:otherwise>
										<xsl:attribute name="class">
											<xsl:text>Description</xsl:text>
										</xsl:attribute>
									</xsl:otherwise>
								</xsl:choose>
								<xsl:choose>
									<xsl:when test="MetaData/General/Language='de'">
										<strong>Zusammenfassung:</strong>
									</xsl:when>
									<xsl:when test="MetaData/General/Language='en'">
										<strong>Abstract:</strong>
									</xsl:when>
									<xsl:otherwise>
										<strong>Abstract:</strong>
									</xsl:otherwise>
								</xsl:choose>
								<br/>
								<xsl:apply-templates select="MetaData/General/Description"/>
							</div>
<!-- Erzeugen des Inhaltsverzeichnisses -->
<!-- Jedes LearningObject mit einem AggregationLevel > 1 wird in das Inhaltsverzeichnis aufgenommen -->
							<h2>
								<xsl:if test="$ILIAS='Yes'">
									<xsl:attribute name="style">
										<xsl:text>font-family:verdana,arial,sans-serif;</xsl:text>
									</xsl:attribute>
								</xsl:if>
								<xsl:choose>
									<xsl:when test="MetaData/General/Language='de'">
										<xsl:text>Inhalt</xsl:text>
									</xsl:when>
									<xsl:otherwise>
										<xsl:text>Table of Contents</xsl:text>
									</xsl:otherwise>
								</xsl:choose>
							</h2>
							<xsl:for-each select="Content/LearningObject">
								<xsl:choose>
									<xsl:when test="MetaData/General/@AggregationLevel>1 and @Optional!='Yes'">
										<xsl:variable name="LOfile" select="concat(string(MetaData/General/Identifier/@Entry),'.xhtml')"/>
										<div>
											<xsl:choose>
												<xsl:when test="$ILIAS='Yes'">
													<xsl:attribute name="style">
														<xsl:text>font-family:verdana,arial,sans-serif; margin-bottom:12pt; margin-top:12pt;</xsl:text>
													</xsl:attribute>
												</xsl:when>
												<xsl:otherwise>
													<xsl:attribute name="class">
														<xsl:text>Paragraph</xsl:text>
													</xsl:attribute>
												</xsl:otherwise>
											</xsl:choose>
											<a>
												<xsl:attribute name="href">
													<xsl:value-of select="$LOfile"/>
												</xsl:attribute>
												<xsl:value-of select="MetaData/General/Title"/>
											</a>
											<br/>
											<xsl:apply-templates select="MetaData/General/Description"/>
										</div>
									</xsl:when>
								</xsl:choose>
							</xsl:for-each>
							<xsl:if test="Test | Bibliography | Glossary">
								<div><br/></div>
							</xsl:if>
							<xsl:apply-templates select="Test"/>
							<xsl:if test="Bibliography">
								<div>
									<xsl:choose>
										<xsl:when test="$ILIAS='Yes'">
											<xsl:attribute name="style">
												<xsl:text>font-family:verdana,arial,sans-serif; margin-bottom:12pt; margin-top:12pt;</xsl:text>
											</xsl:attribute>
										</xsl:when>
										<xsl:otherwise>
											<xsl:attribute name="class">
												<xsl:text>Paragraph</xsl:text>
											</xsl:attribute>
										</xsl:otherwise>
									</xsl:choose>										
									<a>
										<xsl:attribute name="href">
											<xsl:value-of select="concat(string(MetaData/General/Identifier/@Entry),'-','bib','.xhtml')"/>
										</xsl:attribute>
										<xsl:choose>
											<xsl:when test="MetaData/General/Language='de'">
												<xsl:text>Literaturangaben</xsl:text>
											</xsl:when>
											<xsl:otherwise>
												<xsl:text>Bibliography</xsl:text>
											</xsl:otherwise>
										</xsl:choose>
									</a>
								</div>
								<xsl:apply-templates select="Bibliography"/>
							</xsl:if>
							<xsl:if test="Glossary">
								<div>
									<xsl:choose>
										<xsl:when test="$ILIAS='Yes'">
											<xsl:attribute name="style">
												<xsl:text>font-family:verdana,arial,sans-serif; margin-bottom:12pt; margin-top:12pt;</xsl:text>
											</xsl:attribute>
										</xsl:when>
										<xsl:otherwise>
											<xsl:attribute name="class">
												<xsl:text>Paragraph</xsl:text>
											</xsl:attribute>
										</xsl:otherwise>
									</xsl:choose>
									<a>
										<xsl:attribute name="href">
											<xsl:value-of select="concat(string(MetaData/General/Identifier/@Entry),'-','gloss','.xhtml')"/>
										</xsl:attribute>
										<xsl:choose>
											<xsl:when test="MetaData/General/Language='de'">
												<xsl:text>Glossar</xsl:text>
											</xsl:when>
											<xsl:otherwise>
												<xsl:text>Glossary</xsl:text>
											</xsl:otherwise>
										</xsl:choose>
									</a>
								</div>
								<xsl:apply-templates select="Glossary"/>
							</xsl:if>
							<xsl:choose>
								<xsl:when test="$ILIAS='Yes'"/>
								<xsl:otherwise>
									<xsl:call-template name="nav_level3"/>
								</xsl:otherwise>
							</xsl:choose>
						</body>
					</html>
				</xsl:result-document>
			</xsl:when>
			<xsl:when test="MetaData/General/@AggregationLevel=2 and @Optional!='Yes'">
<!-- LearningObjects mit Level 2 werden als XHTML-Seiten ausgegeben - sofern sie nicht als optional gekennzeichnet sind. -->
				<xsl:variable name="LO" select="concat(string(MetaData/General/Identifier/@Entry),'.xhtml')"/>
				<xsl:result-document href="{$LO}">
					<html>
						<head>
							<xsl:apply-templates select="MetaData"/>
							<xsl:choose>
								<xsl:when test="$ILIAS='Yes'"/>
								<xsl:otherwise>
									<link type="text/css" rel="stylesheet">
										<xsl:attribute name="href">
											<xsl:value-of select="LayoutInformation/@CSS-URL"/>
										</xsl:attribute>
									</link>
								</xsl:otherwise>
							</xsl:choose>
						</head>
						<body>
							<xsl:choose>
								<xsl:when test="$ILIAS='Yes'">
<!-- Einfuegen eines Kommentars, damit das Einfuegen in ILIAS per Cut/Paste schneller geht -->			
									<xsl:comment>Ab hier ausschneiden und in ILIAS einfuegen wenn Title und Description erwuenscht!</xsl:comment>
								</xsl:when>
								<xsl:otherwise>
									<xsl:call-template name="nav_level2"/>
								</xsl:otherwise>
							</xsl:choose>
							<h1>
								<xsl:if test="$ILIAS='Yes'">
									<xsl:attribute name="style">
										<xsl:text>font-family:verdana,arial,sans-serif;</xsl:text>
									</xsl:attribute>
								</xsl:if>
								<xsl:apply-templates select="MetaData/General/Title"/>
							</h1>
							<div>
								<xsl:choose>
									<xsl:when test="$ILIAS='Yes'">
										<xsl:attribute name="style">
											<xsl:text>font-family:verdana,arial,sans-serif; margin-bottom:12pt; margin-top:12pt;</xsl:text>
										</xsl:attribute>
									</xsl:when>
									<xsl:otherwise>
										<xsl:attribute name="class">
											<xsl:text>Description</xsl:text>
										</xsl:attribute>
									</xsl:otherwise>
								</xsl:choose>
								<xsl:choose>
									<xsl:when test="MetaData/General/Language='de'">
										<strong>Zusammenfassung:</strong>
									</xsl:when>
									<xsl:otherwise>
										<strong>Abstract:</strong>
									</xsl:otherwise>
								</xsl:choose>
								<br/>
								<xsl:apply-templates select="MetaData/General/Description"/>
							</div>
							<xsl:if test="$ILIAS='Yes'">
								<xsl:comment>Ab hier ausschneiden und in ILIAS einfuegen, falls Title und Description nicht erwuenscht!</xsl:comment>
							</xsl:if>
							<xsl:apply-templates select="Content"/>
							<xsl:if test="Test | Bibliography | Glossary">
								<div><br/></div>
							</xsl:if>
							<xsl:apply-templates select="Test"/>
							<xsl:if test="Bibliography">
								<div>
									<xsl:choose>
										<xsl:when test="$ILIAS='Yes'">
											<xsl:attribute name="style">
												<xsl:text>font-family:verdana,arial,sans-serif; margin-bottom:12pt; margin-top:12pt;</xsl:text>
											</xsl:attribute>
										</xsl:when>
										<xsl:otherwise>
											<xsl:attribute name="class">
												<xsl:text>Paragraph</xsl:text>
											</xsl:attribute>
										</xsl:otherwise>
									</xsl:choose>
									<a>
										<xsl:attribute name="href">
											<xsl:value-of select="concat(string(MetaData/General/Identifier/@Entry),'-','bib','.xhtml')"/>
										</xsl:attribute>
										<xsl:choose>
											<xsl:when test="MetaData/General/Language='de'">
												<xsl:text>Literaturangaben</xsl:text>
											</xsl:when>
											<xsl:otherwise>
												<xsl:text>Bibliography</xsl:text>
											</xsl:otherwise>
										</xsl:choose>
									</a>
								</div>
								<xsl:apply-templates select="Bibliography"/>
							</xsl:if>
							<xsl:if test="Glossary">
								<div>
									<xsl:choose>
										<xsl:when test="$ILIAS='Yes'">
											<xsl:attribute name="style">
												<xsl:text>font-family:verdana,arial,sans-serif; margin-bottom:12pt; margin-top:12pt;</xsl:text>
											</xsl:attribute>
										</xsl:when>
										<xsl:otherwise>
											<xsl:attribute name="class">
												<xsl:text>Paragraph</xsl:text>
											</xsl:attribute>
										</xsl:otherwise>
									</xsl:choose>
									<a>
										<xsl:attribute name="href">
											<xsl:value-of select="concat(string(MetaData/General/Identifier/@Entry),'-','gloss','.xhtml')"/>
										</xsl:attribute>
										<xsl:choose>
											<xsl:when test="MetaData/General/Language='de'">
												<xsl:text>Glossar</xsl:text>
											</xsl:when>
											<xsl:otherwise>
												<xsl:text>Glossary</xsl:text>
											</xsl:otherwise>
										</xsl:choose>
									</a>
								</div>
								<xsl:apply-templates select="Glossary"/>
							</xsl:if>
							<xsl:choose>
								<xsl:when test="$ILIAS='Yes'">
									<xsl:comment>Hier Ende von Cut/Paste fuer ILIAS!</xsl:comment>
								</xsl:when>
								<xsl:otherwise>
									<p/>
									<xsl:call-template name="nav_level2"/>
								</xsl:otherwise>
							</xsl:choose>
						</body>
					</html>
				</xsl:result-document>
			</xsl:when>
			<xsl:when test="MetaData/General/@AggregationLevel=1 and @Optional!='Yes'">
<!-- Verarbeitung von LearningObjects des Aggregationsgrades 1 -->	
				<xsl:if test="$ILIAS='Yes'">
					<xsl:comment>Ab hier Objekt &quot;<xsl:value-of select="MetaData/Technical/Location"/>&quot;!</xsl:comment>
				</xsl:if>
				<xsl:choose>
					<xsl:when test="MetaData/Technical/@Format='image-gif' or MetaData/Technical/@Format='image-jpeg' or MetaData/Technical/@Format='image-png' or MetaData/Technical/@Format='application-x-shockwave-flash'">
						<xsl:call-template name="bilder"/>
						<xsl:if test="$ILIAS='Yes'">
							<xsl:comment>Ende des Objekts &quot;<xsl:value-of select="MetaData/Technical/Location"/>&quot;!</xsl:comment>
						</xsl:if>
					</xsl:when>
					<xsl:when test="MetaData/Technical/@Format='image-svg-xml'">
						<xsl:copy-of select="document(MetaData/Technical/Location)/*"/>
						<xsl:if test="$ILIAS='Yes'">
							<xsl:comment>Ende des Objekts &quot;<xsl:value-of select="MetaData/Technical/Location"/>&quot;!</xsl:comment>
						</xsl:if>
						<div>
							<xsl:choose>
								<xsl:when test="$ILIAS='Yes'">
									<xsl:attribute name="style">
										<xsl:text>font-family:verdana,arial,sans-serif; font-weight:bold; font-size:smaller;</xsl:text>
									</xsl:attribute>	
								</xsl:when>
								<xsl:otherwise>
									<xsl:attribute name="class">
										<xsl:text>Image</xsl:text>
									</xsl:attribute>
								</xsl:otherwise>
							</xsl:choose>
							<xsl:choose>
								<xsl:when test="MetaData/General/Language='de'">
									<xsl:text>Abbildung </xsl:text>
								</xsl:when>
								<xsl:otherwise>
									<xsl:text>Figure </xsl:text>
								</xsl:otherwise>
							</xsl:choose>
							<xsl:number count="LearningObject[@Optional!='Yes']"/>
							<xsl:text>: </xsl:text>
							<xsl:value-of select="MetaData/General/Title"/>
						</div>
						<div>
							<xsl:choose>
								<xsl:when test="$ILIAS='Yes'">
									<xsl:attribute name="style">
										<xsl:text>font-family:verdana,arial,sans-serif; font-size:smaller;</xsl:text>
									</xsl:attribute>	
								</xsl:when>
								<xsl:otherwise>
									<xsl:attribute name="class">
										<xsl:text>Imagetext</xsl:text>
									</xsl:attribute>
								</xsl:otherwise>
							</xsl:choose>
							<xsl:apply-templates select="MetaData/General/Description"/>
						</div>
					</xsl:when>
					<xsl:when test="MetaData/Technical/@Format='text-xhtml'">
						<xsl:copy-of select="document(MetaData/Technical/Location)/xhtml:html/xhtml:body/*"/>
						<xsl:if test="$ILIAS='Yes'">
							<xsl:comment>Ende des Objekts &quot;<xsl:value-of select="MetaData/Technical/Location"/>&quot;!</xsl:comment>
						</xsl:if>
						<div>
							<xsl:choose>
								<xsl:when test="$ILIAS='Yes'">
									<xsl:attribute name="style">
										<xsl:text>font-family:verdana,arial,sans-serif; font-weight:bold; font-size:smaller;</xsl:text>
									</xsl:attribute>	
								</xsl:when>
								<xsl:otherwise>
									<xsl:attribute name="class">
										<xsl:text>Image</xsl:text>
									</xsl:attribute>
								</xsl:otherwise>
							</xsl:choose>
							<xsl:value-of select="MetaData/General/Title"/>
						</div>
						<div>
							<xsl:choose>
								<xsl:when test="$ILIAS='Yes'">
									<xsl:attribute name="style">
										<xsl:text>font-family:verdana,arial,sans-serif; font-size:smaller;</xsl:text>
									</xsl:attribute>	
								</xsl:when>
								<xsl:otherwise>
									<xsl:attribute name="class">
										<xsl:text>Imagetext</xsl:text>
									</xsl:attribute>
								</xsl:otherwise>
							</xsl:choose>
							<xsl:apply-templates select="MetaData/General/Description"/>
						</div>
					</xsl:when>		
					<xsl:otherwise>
						<div>
							<xsl:choose>
								<xsl:when test="$ILIAS='Yes'">
									<xsl:attribute name="style">
										<xsl:text>font-family:verdana,arial,sans-serif; font-weight:bold; font-size:smaller;</xsl:text>
									</xsl:attribute>	
								</xsl:when>
								<xsl:otherwise>
									<xsl:attribute name="class">
										<xsl:text>Image</xsl:text>
									</xsl:attribute>
								</xsl:otherwise>
							</xsl:choose>
							<a>
								<xsl:attribute name="href">
									<xsl:value-of select="MetaData/Technical/Location"/>
								</xsl:attribute>
								<xsl:apply-templates select="MetaData/General/Title"/>
							</a>
						</div>
						<div>
							<xsl:choose>
								<xsl:when test="$ILIAS='Yes'">
									<xsl:attribute name="style">
										<xsl:text>font-family:verdana,arial,sans-serif; font-size:smaller;</xsl:text>
									</xsl:attribute>	
								</xsl:when>
								<xsl:otherwise>
									<xsl:attribute name="class">
										<xsl:text>Imagetext</xsl:text>
									</xsl:attribute>
								</xsl:otherwise>
							</xsl:choose>
							<xsl:apply-templates select="MetaData/General/Description"/>
						</div>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
		</xsl:choose>
		<xsl:apply-templates/>
	</xsl:template>
	
	<xsl:template name="nav_level3">
		<table width="100%" class="Nav">
			<tr>
				<td style="width:33%" align="left">
					<xsl:choose>
						<xsl:when test="preceding-sibling::*[1][self::LearningObject]">
							<a class="NavItem">
								<xsl:attribute name="href">
									<xsl:value-of select="concat(string(preceding-sibling::*[1][self::LearningObject]/MetaData/General/Identifier/@Entry),'.xhtml')"/>
								</xsl:attribute>
								<xsl:text>&#171;</xsl:text>
							</a>
						</xsl:when>
					</xsl:choose>
				</td>
				<td style="width:33%" align="center">
					<xsl:choose>
						<xsl:when test="ancestor::LearningObject">
							<a class="NavItem">
								<xsl:attribute name="href">
									<xsl:value-of select="concat(string(ancestor::LearningObject[1]/MetaData/General/Identifier/@Entry),'.xhtml')"/>
								</xsl:attribute>
								<xsl:text>up</xsl:text>
							</a>
						</xsl:when>
					</xsl:choose>
				</td>
				<td style="width:33%" align="right">
					<xsl:choose>
						<xsl:when test="following-sibling::*[1][self::LearningObject]">
							<a class="NavItem">
								<xsl:attribute name="href">
									<xsl:value-of select="concat(string(Content/LearningObject[1]/MetaData/General/Identifier/@Entry),'.xhtml')"/>
								</xsl:attribute>
								<xsl:text>&#187;</xsl:text>
							</a>
						</xsl:when>
						<xsl:otherwise>
							<a class="NavItem">
								<xsl:attribute name="href">
									<xsl:value-of select="concat(string(Content/LearningObject[1]/MetaData/General/Identifier/@Entry),'.xhtml')"/>
								</xsl:attribute>
								<xsl:text>&#187;</xsl:text>
							</a>
						</xsl:otherwise>
					</xsl:choose>
				</td>
			</tr>
		</table>
	</xsl:template>
	
	<xsl:template name="nav_level2">
		<table width="100%" class="Nav">
			<tr>
				<td style="width:33%" align="left">
					<xsl:choose>
						<xsl:when test="preceding-sibling::*[1][self::LearningObject]">
							<a class="NavItem">
								<xsl:attribute name="href">
									<xsl:value-of select="concat(string(preceding-sibling::*[1][self::LearningObject]/MetaData/General/Identifier/@Entry),'.xhtml')"/>
								</xsl:attribute>
								<xsl:text>&#171;</xsl:text>
							</a>
						</xsl:when>
						<xsl:otherwise>
							<a class="NavItem">
								<xsl:attribute name="href">
									<xsl:value-of select="concat(string(ancestor::LearningObject[1]/MetaData/General/Identifier/@Entry),'.xhtml')"/>
								</xsl:attribute>
								<xsl:text>&#171;</xsl:text>
							</a>
						</xsl:otherwise>
					</xsl:choose>
				</td>
				<td style="width:33%" align="center">
					<xsl:choose>
						<xsl:when test="ancestor::LearningObject">
							<a class="NavItem">
								<xsl:attribute name="href">
									<xsl:value-of select="concat(string(ancestor::LearningObject[1]/MetaData/General/Identifier/@Entry),'.xhtml')"/>
								</xsl:attribute>
								<xsl:text>up</xsl:text>
							</a>
						</xsl:when>
					</xsl:choose>
				</td>
				<td style="width:33%" align="right">
					<xsl:choose>
						<xsl:when test="following-sibling::*[1][self::LearningObject]">
							<a class="NavItem">
								<xsl:attribute name="href">
									<xsl:value-of select="concat(string(following-sibling::LearningObject/MetaData/General/Identifier/@Entry),'.xhtml')"/>
								</xsl:attribute>
								<xsl:text>&#187;</xsl:text>
							</a>
						</xsl:when>
						<xsl:when test="following::LearningObject[MetaData/AggregationLevel>=2]">
							<a class="NavItem">
								<xsl:attribute name="href">
									<xsl:value-of select="concat(string(following::LearningObject[MetaData/General/@AggregationLevel>2]/MetaData/General/Identifier/@Entry),'.xhtml')"/>
								</xsl:attribute>
								<xsl:text>&#187;</xsl:text>
							</a>
						</xsl:when>
					</xsl:choose>
				</td>
			</tr>
		</table>
	</xsl:template>

	<xsl:template name="bilder">
		<table width="100%">
			<tr>
				<xsl:choose>
					<xsl:when test="(following-sibling::LearningObject[MetaData/General/@AggregationLevel='1'])[1]">
						<xsl:choose>
							<xsl:when test="LayoutInformation/@KeepWithPrevious='Yes' and not(LayoutInformation/@KeepWithNext='Yes')">
							</xsl:when>
							<xsl:when test="LayoutInformation/@KeepWithPrevious='Yes' and LayoutInformation/@KeepWithNext='Yes'">
							</xsl:when>
							<xsl:when test="LayoutInformation/@KeepWithNext='Yes' and not(LayoutInformation/@KeepWithPrevious='Yes')">
								<td>
									<xsl:if test="LayoutInformation/@HorizontalAlign">
										<xsl:attribute name="align">
											<xsl:value-of select="translate(string(LayoutInformation/@HorizontalAlign),'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz')"/>									
										</xsl:attribute>
									</xsl:if>
									<xsl:call-template name="bilder2"/>
								</td>
								<xsl:for-each select="following-sibling::LearningObject[MetaData/General/@AggregationLevel='1'][LayoutInformation/@KeepWithPrevious='Yes']">
									<td>
										<xsl:if test="LayoutInformation/@HorizontalAlign">
											<xsl:attribute name="align">
												<xsl:value-of select="translate(string(LayoutInformation/@HorizontalAlign),'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz')"/>									
											</xsl:attribute>
										</xsl:if>
										<xsl:call-template name="bilder2"/>
									</td>
								</xsl:for-each>
							</xsl:when>
							<xsl:otherwise>
								<td>
									<xsl:if test="LayoutInformation/@HorizontalAlign">
										<xsl:attribute name="align">
											<xsl:value-of select="translate(string(LayoutInformation/@HorizontalAlign),'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz')"/>									
										</xsl:attribute>
									</xsl:if>
									<xsl:call-template name="bilder2"/>
								</td>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<td>
							<xsl:if test="LayoutInformation/@HorizontalAlign">
								<xsl:attribute name="align">
									<xsl:value-of select="translate(string(LayoutInformation/@HorizontalAlign),'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz')"/>									
								</xsl:attribute>
							</xsl:if>
							<xsl:call-template name="bilder2"/>
						</td>
					</xsl:otherwise>
				</xsl:choose>
			</tr>
		</table>
	</xsl:template>

	<xsl:template name="bilder2">
		<xsl:choose>
			<xsl:when test="MetaData/Technical/@Format='application-x-shockwave-flash'">
				<object type="application/x-shockwave-flash">
					<xsl:attribute name="id">
						<xsl:value-of select="MetaData/General/Identifier/@Entry"/>
					</xsl:attribute>
					<xsl:attribute name="data">
						<xsl:value-of select="MetaData/Technical/Location"/>
					</xsl:attribute>
					<xsl:attribute name="width">
						<xsl:value-of select="LayoutInformation/@Width"/>
					</xsl:attribute>
					<xsl:attribute name="height">
						<xsl:value-of select="LayoutInformation/@Height"/>
					</xsl:attribute>
					<param name="movie">
						<xsl:attribute name="value">
							<xsl:value-of select="MetaData/Technical/Location"/>
						</xsl:attribute>
					</param>
					<div>Flash-Plugin erforderlich!</div>
				</object>					
			</xsl:when>
			<xsl:otherwise>
				<img>
					<xsl:attribute name="id">
						<xsl:value-of select="MetaData/General/Identifier/@Entry"/>
					</xsl:attribute>
					<xsl:attribute name="src">
						<xsl:value-of select="MetaData/Technical/Location"/>
					</xsl:attribute>
					<xsl:attribute name="alt">
						<xsl:value-of select="MetaData/General/Description"/>
					</xsl:attribute>
					<xsl:if test="LayoutInformation/@Width">
						<xsl:attribute name="width">
							<xsl:value-of select="LayoutInformation/@Width"/>
						</xsl:attribute>
					</xsl:if>
					<xsl:if test="LayoutInformation/@Height">
						<xsl:attribute name="height">
							<xsl:value-of select="LayoutInformation/@Height"/>
						</xsl:attribute>
					</xsl:if>
				</img>
			</xsl:otherwise>
		</xsl:choose>
		<div>
			<xsl:choose>
				<xsl:when test="$ILIAS='Yes'">
					<xsl:attribute name="style">
						<xsl:text>font-family:verdana,arial,sans-serif; font-weight:bold; font-size:smaller;</xsl:text>
					</xsl:attribute>	
				</xsl:when>
				<xsl:otherwise>
					<xsl:attribute name="class">
						<xsl:text>Image</xsl:text>
					</xsl:attribute>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:choose>
				<xsl:when test="MetaData/General/Language='de'">
					<xsl:text>Abbildung </xsl:text>
				</xsl:when>
				<xsl:otherwise>
					<xsl:text>Figure </xsl:text>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:number count="LearningObject[@Optional!='Yes']"/>
			<xsl:text>: </xsl:text>
			<xsl:apply-templates select="MetaData/General/Title"/>
		</div>
		<div>
			<xsl:choose>
				<xsl:when test="$ILIAS='Yes'">
					<xsl:attribute name="style">
						<xsl:text>font-family:verdana,arial,sans-serif; font-size:smaller;</xsl:text>
					</xsl:attribute>	
				</xsl:when>
				<xsl:otherwise>
					<xsl:attribute name="class">
						<xsl:text>Imagetext</xsl:text>
					</xsl:attribute>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:apply-templates select="MetaData/General/Description"/>
		</div>
	</xsl:template>

<!-- Template fuer die MetaDaten -->
<!-- In HTML verwendete MetaDaten wie Titel, Autor, Description und Keywords werden weitergerreicht -->
	<xsl:template match="MetaData">
		<xsl:for-each select="Lifecycle/Contribute/Entity">
			<xsl:choose>
				<xsl:when test="vCard">
					<xsl:variable name="vcard" select="concat(string(vCard/N/Given),'_',string(vCard/N/Family),'.vcf')"/>
					<xsl:result-document format="text" href="{$vcard}">
						begin:vcard
						n:<xsl:value-of select="vCard/N/Family"/><xsl:text>;</xsl:text><xsl:value-of select="vCard/N/Given"/>
						fn:<xsl:value-of select="vCard/FN"/>
						<xsl:if test="vCard/ORG">
							org:<xsl:value-of select="vCard/ORG/Orgname"/><xsl:text>;</xsl:text><xsl:value-of select="vCard/ORG/Orgunit"/>
						</xsl:if>
						<xsl:for-each select="vCard/ADR">
							adr;<xsl:value-of select="@TYPE"/>:;;<xsl:value-of select="Street"/>;<xsl:value-of select="Locality"/>;;<xsl:value-of select="Pcode"/>;<xsl:value-of select="Country"/>
						</xsl:for-each>
						<xsl:for-each select="vCard/TEL">
							tel;<xsl:value-of select="@TYPE"/>:<xsl:value-of select="."/>
						</xsl:for-each>
						<xsl:for-each select="vCard/EMAIL">
							email;<xsl:value-of select="@TYPE"/>:<xsl:value-of select="."/>
						</xsl:for-each>
						end:vcard
					</xsl:result-document>
					<xsl:if test="../@Role='Author'">
						<meta name="author">
							<xsl:attribute name="content">
								<xsl:value-of select="vCard/FN"/>
							</xsl:attribute>
						</meta>
					</xsl:if>
				</xsl:when>
				<xsl:otherwise>
					<xsl:if test="../@Role='Author'">
						<meta name="author">
							<xsl:attribute name="content">
								<xsl:value-of select="."/>
							</xsl:attribute>
						</meta>
					</xsl:if>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:for-each>
		<xsl:if test="General/@AggregationLevel>1">
			<meta name="description">
				<xsl:attribute name="content">
					<xsl:value-of select="General/Description"/>
				</xsl:attribute>
			</meta>
			<meta name="keywords">
				<xsl:attribute name="content">
					<xsl:for-each select="General/Keyword">
						<xsl:value-of select="."/>
						<xsl:if test="position()!=last()">
							<xsl:text>, </xsl:text>
						</xsl:if>
					</xsl:for-each>
				</xsl:attribute>
			</meta>
			<meta name="date">
				<xsl:attribute name="content">
					<xsl:value-of select="date:date-time()"/>
				</xsl:attribute>
			</meta>
			<title>
				<xsl:value-of select="General/Title"/>
			</title>
		</xsl:if>
	</xsl:template>

<!-- Template fuer den Inhalt -->
	<xsl:template match="Content">
		<xsl:apply-templates/>
	</xsl:template>

	<xsl:template match="Text">
		<xsl:apply-templates/>
	</xsl:template>

	<xsl:template match="Paragraph">
		<xsl:choose>
			<xsl:when test="$include-optional-paragraphs='No' and @Optional='Yes'">
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="@Characteristic='Headline'">
						<h3>
							<xsl:choose>
								<xsl:when test="$ILIAS='Yes'">
									<xsl:attribute name="style">
										<xsl:text>font-family:verdana,arial,sans-serif;</xsl:text>
									</xsl:attribute>
								</xsl:when>
								<xsl:otherwise>
									<xsl:attribute name="class">
										<xsl:text>Headline</xsl:text>
									</xsl:attribute>
								</xsl:otherwise>
							</xsl:choose>
							<xsl:apply-templates/>
						</h3>
					</xsl:when>
					<xsl:when test="@Characteristic='Mnemonic'">
						<div>
							<xsl:choose>
								<xsl:when test="$ILIAS='Yes'">
									<xsl:attribute name="style">
										<xsl:text>margin-left:20%; margin-right:20%; margin-top:15px; padding:10px; font-family:verdana,arial,sans-serif; font-weight:bold; background-color:#cccccc; border-style:solid; border-color:black; border-width:2;</xsl:text>
									</xsl:attribute>		
								</xsl:when>
								<xsl:otherwise>
									<xsl:attribute name="class">
										<xsl:text>Extract</xsl:text>
									</xsl:attribute>
								</xsl:otherwise>
							</xsl:choose>
							<xsl:choose>
								<xsl:when test="../../../MetaData/General/Language='de'">
									<xsl:text>Zusammenfassung:</xsl:text>
								</xsl:when>
								<xsl:otherwise>
									<xsl:text>Abstract:</xsl:text>
								</xsl:otherwise>
							</xsl:choose>
							<br/>
							<xsl:apply-templates/>
						</div>
					</xsl:when>
					<xsl:otherwise>
						<xsl:choose>
							<xsl:when test="name(..)='Definition'">
								<xsl:for-each select=".">
									<xsl:apply-templates/>
									<br/>
								</xsl:for-each>
							</xsl:when>
							<xsl:otherwise>
								<div>
									<xsl:choose>
										<xsl:when test="$ILIAS='Yes'">
											<xsl:attribute name="style">
												<xsl:text>font-family:verdana,arial,sans-serif; margin-bottom:12pt; margin-top:12pt;</xsl:text>
											</xsl:attribute>
										</xsl:when>
										<xsl:otherwise>
											<xsl:attribute name="class">
												<xsl:text>Paragraph</xsl:text>
											</xsl:attribute>
										</xsl:otherwise>
									</xsl:choose>
									<xsl:apply-templates/>
								</div>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template match="Link">
		<a target="_blank">
			<xsl:attribute name="href">
				<xsl:value-of select="@xlink:href"/>
			</xsl:attribute>
			<xsl:attribute name="title">
				<xsl:value-of select="@xlink:title"/>
				<xsl:if test="@Last_Visit">
					<xsl:choose>
						<xsl:when test="ancestor::LearningObject[1]/MetaData/General/Language='de'">
							<xsl:text> - Zuletzt besucht: </xsl:text>
							<xsl:value-of select="@Last_Visit"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:text> - Last visit: </xsl:text>
							<xsl:value-of select="@Last_Visit"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:if>
			</xsl:attribute>
			<xsl:apply-templates/>
		</a>
	</xsl:template>

<!-- Emph und Strong werden nach HTML durchgereicht -->
<!-- Je nach Grund der Hervorhebung wird eine CSS-Klasse genutzt -->
	<xsl:template match="Emph">
		<em>
			<xsl:choose>
				<xsl:when test="@Reason='Keyword'">
					<xsl:choose>
						<xsl:when test="$ILIAS='Yes'">
							<xsl:attribute name="style">
								<xsl:text>font-weight:bold</xsl:text>
							</xsl:attribute>
						</xsl:when>
						<xsl:otherwise>
							<xsl:attribute name="class">
								<xsl:text>Keyword</xsl:text>
							</xsl:attribute>
						</xsl:otherwise>
					</xsl:choose>
					<xsl:apply-templates/>
				</xsl:when>
				<xsl:when test="@Reason='Intuition'">
					<xsl:choose>
						<xsl:when test="$ILIAS='Yes'">
							<xsl:attribute name="style">
								<xsl:text>font-weight:italic</xsl:text>
							</xsl:attribute>
						</xsl:when>
						<xsl:otherwise>
							<xsl:attribute name="class">
								<xsl:text>Intuition</xsl:text>
							</xsl:attribute>
						</xsl:otherwise>
					</xsl:choose>
					<xsl:apply-templates/>
				</xsl:when>
				<xsl:when test="@Reason='MetaLanguageUse'">
					<xsl:choose>
						<xsl:when test="$ILIAS='Yes'">
							<xsl:attribute name="style">
								<xsl:text>font-style:italic</xsl:text>
							</xsl:attribute>	
						</xsl:when>
						<xsl:otherwise>
							<xsl:attribute name="class">
								<xsl:text>MetaLanguageUse</xsl:text>
							</xsl:attribute>
						</xsl:otherwise>
					</xsl:choose>
					<xsl:apply-templates/>
				</xsl:when>
				<xsl:when test="@Reason='Highlight'">
					<xsl:choose>
						<xsl:when test="$ILIAS='Yes'">
							<xsl:attribute name="style">
								<xsl:text>background-color:yellow;</xsl:text>
							</xsl:attribute>
						</xsl:when>
						<xsl:otherwise>
							<xsl:attribute name="class">
								<xsl:text>Highlight</xsl:text>
							</xsl:attribute>
						</xsl:otherwise>
					</xsl:choose>
					<xsl:apply-templates/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:apply-templates/>
				</xsl:otherwise>
			</xsl:choose>
		</em>
	</xsl:template>

	<xsl:template match="Strong">
		<strong>
			<xsl:choose>
				<xsl:when test="@Reason='Keyword'">
					<xsl:choose>
						<xsl:when test="$ILIAS='Yes'">
							<xsl:attribute name="style">
								<xsl:text>font-weight:bold</xsl:text>
							</xsl:attribute>
						</xsl:when>
						<xsl:otherwise>
							<xsl:attribute name="class">
								<xsl:text>Keyword</xsl:text>
							</xsl:attribute>
						</xsl:otherwise>
					</xsl:choose>
					<xsl:apply-templates/>
				</xsl:when>
				<xsl:when test="@Reason='Intuition'">
					<xsl:choose>
						<xsl:when test="$ILIAS='Yes'">
							<xsl:attribute name="style">
								<xsl:text>font-weight:italic</xsl:text>
							</xsl:attribute>
						</xsl:when>
						<xsl:otherwise>
							<xsl:attribute name="class">
								<xsl:text>Intuition</xsl:text>
							</xsl:attribute>
						</xsl:otherwise>
					</xsl:choose>
					<xsl:apply-templates/>
				</xsl:when>
				<xsl:when test="@Reason='MetaLanguageUse'">
					<xsl:choose>
						<xsl:when test="$ILIAS='Yes'">
							<xsl:attribute name="style">
								<xsl:text>font-style:italic</xsl:text>
							</xsl:attribute>
						</xsl:when>
						<xsl:otherwise>
							<xsl:attribute name="class">
								<xsl:text>MetaLanguageUse</xsl:text>
							</xsl:attribute>
						</xsl:otherwise>
					</xsl:choose>
					<xsl:apply-templates/>
				</xsl:when>
				<xsl:when test="@Reason='Highlight'">
					<xsl:choose>
						<xsl:when test="$ILIAS='Yes'">
							<xsl:attribute name="style">
								<xsl:text>background-color:yellow;</xsl:text>
							</xsl:attribute>
						</xsl:when>
						<xsl:otherwise>
							<xsl:attribute name="class">
								<xsl:text>Highlight</xsl:text>
							</xsl:attribute>
						</xsl:otherwise>
					</xsl:choose>
					<xsl:apply-templates/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:apply-templates/>
				</xsl:otherwise>
			</xsl:choose>
		</strong>
	</xsl:template>

<!-- Woertliche Zitate -->
<!-- Zitate werden in Anfuehrungszeichen gesetzt -->
<!-- Wenn es eine Referenz gibt, dann wird der Autor der Referenz genannt -->
<!-- Gibt es mehrere Autoren, werden sie durch Kommata getrennt -->
<!-- Anschliessend erfolgt die Nennung des Jahres und einer evtl. vorhandenen Seitenangabe -->
	<xsl:template match="Quotation">
		<xsl:choose>
			<xsl:when test="@Type='Block'">
				<blockquote>
					<xsl:text>"</xsl:text>
					<xsl:apply-templates/>
					<xsl:text>" </xsl:text>
					<xsl:if test="@Reference_to">
						<xsl:choose>
							<xsl:when test="$ILIAS='Yes'">
								<xsl:call-template name="Authors_and_Editors"/>
								<xsl:text>, </xsl:text>
								<xsl:apply-templates select="id(@Reference_to)/Year"/>
								<xsl:if test="@Page">
									<xsl:text>, S. </xsl:text>
									<xsl:apply-templates select="@Page"/>
								</xsl:if>
							</xsl:when>
							<xsl:otherwise>
								<a class="Reference">
									<xsl:attribute name="href">
										<xsl:value-of select="concat(string(id(@Reference_to)/../../MetaData/General/Identifier/@Entry),'-','bib','.xhtml','#',string(@Reference_to))"/>
									</xsl:attribute>
									<xsl:call-template name="Authors_and_Editors"/>
									<xsl:text>, </xsl:text>
									<xsl:apply-templates select="id(@Reference_to)/Year"/>
									<xsl:if test="@Page">
										<xsl:text>, S. </xsl:text>
										<xsl:apply-templates select="@Page"/>
									</xsl:if>
								</a>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:if>
				</blockquote>
			</xsl:when>
			<xsl:otherwise>
				<xsl:text>"</xsl:text><xsl:apply-templates/><xsl:text>" </xsl:text>
				<xsl:if test="@Reference_to">
					<xsl:choose>
						<xsl:when test="$ILIAS='Yes'">
							<xsl:text>[</xsl:text>
							<xsl:call-template name="Authors_and_Editors"/>
							<xsl:text>, </xsl:text>
							<xsl:apply-templates select="id(@Reference_to)/Year"/>
							<xsl:if test="@Page">
								<xsl:text>, S. </xsl:text>
								<xsl:apply-templates select="@Page"/>
							</xsl:if>
							<xsl:text>]</xsl:text>
						</xsl:when>
						<xsl:otherwise>
							<a class="Reference">
								<xsl:attribute name="href">
									<xsl:value-of select="concat(string(id(@Reference_to)/../../MetaData/General/Identifier/@Entry),'-','bib','.xhtml','#',string(@Reference_to))"/>
								</xsl:attribute>
								<xsl:text>[</xsl:text>
								<xsl:call-template name="Authors_and_Editors"/>
								<xsl:text>, </xsl:text>
								<xsl:apply-templates select="id(@Reference_to)/Year"/>
								<xsl:if test="@Page">
									<xsl:text>, S. </xsl:text>
									<xsl:apply-templates select="@Page"/>
								</xsl:if>
								<xsl:text>]</xsl:text>
							</a>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:if>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template match="Entity">
<!-- vCard oder PCDATA ? -->
		<xsl:choose>
			<xsl:when test="vCard">
				<xsl:variable name="vCard" select="concat(string(vCard/N),'.vcf')"/>
				<xsl:result-document format="text" href="{$vCard}">
					<xsl:copy-of select="."/>
				</xsl:result-document>
				<xsl:value-of select="vCard/FN"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:apply-templates/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template match="Code">
		<xsl:choose>
			<xsl:when test="@Display='Block'">
				<xsl:choose>
					<xsl:when test="@Id">
						<xsl:variable name="code" select="concat(string(@Id),'code','.txt')"/>
						<xsl:result-document format="text" href="{$code}">
							<xsl:copy-of select="."/>
						</xsl:result-document>
					</xsl:when>
					<xsl:otherwise>
						<xsl:variable name="code" select="concat(generate-id(),'code','.txt')"/>
						<xsl:result-document format="text" href="{$code}">
							<xsl:copy-of select="."/>
						</xsl:result-document>
					</xsl:otherwise>
				</xsl:choose>
				<div>
					<xsl:choose>
						<xsl:when test="$ILIAS='Yes'">
							<xsl:attribute name="style">
								<xsl:choose>
									<xsl:when test="../../../Example">
										<xsl:text>text-indent:4em; font-weight:bold; font-family:monospace; font-size:120%;</xsl:text>
									</xsl:when>
									<xsl:otherwise>
										<xsl:text>font-family:monospace; margin-bottom:15pt; padding:5px; padding-left:10px; background-color:#cccccc; margin-left:5pt; margin-right:5pt;</xsl:text>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:attribute>
						</xsl:when>
						<xsl:otherwise>
							<xsl:attribute name="class">
								<xsl:choose>
									<xsl:when test="../../../Example">
										<xsl:text>CodeExample</xsl:text>
									</xsl:when>
									<xsl:otherwise>
										<xsl:text>CodeBlock</xsl:text>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:attribute>
						</xsl:otherwise>
					</xsl:choose>
					<xsl:choose>
						<xsl:when test="CodeElem">
							<xsl:for-each select="CodeElem">
								<div>
									<xsl:choose>
										<xsl:when test="../@ProgrammingLanguage='XML' and ../@Pretty-Print='Yes'">
											<xsl:call-template name="pretty-print">
												<xsl:with-param name="input" select="."/>
											</xsl:call-template>
										</xsl:when>
										<xsl:otherwise>
											<xsl:value-of select="."/>
										</xsl:otherwise>
									</xsl:choose>
								</div>
							</xsl:for-each>
						</xsl:when>
						<xsl:otherwise>
							<div>
								<xsl:choose>
									<xsl:when test="$ILIAS='Yes'">
										<xsl:attribute name="style">
											<xsl:text>font-family:monospace; margin-bottom:15pt; padding:5px; padding-left:10px; background-color:#cccccc; margin-left:5pt; margin-right:5pt;</xsl:text>
										</xsl:attribute>
									</xsl:when>
									<xsl:otherwise>
										<xsl:attribute name="class">
											<xsl:text>CodeBlock</xsl:text>
										</xsl:attribute>
									</xsl:otherwise>
								</xsl:choose>
								<xsl:choose>
									<xsl:when test="@ProgrammingLanguage='XML' and @Pretty-Print='Yes'">
										<xsl:call-template name="pretty-print">
											<xsl:with-param name="input" select="."/>
										</xsl:call-template>
									</xsl:when>
									<xsl:otherwise>
										<xsl:value-of select="."/>
									</xsl:otherwise>
								</xsl:choose>
							</div>
						</xsl:otherwise>
					</xsl:choose>
				</div>
			</xsl:when>
			<xsl:otherwise>
				<span>
					<xsl:choose>
						<xsl:when test="$ILIAS='Yes'">
							<xsl:attribute name="style">
								<xsl:text>font-family:monospace; font-size:120%;</xsl:text>
							</xsl:attribute>
						</xsl:when>
						<xsl:otherwise>
							<xsl:attribute name="class">
								<xsl:text>Code</xsl:text>
							</xsl:attribute>
						</xsl:otherwise>
					</xsl:choose>
					<xsl:choose>
						<xsl:when test="@ProgrammingLanguage='XML' and @Pretty-Print='Yes'">
							<xsl:call-template name="pretty-print">
								<xsl:with-param name="input" select="."/>
							</xsl:call-template>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="."/>
						</xsl:otherwise>
					</xsl:choose>
				</span>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template match="List">
		<xsl:choose>
			<xsl:when test="@Type='Ordered'">
				<xsl:for-each select="Title">
					<br/>
					<xsl:apply-templates select="."/>
				</xsl:for-each>
				<ol>
					<xsl:if test="$ILIAS='Yes'">
						<xsl:attribute name="style">
							<xsl:text>font-family:verdana,arial,sans-serif;</xsl:text>
						</xsl:attribute>
					</xsl:if>
					<xsl:apply-templates select="Item"/>
				</ol>
			</xsl:when>
			<xsl:otherwise>
			<xsl:for-each select="Title">
				<br/>
				<xsl:apply-templates select="."/>
			</xsl:for-each>
			<ul>
				<xsl:if test="$ILIAS='Yes'">
					<xsl:attribute name="style">
						<xsl:text>font-family:verdana,arial,sans-serif;</xsl:text>
					</xsl:attribute>
				</xsl:if>
				<xsl:apply-templates select="Item"/>
			</ul>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template match="Item">
		<li>
			<xsl:for-each select="Paragraph">
				<xsl:apply-templates/>
				<xsl:if test="following-sibling::Paragraph">
					<br/>
				</xsl:if>
			</xsl:for-each>
		</li>
	</xsl:template>

	<xsl:template match="Formula">
		<xsl:choose>
			<xsl:when test="@Display='Block'">
				<div>
					<xsl:choose>
						<xsl:when test="$ILIAS='Yes'">
							<xsl:attribute name="style">
								<xsl:text>font-family: CMSY10,CMEX10,Symbol,Times; font-style:normal; font-size:14pt; color:blue; word-spacing:.2em; margin:20px; position:relative; padding:10px; white-space:nowrap;</xsl:text>
							</xsl:attribute>
						</xsl:when>
						<xsl:otherwise>
							<xsl:attribute name="class">
								<xsl:text>FormulaBlock</xsl:text>
							</xsl:attribute>
						</xsl:otherwise>
					</xsl:choose>
					<xsl:if test="@Id">
						<xsl:attribute name="id">
							<xsl:value-of select="@Id"/>
						</xsl:attribute>
					</xsl:if>
					<xsl:copy-of select="node()"/>
					<xsl:if test="@Id">
						<span>
							<xsl:choose>
								<xsl:when test="$ILIAS='Yes'">
									<xsl:attribute name="style">
										<xsl:text>margin-left:80%;</xsl:text>
									</xsl:attribute>
								</xsl:when>
								<xsl:otherwise>
									<xsl:attribute name="class">
										<xsl:text>Label</xsl:text>
									</xsl:attribute>
								</xsl:otherwise>
							</xsl:choose>
							<xsl:text>(</xsl:text>
							<xsl:choose>
								<xsl:when test="@Information_Link">
									<a target="_blank">
										<xsl:attribute name="href">
											<xsl:value-of select="@Information_Link"/>
										</xsl:attribute>
										<xsl:value-of select="@Id"/>
									</a>
								</xsl:when>
								<xsl:when test="@Information_Ref">
									<a>
										<xsl:attribute name="href">
											<xsl:value-of select="@Information_Ref"/>
										</xsl:attribute>
										<xsl:value-of select="@Id"/>
									</a>
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="@Id"/>
								</xsl:otherwise>
							</xsl:choose>
							<xsl:text>)</xsl:text>
						</span>
					</xsl:if>
				</div>
			</xsl:when>
			<xsl:otherwise>
				<span>
					<xsl:choose>
						<xsl:when test="$ILIAS='Yes'">
							<xsl:attribute name="style">
								<xsl:text>font-size:12pt; white-space: nowrap;</xsl:text>
							</xsl:attribute>
						</xsl:when>
						<xsl:otherwise>
							<xsl:attribute name="class">
								<xsl:text>Formula</xsl:text>
							</xsl:attribute>
						</xsl:otherwise>
					</xsl:choose>
					<xsl:if test="@Id">
						<xsl:attribute name="id">
							<xsl:value-of select="@Id"/>
						</xsl:attribute>
					</xsl:if>
					<xsl:copy-of select="node()"/>
				</span>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

<!-- Innerhalb eines LearningObjects werden die Tabellen automatisch durchnummeriert -->
<!-- Attribute werden nach HTML durchgereicht -->
	<xsl:template match="Table">
		<xsl:for-each select="Title">
			<xsl:value-of select="."/>
			<br/>
		</xsl:for-each>
		<table>
			<xsl:if test="@Id">
				<xsl:attribute name="id">
					<xsl:value-of select="@Id"/>
				</xsl:attribute>
			</xsl:if>
			<xsl:if test="@Width">
				<xsl:attribute name="width">
					<xsl:value-of select="@Width"/>
				</xsl:attribute>
			</xsl:if>
			<xsl:if test="@Height">
				<xsl:attribute name="height">
					<xsl:value-of select="@Height"/>
				</xsl:attribute>
			</xsl:if>
			<xsl:if test="@Border">
				<xsl:attribute name="border">
					<xsl:value-of select="@Border"/>
				</xsl:attribute>
			</xsl:if>
			<xsl:if test="Summary">
				<xsl:attribute name="summary">
					<xsl:value-of select="Summary"/>
				</xsl:attribute>
			</xsl:if>
			<xsl:if test="HeaderCaption">
				<caption align="top">
					<xsl:choose>
						<xsl:when test="../@Language='de'">
							<xsl:text>Tabelle </xsl:text>
						</xsl:when>
						<xsl:otherwise>
							<xsl:text>Table </xsl:text>
						</xsl:otherwise>
					</xsl:choose>
					<xsl:number count="Table"/>
					<xsl:text>: </xsl:text>
					<xsl:apply-templates select="HeaderCaption"/>
				</caption>
			</xsl:if>
			<xsl:if test="FooterCaption">
				<caption align="bottom">
					<xsl:apply-templates select="FooterCaption"/>
				</caption>
			</xsl:if>
			<xsl:for-each select="TableRow">
				<tr>
					<xsl:for-each select="TableData">
						<td>
							<xsl:apply-templates/>
						</td>
					</xsl:for-each>
				</tr>
			</xsl:for-each>
		</table>
	</xsl:template>

	<xsl:template match="Glossary">
		<xsl:variable name="gloss" select="concat(string(../MetaData/General/Identifier/@Entry),'-','gloss','.xhtml')"/>
		<xsl:result-document href="{$gloss}">
			<html>
				<head>
					<title>
						<xsl:choose>
							<xsl:when test="../MetaData/General/Language='de'">
								<xsl:value-of select="concat(string(../MetaData/General/Title),' - ','Glossar')"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="concat(string(../MetaData/General/Title),' - ','Glossary')"/>
							</xsl:otherwise>
						</xsl:choose>
					</title>
					<xsl:choose>
						<xsl:when test="$ILIAS='Yes'"/>
						<xsl:otherwise>
							<link type="text/css" rel="stylesheet">
								<xsl:attribute name="href">
									<xsl:value-of select="../LayoutInformation/@CSS-URL"/>
								</xsl:attribute>
							</link>
						</xsl:otherwise>
					</xsl:choose>
				</head>
				<body>
					<h1>
						<xsl:if test="$ILIAS='Yes'">
							<xsl:attribute name="style">
								<xsl:text>font-family:verdana,arial,sans-serif;</xsl:text>
							</xsl:attribute>
						</xsl:if>
						<xsl:choose>
							<xsl:when test="../MetaData/General/Language='de'">
								<xsl:text>Glossar</xsl:text>
							</xsl:when>
							<xsl:otherwise>
								<xsl:text>Glossary</xsl:text>
							</xsl:otherwise>
						</xsl:choose>
					</h1>
					<table width="90%">
						<xsl:if test="$ILIAS='Yes'">
							<xsl:attribute name="style">
								<xsl:text>font-family:verdana,arial,sans-serif;</xsl:text>
							</xsl:attribute>
						</xsl:if>
						<xsl:for-each select="GlossaryItem">
							<xsl:sort select="GlossaryTerm"/>
							<tr>
								<xsl:attribute name="id">
									<xsl:value-of select="GlossaryTerm/@Definition"/>
								</xsl:attribute>
								<xsl:for-each select="GlossaryTerm">
									<td valign="top">
										<span>
											<xsl:choose>
												<xsl:when test="$ILIAS='Yes'">
													<xsl:attribute name="style">
														<xsl:text>color:black; font-weight:bold;</xsl:text>
													</xsl:attribute>
												</xsl:when>
												<xsl:otherwise>
													<xsl:attribute name="class">
														<xsl:text>GlossaryEntry</xsl:text>
													</xsl:attribute>
												</xsl:otherwise>
											</xsl:choose>
											<xsl:value-of select="."/>
										</span>
									</td>
								</xsl:for-each>
								<xsl:for-each select="DefinitionList">
									<td valign="top">
										<xsl:for-each select="Definition">
											<xsl:apply-templates/>
										</xsl:for-each>
									</td>
								</xsl:for-each>
								<xsl:for-each select="Definition">
									<td valign="top">
										<xsl:apply-templates select="."/>
									</td>
								</xsl:for-each>
							</tr>
						</xsl:for-each>
					</table>
				</body>
			</html>
		</xsl:result-document>
	</xsl:template>

	<xsl:template match="GlossaryTerm">
		<a>
			<xsl:choose>
				<xsl:when test="$ILIAS='Yes'">
					<xsl:attribute name="style">
						<xsl:text>color:red; text-decoration:none;</xsl:text>
					</xsl:attribute>
				</xsl:when>
				<xsl:otherwise>
					<xsl:attribute name="class">
						<xsl:text>GlossaryTerm</xsl:text>
					</xsl:attribute>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:attribute name="href">
				<xsl:value-of select="concat(string(id(@Definition)/ancestor::LearningObject[1]/MetaData/General/Identifier/@Entry),'-','gloss','.xhtml','#',string(@Definition))"/>
			</xsl:attribute>
			<sup>&#8599;</sup>
		</a>
		<acronym>
			<xsl:attribute name="title">
				<xsl:value-of select="id(@Definition)/."/>
			</xsl:attribute>
			<xsl:apply-templates/>
		</acronym>
	</xsl:template>

	<xsl:template match="Definition">
		<xsl:apply-templates/>
	</xsl:template>

	<xsl:template match="Reference">
		<xsl:choose>
			<xsl:when test="@Type='BibliographyEntry'">
				<xsl:choose>
					<xsl:when test="$ILIAS='Yes'">
						<xsl:call-template name="Authors_and_Editors"/>
						<xsl:if test="id(@Reference_to)/Year">
							<xsl:text>, </xsl:text>
							<xsl:apply-templates select="id(@Reference_to)/Year"/>
						</xsl:if>
						<xsl:if test="@Page">
							<xsl:text>, S. </xsl:text>
							<xsl:apply-templates select="@Page"/>
						</xsl:if>
					</xsl:when>
					<xsl:otherwise>
						<a class="Reference">
							<xsl:attribute name="href">
								<xsl:value-of select="concat(string(id(@Reference_to)/ancestor::LearningObject[1]/MetaData/General/Identifier/@Entry),'-','bib','.xhtml','#',string(@Reference_to))"/>
							</xsl:attribute>
							<xsl:call-template name="Authors_and_Editors"/>
							<xsl:if test="id(@Reference_to)/Year">
								<xsl:text>, </xsl:text>
								<xsl:apply-templates select="id(@Reference_to)/Year"/>
							</xsl:if>
							<xsl:if test="@Page">
								<xsl:text>, S. </xsl:text>
								<xsl:apply-templates select="@Page"/>
							</xsl:if>
						</a>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:when test="@Type='LearningObject'">
<!-- Verzweigung: Je nach AggregationLevel wird anders verfahren -->
				<xsl:choose>
					<xsl:when test="id(@Reference_to)/../@AggregationLevel='1' and id(@Reference_to)/../../../@Optional!='Yes'">
<!-- Level 1-LearningObjects -->
<!-- Erster Schritt: Level 1-LO, auf die verwiesen wird, erhalten eine eigene XHTML-Datei -->
						<xsl:variable name="LO1" select="concat(string(@Reference_to),'.xhtml')"/>
						<xsl:result-document href="{$LO1}">
							<html>
								<head>
									<title>
										<xsl:value-of select="id(@Reference_to)/../Title"/>
									</title>
									<xsl:choose>
										<xsl:when test="$ILIAS='Yes'"/>
										<xsl:otherwise>
											<link type="text/css" rel="stylesheet">
												<xsl:attribute name="href">
													<xsl:choose>
														<xsl:when test="id(@Reference_to)/../../../LayoutInformation/@CSS-URL">
															<xsl:value-of select="id(@Reference_to)/../../../LayoutInformation/@CSS-URL"/>
														</xsl:when>
														<xsl:otherwise>
															<xsl:value-of select="ancestor::LearningObject[1]/LayoutInformation/@CSS-URL"/>
														</xsl:otherwise>
													</xsl:choose>
												</xsl:attribute>
											</link>
										</xsl:otherwise>
									</xsl:choose>
								</head>
								<body>
<!-- Hier muss unterschieden werden - je nach Dateiformat kann img oder a gewaehlt werden -->
									<xsl:choose>
										<xsl:when test="id(@Reference_to)/../../Technical/@Format='image-gif' or id(@Reference_to)/../../Technical/@Format='image-jpeg' or id(@Reference_to)/../../Technical/@Format='image-png'">
<!-- Einbinden der LOs, die GIF/PNG/JPEG-Grafiken sind - per img-Tag -->
											<img>
												<xsl:attribute name="src">
													<xsl:value-of select="id(@Reference_to)/../../Technical/Location"/>
												</xsl:attribute>
											</img>
										</xsl:when>
										<xsl:when test="id(@Reference_to)/../../Technical/@Format='application-x-shockwave-flash'">
<!-- Einbinden von Flash -->									
											<object type="application/x-shockwave-flash">
												<xsl:attribute name="data">
													<xsl:value-of select="id(@Reference_to)/../../Technical/Location"/>
												</xsl:attribute>
												<xsl:attribute name="width">
													<xsl:value-of select="id(@Reference_to)/../../../LayoutInformation/@Width"/>
												</xsl:attribute>
												<xsl:attribute name="height">
													<xsl:value-of select="id(@Reference_to)/../../../LayoutInformation/@Height"/>
												</xsl:attribute>
												<param name="movie">
													<xsl:attribute name="value">
														<xsl:value-of select="id(@Reference_to)/../../Technical/Location"/>
													</xsl:attribute>
												</param>
												<div>Flash-Plugin erforderlich!</div>
											</object>
										</xsl:when>
										<xsl:when test="id(@Reference_to)/../../Technical/@Format='image-svg-xml'">
<!-- Einbinden der LOs, die SVG-Grafiken sind - hier durch Kopie des entsprechenden Knotens (bei SVG-enabled Browsern) -->
											<xsl:copy-of select="document(id(@Reference_to)/../../Technical/Location)/*"/>
										</xsl:when>
										<xsl:otherwise>
<!-- LOs, die keine Grafiken sind, werden per a eingebunden - wenig sinnvoll - es wird eine Seite erzeugt, auf der ein Link ist -->										
											<a>
												<xsl:choose>
													<xsl:when test="$ILIAS='Yes'">
														<xsl:attribute name="style">
															<xsl:text>font-family:verdana,arial,sans-serif; font-weight:bold; font-size:smaller;</xsl:text>
														</xsl:attribute>
													</xsl:when>
													<xsl:otherwise>
														<xsl:attribute name="class">
															<xsl:text>Image</xsl:text>
														</xsl:attribute>
													</xsl:otherwise>
												</xsl:choose>
												<xsl:attribute name="href">
													<xsl:value-of select="id(@Reference_to)/../../Technical/Location"/>
												</xsl:attribute>
												<xsl:value-of select="id(@Reference_to)/../Title"/>
											</a>
										</xsl:otherwise>
									</xsl:choose>
<!-- Ausgabe des Titels und der Description -->
									<div>
										<xsl:choose>
											<xsl:when test="$ILIAS='Yes'">
												<xsl:attribute name="style">
													<xsl:text>font-family:verdana,arial,sans-serif; font-weight:bold; font-size:smaller;</xsl:text>
												</xsl:attribute>
											</xsl:when>
											<xsl:otherwise>
												<xsl:attribute name="class">
													<xsl:text>Image</xsl:text>
												</xsl:attribute>
											</xsl:otherwise>
										</xsl:choose>
										<xsl:choose>
											<xsl:when test="id(@Reference_to)/../Language='de'">
												<xsl:text>Abbildung </xsl:text>
											</xsl:when>
											<xsl:otherwise>
												<xsl:text>Figure </xsl:text>
											</xsl:otherwise>
										</xsl:choose>
										<xsl:number count="LearningObject[@Optional!='Yes']"/>
										<xsl:text>: </xsl:text>
										<xsl:apply-templates select="id(@Reference_to)/../Title"/>
									</div>
									<div>
										<xsl:choose>
											<xsl:when test="$ILIAS='Yes'">
												<xsl:attribute name="style">
													<xsl:text>font-family:verdana,arial,sans-serif; font-size:smaller;</xsl:text>
												</xsl:attribute>
											</xsl:when>
											<xsl:otherwise>
												<xsl:attribute name="class">
													<xsl:text>Imagetext</xsl:text>
												</xsl:attribute>
											</xsl:otherwise>
										</xsl:choose>
										<xsl:apply-templates select="id(@Reference_to)/../Description"/>
									</div>
								</body>
							</html>
						</xsl:result-document>
<!-- Zweiter Schritt: Einbau der Referenz auf die soeben erzeugte XHTML-Datei -->
						<xsl:choose>
							<xsl:when test="id(@Reference_to)/../../Technical/@Format='image-gif'">
<!-- Einfuegen der Typ-Grafik entsprechend des Multimedia-Objekts -->
								<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" width="40px" height="40px">
									<rect id="quadrat" stroke="black" fill="none" y="5px" x="5px" width="30px" height="30px" stroke-width="2px"/>
									<text y="23px" x="10px" style="font-size:10pt">GIF</text>
								</svg>
								<a>
									<xsl:choose>
										<xsl:when test="ancestor::LearningObject[MetaData/General/@AggregationLevel='2']/MetaData/General/Identifier/@Entry = id(@Reference_to)/ancestor::LearningObject[MetaData/General/@AggregationLevel='2']/MetaData/General/Identifier/@Entry"><!-- LO und Referenz auf LO haben den gleichen direkten ancestor -->
											<xsl:attribute name="href">
												<xsl:value-of select="concat('#',@Reference_to)"/>
											</xsl:attribute> 
										</xsl:when>
										<xsl:otherwise>
											<xsl:attribute name="target">
												<xsl:text>_blank</xsl:text>
											</xsl:attribute>
											<xsl:attribute name="href">
												<xsl:value-of select="concat(string(@Reference_to),'.xhtml')"/>
											</xsl:attribute>
										</xsl:otherwise>
									</xsl:choose>
									<xsl:text>&#187; </xsl:text>
									<xsl:value-of select="id(@Reference_to)/../Title"/>
								</a>
							</xsl:when>
							<xsl:when test="id(@Reference_to)/../../Technical/@Format='image-jpeg'">
								<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" width="40px" height="40px">
									<rect id="quadrat" stroke="black" fill="none" y="5px" x="5px" width="30px" height="30px" stroke-width="2px"/>
									<text y="23px" x="9px" style="font-size:10pt">JPG</text>
								</svg>
								<a>
									<xsl:choose>
										<xsl:when test="ancestor::LearningObject[MetaData/General/@AggregationLevel='2']/MetaData/General/Identifier/@Entry = id(@Reference_to)/ancestor::LearningObject[MetaData/General/@AggregationLevel='2']/MetaData/General/Identifier/@Entry"><!-- LO und Referenz auf LO haben den gleichen direkten ancestor -->
											<xsl:attribute name="href">
												<xsl:value-of select="concat('#',@Reference_to)"/>
											</xsl:attribute> 
										</xsl:when>
										<xsl:otherwise>
											<xsl:attribute name="target">
												<xsl:text>_blank</xsl:text>
											</xsl:attribute>
											<xsl:attribute name="href">
												<xsl:value-of select="concat(string(@Reference_to),'.xhtml')"/>
											</xsl:attribute>
										</xsl:otherwise>
									</xsl:choose>
									<xsl:text>&#187; </xsl:text>
									<xsl:value-of select="id(@Reference_to)/../Title"/>
								</a>
							</xsl:when>
							<xsl:when test="id(@Reference_to)/../../Technical/@Format='image-png'">
								<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" width="40px" height="40px">
									<rect id="quadrat" stroke="black" fill="none" y="5px" x="5px" width="30px" height="30px" stroke-width="2px"/>
									<text y="23px" x="10px" style="font-size:10pt">PNG</text>
								</svg>
								<a>
									<xsl:choose>
										<xsl:when test="ancestor::LearningObject[MetaData/General/@AggregationLevel='2']/MetaData/General/Identifier/@Entry = id(@Reference_to)/ancestor::LearningObject[MetaData/General/@AggregationLevel='2']/MetaData/General/Identifier/@Entry"><!-- LO und Referenz auf LO haben den gleichen direkten ancestor -->
											<xsl:attribute name="href">
												<xsl:value-of select="concat('#',@Reference_to)"/>
											</xsl:attribute> 
										</xsl:when>
										<xsl:otherwise>
											<xsl:attribute name="target">
												<xsl:text>_blank</xsl:text>
											</xsl:attribute>
											<xsl:attribute name="href">
												<xsl:value-of select="concat(string(@Reference_to),'.xhtml')"/>
											</xsl:attribute>
										</xsl:otherwise>
									</xsl:choose>
									<xsl:text>&#187; </xsl:text>
									<xsl:value-of select="id(@Reference_to)/../Title"/>
								</a>
							</xsl:when>
							<xsl:when test="contains(string(id(@Reference_to)/../../Technical/@Format),'audio')">
								<svg xmlns="http://www.w3.org/2000/svg" width="40px" height="40px">
									<desc>Audio</desc>
									<rect id="quadrat" stroke="rgb(0,0,0)" fill="none" y="5px" x="5px" width="30px"	height="30px" stroke-width="2px"/>
									<line id="querbalken" fill="none" stroke="rgb(0,0,0)" stroke-width="4" x1="11" y1="16" x2="27" y2="11" transform="translate(0 -1) translate(0 -1) translate(1 0) translate(0 -1) translate(1 0) translate(0 1) translate(1 0) translate(1 0) translate(-1 0) translate(0 -1) translate(0 1) translate(1 0)"/>
									<line id="rechter_balken" fill="none" stroke="rgb(0,0,0)" stroke-width="2" x1="27" y1="9" x2="27" y2="30"	transform="translate(0 -1) translate(0 -1) translate(1 0) translate(0 -1) translate(1 0) translate(0 1) translate(27 9) scale(1 0.8779) translate(-27 -9) translate(1 0) translate(1 0) translate(-1 0) translate(0 -1.13908) translate(0 1.13908) translate(1 0)"/>
									<line id="linker_balken" fill="none" stroke="rgb(0,0,0)" stroke-width="2"	x1="20" y1="10" x2="20" y2="31"	transform="translate(-8.97436 3.84615) translate(20 20.5) scale(1 1) translate(-20 -20.5) translate(1 0) translate(1 0) translate(1 0) translate(0 -1) translate(0 -1) translate(-1 0) translate(20 10) scale(1 0.8372) translate(-20 -10) translate(20 20.5) scale(1 1) translate(-20 -20.5) translate(20 31) scale(1 0.927078) translate(-20 -31) translate(20 20.5) scale(1 1) translate(-20 -20.5) translate(1 0) translate(20 20.5) scale(1 1) translate(-20 -20.5) translate(-1 0) translate(0 -1.28841) translate(1 0) translate(1 0) translate(-1 0) translate(0 -1.28841) translate(0 1.28841) translate(1 0)"/>
									<ellipse id="ellipse_rechts" fill="rgb(0,0,0)" stroke="rgb(0,0,0)" stroke-width="1" cx="27" cy="29.5" rx="4" ry="2.5"	transform="translate(0 -1) translate(0 -1) translate(-1 0) translate(0 -1) translate(0 -1) translate(-1 0) translate(0 -1) translate(1 0) translate(1 0) translate(-1 0) translate(0 -1) translate(0 1) translate(1 0) translate(0 1) translate(1 0) translate(-1 0) translate(0 -1) translate(0 1) translate(1 0)"/>
									<ellipse id="ellipse_links" fill="rgb(0,0,0)" stroke="rgb(0,0,0)"	stroke-width="1" cx="27" cy="29.5" rx="4" ry="2.5" transform="matrix(1 0 0 1 -7 -9) translate(0 1) translate(0 1) translate(0 1) translate(0 1) translate(0 1) translate(0 1) translate(0 1) translate(0 1) translate(-1 0) translate(-1 0) translate(-1 0) translate(-1 0) translate(-1 0) translate(-1 0) translate(-1 0) translate(-1 0) translate(-1 0) translate(-1 0) translate(1 0) translate(0 -1) translate(-1 0) translate(0 1) translate(1 0) translate(0 -1) translate(1 0)"/>
								</svg>
							</xsl:when>
<!-- Flash -->
							<xsl:when test="id(@Reference_to)/../../Technical/@Format='application-x-shockwave-flash'">
								<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" width="40px" height="40px">
									<rect id="quadrat" stroke="black" fill="none" y="5px" x="5px" width="30px" height="30px" stroke-width="2px"/>
									<text y="23px" x="10px" style="font-size:10pt">SWF</text>
								</svg>
								<a>
									<xsl:choose>
										<xsl:when test="ancestor::LearningObject[MetaData/General/@AggregationLevel='2']/MetaData/General/Identifier/@Entry = id(@Reference_to)/ancestor::LearningObject[MetaData/General/@AggregationLevel='2']/MetaData/General/Identifier/@Entry"><!-- LO und Referenz auf LO haben den gleichen direkten ancestor -->
											<xsl:attribute name="href">
												<xsl:value-of select="concat('#',@Reference_to)"/>
											</xsl:attribute> 
										</xsl:when>
										<xsl:otherwise>
											<xsl:attribute name="target">
												<xsl:text>_blank</xsl:text>
											</xsl:attribute>
											<xsl:attribute name="href">
												<xsl:value-of select="concat(string(@Reference_to),'.xhtml')"/>
											</xsl:attribute>
										</xsl:otherwise>
									</xsl:choose>
									<xsl:text>&#187; </xsl:text>
									<xsl:value-of select="id(@Reference_to)/../Title"/>
								</a>
							</xsl:when>
							<xsl:otherwise>
<!-- Behandlung von Level 1 LOs, die nicht Grafik sind -->
								<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" width="40px" height="40px">
									<rect id="quadrat" stroke="black" fill="none" y="5px" x="5px" width="30px" height="30px" stroke-width="2px"/>
									<text y="23px" x="10px" style="font-size:10pt">???</text>
								</svg>
								<a>
									<xsl:choose>
										<xsl:when test="ancestor::LearningObject[MetaData/General/@AggregationLevel='2']/MetaData/General/Identifier/@Entry = id(@Reference_to)/ancestor::LearningObject[MetaData/General/@AggregationLevel='2']/MetaData/General/Identifier/@Entry"><!-- LO und Referenz auf LO haben den gleichen direkten ancestor -->
											<xsl:attribute name="href">
												<xsl:value-of select="concat('#',@Reference_to)"/>
											</xsl:attribute> 
										</xsl:when>
										<xsl:otherwise>
											<xsl:attribute name="target">
												<xsl:text>_blank</xsl:text>
											</xsl:attribute>
											<xsl:attribute name="href">
												<xsl:value-of select="concat(string(@Reference_to),'.xhtml')"/>
											</xsl:attribute>
										</xsl:otherwise>
									</xsl:choose>
									<xsl:text>&#187; </xsl:text>
									<xsl:value-of select="id(@Reference_to)/../Title"/>
								</a>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:when>
					<xsl:when test="id(@Reference_to)/../@AggregationLevel='1' and id(@Reference_to)/../../../@Optional='Yes'">
<!-- Referenzen auf optionale Level 1 LOs werden nicht erzeugt -->										
					</xsl:when>
<!-- Ende von Behandlung von Level 1 LOs -->
					<xsl:otherwise>
<!-- Level 2 oder 3 LOs, auf die referenziert wird -->
						<xsl:choose>
							<xsl:when test="id(@Reference_to)/../../../@Optional!='Yes'">
								<a>
									<xsl:attribute name="href">
										<xsl:value-of select="concat(string(@Reference_to),'.xhtml')"/>
									</xsl:attribute>
									<xsl:text>&#187; </xsl:text>
									<xsl:value-of select="id(@Reference_to)/../Title"/>
								</a>
							</xsl:when>
							<xsl:otherwise>
								<xsl:text>&#187; </xsl:text>
								<xsl:value-of select="id(@Reference_to)/../Title"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:otherwise>
<!-- Ende von Behandlung von Level 2 oder 3 LOs -->
				</xsl:choose>
			</xsl:when>
<!-- Ende der Verarbeitung von LearningObjects -->
			<xsl:when test="@Type='Example' or @Type='Exercise'">
				<a>
					<xsl:choose>
						<xsl:when test="$ILIAS='Yes'">
							<xsl:attribute name="style">
								<xsl:text>font-style:italic</xsl:text>
							</xsl:attribute>
						</xsl:when>
						<xsl:otherwise>
							<xsl:attribute name="class">
								<xsl:text>Reference</xsl:text>
							</xsl:attribute>
						</xsl:otherwise>
					</xsl:choose>
					<xsl:attribute name="href">
						<xsl:value-of select="concat(string(id(@Reference_to)/ancestor::LearningObject[1]/MetaData/General/Identifier/@Entry),'.xhtml','#',string(@Reference_to))"/>
					</xsl:attribute>
					<xsl:text>&#187; </xsl:text>
					<xsl:choose>
						<xsl:when test="../@Language='de'">
							<xsl:text>Beispiel</xsl:text>
						</xsl:when>
						<xsl:otherwise>
							<xsl:text>Example</xsl:text>
						</xsl:otherwise>
					</xsl:choose>
					<xsl:text>: </xsl:text>
					<xsl:value-of select="translate(@Reference_to,'_',' ')"/>
					<xsl:apply-templates/>
				</a>
			</xsl:when>
			<xsl:otherwise>
<!-- Referenz auf eine Stelle im Text -->
				<a>
					<xsl:choose>
						<xsl:when test="$ILIAS='Yes'">
							<xsl:attribute name="style">
								<xsl:text>font-style:italic</xsl:text>
							</xsl:attribute>
						</xsl:when>
						<xsl:otherwise>
							<xsl:attribute name="class">
								<xsl:text>Reference</xsl:text>
							</xsl:attribute>
						</xsl:otherwise>
					</xsl:choose>
					<xsl:attribute name="href">
						<xsl:value-of select="concat(string(id(@Reference_to)/ancestor::LearningObject[1]/MetaData/General/Identifier/@Entry),'.xhtml','#',string(@Reference_to))"/>
					</xsl:attribute>
					<xsl:text>&#187; </xsl:text>
					<xsl:value-of select="id(@Reference_to)"/>
					<xsl:apply-templates/>
				</a>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template match="RefTarget">
		<span>
		<xsl:attribute name="id">
			<xsl:value-of select="@Id"/>
		</xsl:attribute>
		<xsl:apply-templates/>
		</span>
	</xsl:template>

	<xsl:template match="Examples">
		<div>
			<xsl:choose>
				<xsl:when test="$ILIAS='Yes'">
					<xsl:attribute name="style">
						<xsl:text>font-family:verdana,arial,sans-serif; margin-bottom:12pt; margin-top:12pt;</xsl:text>
					</xsl:attribute>
				</xsl:when>
				<xsl:otherwise>
					<xsl:attribute name="class">
						<xsl:text>Paragraph</xsl:text>
					</xsl:attribute>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:apply-templates/>
		</div>
	</xsl:template>

	<xsl:template match="Example">
		<div>
			<xsl:choose>
				<xsl:when test="$ILIAS='Yes'">
					<xsl:attribute name="style">
						<xsl:text>text-indent:3em; font-weight:bold; margin:15pt; margin-bottom:12pt; margin-top:12pt;</xsl:text>
					</xsl:attribute>
				</xsl:when>
				<xsl:otherwise>
					<xsl:attribute name="class">
						<xsl:text>Example</xsl:text>
					</xsl:attribute>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:attribute name="id">
				<xsl:value-of select="@Id"/>
			</xsl:attribute>
			<xsl:choose>
				<xsl:when test="//MetaData/General/Language='de'">
					<xsl:text>Beispiel </xsl:text>
				</xsl:when>
				<xsl:otherwise>
					<xsl:text>Example</xsl:text>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:number count="Example" level="any"/>
			<xsl:text>: </xsl:text>
			<xsl:value-of select="translate(@Id,'_',' ')"/>
			<xsl:text> </xsl:text>
		</div>
		<xsl:apply-templates/>
	</xsl:template>
	
	<xsl:template match="Example/*">
		<div>
			<xsl:choose>
				<xsl:when test="$ILIAS='Yes'">
					<xsl:attribute name="style">
						<xsl:text>text-indent:4em; font-weight:bold;</xsl:text>
					</xsl:attribute>
				</xsl:when>
				<xsl:otherwise>
					<xsl:attribute name="class">
						<xsl:text>ExampleText</xsl:text>
					</xsl:attribute>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:choose>
				<xsl:when test="../@Status='Ill-formed'">
					<xsl:text>* </xsl:text>
				</xsl:when>
				<xsl:when test="../@Status='Questionable'">
					<xsl:text>? </xsl:text>
				</xsl:when>
			</xsl:choose>
			<xsl:apply-templates/>
		</div>
	</xsl:template>

	<xsl:template match="Gloss">
		<span>
			<xsl:choose>
				<xsl:when test="$ILIAS='Yes'">
					<xsl:attribute name="style">
						<xsl:text>text-indent:3em;</xsl:text>
					</xsl:attribute>
				</xsl:when>
				<xsl:otherwise>
					<xsl:attribute name="class">
						<xsl:text>Indent</xsl:text>
					</xsl:attribute>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:apply-templates/>
		</span>
	</xsl:template>

	<xsl:template match="Formalisation">
		<span>
			<xsl:choose>
				<xsl:when test="$ILIAS='Yes'">
					<xsl:attribute name="style">
						<xsl:text>text-indent:3em;</xsl:text>
					</xsl:attribute>
				</xsl:when>
				<xsl:otherwise>
					<xsl:attribute name="class">
						<xsl:text>Indent</xsl:text>
					</xsl:attribute>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:apply-templates/>
		</span>
	</xsl:template>

	<xsl:template match="Transcription">
		<span>
			<xsl:choose>
				<xsl:when test="$ILIAS='Yes'">
					<xsl:attribute name="style">
						<xsl:text>text-indent:3em;</xsl:text>
					</xsl:attribute>
				</xsl:when>
				<xsl:otherwise>
					<xsl:attribute name="class">
						<xsl:text>Indent</xsl:text>
					</xsl:attribute>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:apply-templates/>
		</span>
	</xsl:template>

	<xsl:template match="Translation">
		<span>
			<xsl:choose>
				<xsl:when test="$ILIAS='Yes'">
					<xsl:attribute name="style">
						<xsl:text>text-indent:3em;</xsl:text>
					</xsl:attribute>
				</xsl:when>
				<xsl:otherwise>
					<xsl:attribute name="class">
						<xsl:text>Indent</xsl:text>
					</xsl:attribute>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:apply-templates/>
		</span>
	</xsl:template>
	
	<xsl:template match="Mention">
		<span>
			<xsl:choose>
				<xsl:when test="$ILIAS='Yes'">
					<xsl:attribute name="style">
						<xsl:text>font-style:italic;</xsl:text>
					</xsl:attribute>
					&quot;<xsl:apply-templates/>&quot;
				</xsl:when>
				<xsl:otherwise>
					<xsl:attribute name="class">
						<xsl:text>Mention</xsl:text>
					</xsl:attribute>
					<xsl:apply-templates/>
				</xsl:otherwise>
			</xsl:choose>
		</span>
	</xsl:template>
	
	<xsl:template match="Exercises">
		<div>
			<xsl:choose>
				<xsl:when test="$ILIAS='Yes'">
					<xsl:attribute name="style">
						<xsl:text>font-family:verdana,arial,sans-serif; background-color:#cccccc; margin-left:5pt; margin-right:5pt; border-style:solid; border-width:2pt; border-color:#808080; padding:5pt; padding-left:10pt;</xsl:text>
					</xsl:attribute>
				</xsl:when>
				<xsl:otherwise>
					<xsl:attribute name="class">
						<xsl:text>Exercise</xsl:text>
					</xsl:attribute>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:apply-templates/>
		</div>
	</xsl:template>

	<xsl:template match="Exercise">
		<xsl:variable name="ex" select="concat(string(ancestor::LearningObject[1]/MetaData/General/Identifier/@Entry),'-',generate-id(),'exercise','.xhtml')"/>
		<div>
			<xsl:if test="@Id">
				<xsl:attribute name="id">
					<xsl:value-of select="@Id"/>
				</xsl:attribute>
			</xsl:if>
			<xsl:choose>
				<xsl:when test="name(..)='Exercises'"/>
				<xsl:otherwise>
					<xsl:choose>
						<xsl:when test="$ILIAS='Yes'">
							<xsl:attribute name="style">
								<xsl:text>font-family:verdana,arial,sans-serif; background-color:#cccccc; margin-left:5pt; margin-right:5pt; border-style:solid; border-width:2pt; border-color:#808080; padding:5pt; padding-left:10pt;</xsl:text>
							</xsl:attribute>
						</xsl:when>
						<xsl:otherwise>
							<xsl:attribute name="class">
								<xsl:text>Exercise</xsl:text>
							</xsl:attribute>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:apply-templates select="ExerciseText"/>
			<xsl:if test="Solution">
				<div>
					<xsl:choose>
						<xsl:when test="$ILIAS='Yes'">
							<xsl:attribute name="style">
								<xsl:text>font-family:verdana,arial,sans-serif; margin-bottom:12pt; margin-top:12pt;</xsl:text>
							</xsl:attribute>
						</xsl:when>
						<xsl:otherwise>
							<xsl:attribute name="class">
								<xsl:text>Paragraph</xsl:text>
							</xsl:attribute>
						</xsl:otherwise>
					</xsl:choose>
					<a href="{$ex}">
						<xsl:choose>
							<xsl:when test="ancestor::LearningObject[1]/MetaData/General/Language='de'">
								<xsl:text>Lösung</xsl:text>
							</xsl:when>
							<xsl:otherwise>
								<xsl:text>Solution</xsl:text>
							</xsl:otherwise>
						</xsl:choose>
					</a>
				</div>
			</xsl:if>
		</div>
		<xsl:result-document href="{$ex}">
			<html>
				<head>
					<title>
						<xsl:choose>
							<xsl:when test="ancestor::LearningObject[1]/MetaData/General/Language='de'">
								<xsl:value-of select="concat(string(ancestor::LearningObject[1]/MetaData/General/Title),' - ','Übungsaufgaben')"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="concat(string(ancestor::LearningObject[1]/MetaData/General/Title),' - ','Exercises')"/>
							</xsl:otherwise>
						</xsl:choose>
					</title>
					<xsl:choose>
						<xsl:when test="$ILIAS='Yes'"/>
						<xsl:otherwise>
							<link type="text/css" rel="stylesheet">
								<xsl:attribute name="href">
									<xsl:value-of select="ancestor::LearningObject[1]/LayoutInformation/@CSS-URL"/>
								</xsl:attribute>
							</link>
						</xsl:otherwise>
					</xsl:choose>
				</head>
				<body>
					<xsl:choose>
						<xsl:when test="ancestor::LearningObject[1]/MetaData/General/Language='de'">
							<h1>
								<xsl:if test="$ILIAS='Yes'">
									<xsl:attribute name="style">
										<xsl:text>font-family:verdana,arial,sans-serif;</xsl:text>
									</xsl:attribute>
								</xsl:if>
								<xsl:text>Übungsaufgaben</xsl:text>
							</h1>
						</xsl:when>
						<xsl:otherwise>
							<h1>
								<xsl:if test="$ILIAS='Yes'">
									<xsl:attribute name="style">
										<xsl:text>font-family:verdana,arial,sans-serif;</xsl:text>
									</xsl:attribute>
								</xsl:if>
								<xsl:text>Exercises</xsl:text>
							</h1>
						</xsl:otherwise>
					</xsl:choose>
					<xsl:choose>
						<xsl:when test="ancestor::LearningObject[1]/MetaData/General/Language='de'">
							<h2>
								<xsl:if test="$ILIAS='Yes'">
									<xsl:attribute name="style">
										<xsl:text>font-family:verdana,arial,sans-serif;</xsl:text>
									</xsl:attribute>
								</xsl:if>
								<xsl:text>Übungsaufgabe aus </xsl:text>
								<xsl:value-of select="ancestor::LearningObject[1]/MetaData/General/Title"/>
							</h2>
						</xsl:when>
						<xsl:otherwise>
							<h2>
								<xsl:if test="$ILIAS='Yes'">
									<xsl:attribute name="style">
										<xsl:text>font-family:verdana,arial,sans-serif;</xsl:text>
									</xsl:attribute>
								</xsl:if>
								<xsl:text>Exercises </xsl:text>
								<xsl:value-of select="ancestor::LearningObject[1]/MetaData/General/Title"/>
							</h2>	
						</xsl:otherwise>
					</xsl:choose>
					<div>
						<xsl:choose>
							<xsl:when test="$ILIAS='Yes'">
								<xsl:attribute name="style">
									<xsl:text>font-family:verdana,arial,sans-serif; margin-bottom:12pt; margin-top:12pt;</xsl:text>
								</xsl:attribute>
							</xsl:when>
							<xsl:otherwise>
								<xsl:attribute name="class">
									<xsl:text>Paragraph</xsl:text>
								</xsl:attribute>
							</xsl:otherwise>
						</xsl:choose>
						<xsl:apply-templates select="ExerciseText"/>
					</div>
					<xsl:if test="Solution">
						<xsl:choose>
							<xsl:when test="ancestor::LearningObject[1]/MetaData/General/Language='de'">
								<h2>
									<xsl:if test="$ILIAS='Yes'">
										<xsl:attribute name="style">
											<xsl:text>font-family:verdana,arial,sans-serif;</xsl:text>
										</xsl:attribute>
									</xsl:if>
									<xsl:text>Lösung</xsl:text>
								</h2>
							</xsl:when>
							<xsl:otherwise>
								<h2>
									<xsl:if test="$ILIAS='Yes'">
										<xsl:attribute name="style">
											<xsl:text>font-family:verdana,arial,sans-serif;</xsl:text>
										</xsl:attribute>
									</xsl:if>
									<xsl:text>Solution</xsl:text>
								</h2>
							</xsl:otherwise>
						</xsl:choose>
						<xsl:for-each select="Solution">
							<div>
								<xsl:choose>
									<xsl:when test="$ILIAS='Yes'">
										<xsl:attribute name="style">
											<xsl:text>font-family:verdana,arial,sans-serif; margin-bottom:12pt; margin-top:12pt;</xsl:text>
										</xsl:attribute>
									</xsl:when>
									<xsl:otherwise>
										<xsl:attribute name="class">
											<xsl:text>Paragraph</xsl:text>
										</xsl:attribute>
									</xsl:otherwise>
								</xsl:choose>
								<xsl:apply-templates select="."/>
							</div>
						</xsl:for-each>
					</xsl:if>
				</body>
			</html>
		</xsl:result-document>
	</xsl:template>
	
	<xsl:template match="ExerciseText">
		<xsl:choose>
			<xsl:when test="../@DifficultyLevel='Easy'">
				<div style="color:green">
					<xsl:choose>
						<xsl:when test="ancestor::LearningObject[1]/MetaData/General/Language='de'">
							<xsl:text>Frage:</xsl:text>
						</xsl:when>
						<xsl:otherwise>
							<xsl:text>Question:</xsl:text>
						</xsl:otherwise>	
					</xsl:choose>
				</div>
			</xsl:when>
			<xsl:when test="../@DifficultyLevel='Medium'">
				<div style="color:yellow">
					<xsl:choose>
						<xsl:when test="ancestor::LearningObject[1]/MetaData/General/Language='de'">
							<xsl:text>Frage:</xsl:text>
						</xsl:when>
						<xsl:otherwise>
							<xsl:text>Question:</xsl:text>
						</xsl:otherwise>	
					</xsl:choose>
				</div>
			</xsl:when>
			<xsl:when test="../@DifficultyLevel='Hard'">
				<div style="color:red">
					<xsl:choose>
						<xsl:when test="ancestor::LearningObject[1]/MetaData/General/Language='de'">
							<xsl:text>Frage:</xsl:text>
						</xsl:when>
						<xsl:otherwise>
							<xsl:text>Question:</xsl:text>
						</xsl:otherwise>	
					</xsl:choose>
				</div>
			</xsl:when>
		</xsl:choose>
		<xsl:apply-templates/>
	</xsl:template>
	
	<xsl:template match="Bibliography">
		<xsl:variable name="bib" select="concat(string(../MetaData/General/Identifier/@Entry),'-','bib','.xhtml')"/>
		<xsl:result-document href="{$bib}">
			<html>
				<head>
					<title>
						<xsl:choose>
							<xsl:when test="../MetaData/General/Language='de'">
								<xsl:value-of select="concat(string(../MetaData/General/Title),' - ','Literaturangaben')"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="concat(string(../MetaData/General/Title),' - ','Bibliography')"/>
							</xsl:otherwise>
						</xsl:choose>
					</title>
					<xsl:choose>
						<xsl:when test="$ILIAS='Yes'"/>
						<xsl:otherwise>
							<link type="text/css" rel="stylesheet">
								<xsl:attribute name="href">
									<xsl:value-of select="../LayoutInformation/@CSS-URL"/>
								</xsl:attribute>
							</link>
						</xsl:otherwise>
					</xsl:choose>
				</head>
				<body>
					<xsl:choose>
						<xsl:when test="../MetaData/General/Language='de'">
							<h1>
								<xsl:if test="$ILIAS='Yes'">
									<xsl:attribute name="style">
										<xsl:text>font-family:verdana,arial,sans-serif;</xsl:text>
									</xsl:attribute>
								</xsl:if>
								<xsl:text>Literaturangaben</xsl:text>
							</h1>
						</xsl:when>
						<xsl:when test="../MetaData/General/Language='en'">
							<h1>
								<xsl:if test="$ILIAS='Yes'">
									<xsl:attribute name="style">
										<xsl:text>font-family:verdana,arial,sans-serif;</xsl:text>
									</xsl:attribute>
								</xsl:if>
								<xsl:text>Bibliography</xsl:text>
							</h1>
						</xsl:when>
					</xsl:choose>
					<xsl:if test="Bibitem/@Type='Article'">
						<xsl:choose>
							<xsl:when test="../MetaData/General/Language='de'">
								<h3>
									<xsl:if test="$ILIAS='Yes'">
										<xsl:attribute name="style">
											<xsl:text>font-family:verdana,arial,sans-serif;</xsl:text>
										</xsl:attribute>
									</xsl:if>
									<xsl:text>Artikel</xsl:text>
								</h3>
							</xsl:when>
							<xsl:otherwise>
								<h3>
									<xsl:if test="$ILIAS='Yes'">
										<xsl:attribute name="style">
											<xsl:text>font-family:verdana,arial,sans-serif;</xsl:text>
										</xsl:attribute>
									</xsl:if>
									<xsl:text>Articles</xsl:text>
								</h3>
							</xsl:otherwise>
						</xsl:choose>
						<xsl:for-each select="Bibitem[@Type='Article']">
							<xsl:sort select="(Author[1]/Family | Editor[1]/Family | Organization)[1]"/>
							<div>
								<xsl:choose>
									<xsl:when test="$ILIAS='Yes'">
										<xsl:attribute name="style">
											<xsl:text>font-family:verdana,arial,sans-serif; margin-bottom:12pt; margin-top:12pt;</xsl:text>
										</xsl:attribute>
									</xsl:when>
									<xsl:otherwise>
										<xsl:attribute name="class">
											<xsl:text>Paragraph</xsl:text>
										</xsl:attribute>
									</xsl:otherwise>
								</xsl:choose>
								<xsl:apply-templates select="."/>
							</div>
						</xsl:for-each>
					</xsl:if>
					<xsl:if test="Bibitem/@Type='AV'">
						<h3>
							<xsl:if test="$ILIAS='Yes'">
								<xsl:attribute name="style">
									<xsl:text>font-family:verdana,arial,sans-serif;</xsl:text>
								</xsl:attribute>
							</xsl:if>
							<xsl:text>AV</xsl:text>
						</h3>
						<xsl:for-each select="Bibitem[@Type='AV']">
							<xsl:sort select="(Author[1]/Family | Editor[1]/Family | Organization)[1]"/>
							<div>
								<xsl:choose>
									<xsl:when test="$ILIAS='Yes'">
										<xsl:attribute name="style">
											<xsl:text>font-family:verdana,arial,sans-serif; margin-bottom:12pt; margin-top:12pt;</xsl:text>
										</xsl:attribute>
									</xsl:when>
									<xsl:otherwise>
										<xsl:attribute name="class">
											<xsl:text>Paragraph</xsl:text>
										</xsl:attribute>
									</xsl:otherwise>
								</xsl:choose>
								<xsl:apply-templates select="."/>
							</div>
						</xsl:for-each>
					</xsl:if>
					<xsl:if test="Bibitem/@Type='Book'">
						<xsl:choose>
							<xsl:when test="../MetaData/General/Language='de'">
								<h3>
									<xsl:if test="$ILIAS='Yes'">
										<xsl:attribute name="style">
											<xsl:text>font-family:verdana,arial,sans-serif;</xsl:text>
										</xsl:attribute>
									</xsl:if>
									<xsl:text>Bücher</xsl:text>
								</h3>
							</xsl:when>
							<xsl:when test="../MetaData/General/Language='en'">
								<h3>
									<xsl:if test="$ILIAS='Yes'">
										<xsl:attribute name="style">
											<xsl:text>font-family:verdana,arial,sans-serif;</xsl:text>
										</xsl:attribute>
									</xsl:if>
									<xsl:text>Books</xsl:text>
								</h3>
							</xsl:when>
						</xsl:choose>
						<xsl:for-each select="Bibitem[@Type='Book']">
							<xsl:sort select="(Author[1]/Family | Editor[1]/Family | Organization)[1]"/>
							<div>
								<xsl:choose>
									<xsl:when test="$ILIAS='Yes'">
										<xsl:attribute name="style">
											<xsl:text>font-family:verdana,arial,sans-serif; margin-bottom:12pt; margin-top:12pt;</xsl:text>
										</xsl:attribute>
									</xsl:when>
									<xsl:otherwise>
										<xsl:attribute name="class">
											<xsl:text>Paragraph</xsl:text>
										</xsl:attribute>
									</xsl:otherwise>
								</xsl:choose>
								<xsl:apply-templates select="."/>
							</div>
						</xsl:for-each>
					</xsl:if>
					<xsl:if test="Bibitem/@Type='Dissertation'">
						<h3>
							<xsl:if test="$ILIAS='Yes'">
								<xsl:attribute name="style">
									<xsl:text>font-family:verdana,arial,sans-serif;</xsl:text>
								</xsl:attribute>
							</xsl:if>
							<xsl:text>Dissertation</xsl:text>
						</h3>
						<xsl:for-each select="Bibitem[@Type='Dissertation']">
							<xsl:sort select="(Author[1]/Family | Editor[1]/Family | Organization)[1]"/>
							<div>
								<xsl:choose>
									<xsl:when test="$ILIAS='Yes'">
										<xsl:attribute name="style">
											<xsl:text>font-family:verdana,arial,sans-serif; margin-bottom:12pt; margin-top:12pt;</xsl:text>
										</xsl:attribute>
									</xsl:when>
									<xsl:otherwise>
										<xsl:attribute name="class">
											<xsl:text>Paragraph</xsl:text>
										</xsl:attribute>
									</xsl:otherwise>
								</xsl:choose>
								<xsl:apply-templates select="."/>
							</div>
						</xsl:for-each>
					</xsl:if>
					<xsl:if test="Bibitem/@Type='Inbook'">
						<xsl:choose>
							<xsl:when test="../MetaData/General/Language='de'">
								<h3>
									<xsl:if test="$ILIAS='Yes'">
										<xsl:attribute name="style">
											<xsl:text>font-family:verdana,arial,sans-serif;</xsl:text>
										</xsl:attribute>
									</xsl:if>
									<xsl:text>Kapitel</xsl:text>
								</h3>
							</xsl:when>
							<xsl:when test="../MetaData/General/Language='en'">
								<h3>
									<xsl:if test="$ILIAS='Yes'">
										<xsl:attribute name="style">
											<xsl:text>font-family:verdana,arial,sans-serif;</xsl:text>
										</xsl:attribute>
									</xsl:if>
									<xsl:text>Inbook</xsl:text>
								</h3>
							</xsl:when>
						</xsl:choose>
						<xsl:for-each select="Bibitem[@Type='Inbook']">
							<xsl:sort select="(Author[1]/Family | Editor[1]/Family | Organization)[1]"/>
							<div>
								<xsl:choose>
									<xsl:when test="$ILIAS='Yes'">
										<xsl:attribute name="style">
											<xsl:text>font-family:verdana,arial,sans-serif; margin-bottom:12pt; margin-top:12pt;</xsl:text>
										</xsl:attribute>
									</xsl:when>
									<xsl:otherwise>
										<xsl:attribute name="class">
											<xsl:text>Paragraph</xsl:text>
										</xsl:attribute>
									</xsl:otherwise>
								</xsl:choose>
								<xsl:apply-templates select="."/>
							</div>
						</xsl:for-each>
					</xsl:if>
					<xsl:if test="Bibitem/@Type='Incollection'">
						<xsl:choose>
							<xsl:when test="../MetaData/General/Language='de'">
								<h3>
									<xsl:if test="$ILIAS='Yes'">
										<xsl:attribute name="style">
											<xsl:text>font-family:verdana,arial,sans-serif; margin-bottom:12pt; margin-top:12pt;</xsl:text>
										</xsl:attribute>
									</xsl:if>
									<xsl:text>Beiträge</xsl:text>
								</h3>
							</xsl:when>
							<xsl:when test="../MetaData/General/Language='en'">
								<h3>
									<xsl:if test="$ILIAS='Yes'">
										<xsl:attribute name="style">
											<xsl:text>font-family:verdana,arial,sans-serif;</xsl:text>
										</xsl:attribute>
									</xsl:if>
									<xsl:text>Incollection</xsl:text>
								</h3>
							</xsl:when>
						</xsl:choose>
						<xsl:for-each select="Bibitem[@Type='Incollection']">
							<xsl:sort select="(Author[1]/Family | Editor[1]/Family | Organization)[1]"/>
							<div>
								<xsl:choose>
									<xsl:when test="$ILIAS='Yes'">
										<xsl:attribute name="style">
											<xsl:text>font-family:verdana,arial,sans-serif; margin-bottom:12pt; margin-top:12pt;</xsl:text>
										</xsl:attribute>
									</xsl:when>
									<xsl:otherwise>
										<xsl:attribute name="class">
											<xsl:text>Paragraph</xsl:text>
										</xsl:attribute>
									</xsl:otherwise>
								</xsl:choose>
								<xsl:apply-templates select="."/>
							</div>
						</xsl:for-each>
					</xsl:if>
					<xsl:if test="Bibitem/@Type='Inproceedings'">
						<xsl:choose>
							<xsl:when test="../MetaData/General/Language='de'">
								<h3>
									<xsl:if test="$ILIAS='Yes'">
										<xsl:attribute name="style">
											<xsl:text>font-family:verdana,arial,sans-serif; margin-bottom:12pt; margin-top:12pt;</xsl:text>
										</xsl:attribute>
									</xsl:if>
									<xsl:text>Beiträge</xsl:text>
								</h3>
							</xsl:when>
							<xsl:when test="../MetaData/General/Language='en'">
								<h3>
									<xsl:if test="$ILIAS='Yes'">
										<xsl:attribute name="style">
											<xsl:text>font-family:verdana,arial,sans-serif;</xsl:text>
										</xsl:attribute>
									</xsl:if>
									<xsl:text>Inproceedings</xsl:text>
								</h3>
							</xsl:when>
						</xsl:choose>
						<xsl:for-each select="Bibitem[@Type='Inproceedings']">
							<xsl:sort select="(Author[1]/Family | Editor[1]/Family | Organization)[1]"/>
							<div>
								<xsl:choose>
									<xsl:when test="$ILIAS='Yes'">
										<xsl:attribute name="style">
											<xsl:text>font-family:verdana,arial,sans-serif; margin-bottom:12pt; margin-top:12pt;</xsl:text>
										</xsl:attribute>
									</xsl:when>
									<xsl:otherwise>
										<xsl:attribute name="class">
											<xsl:text>Paragraph</xsl:text>
										</xsl:attribute>
									</xsl:otherwise>
								</xsl:choose>
								<xsl:apply-templates select="."/>
							</div>
						</xsl:for-each>
					</xsl:if>
					<xsl:if test="Bibitem/@Type='Internet'">
						<h3>
							<xsl:if test="$ILIAS='Yes'">
								<xsl:attribute name="style">
									<xsl:text>font-family:verdana,arial,sans-serif;</xsl:text>
								</xsl:attribute>
							</xsl:if>
							<xsl:text>Internet</xsl:text>
						</h3>
						<xsl:for-each select="Bibitem[@Type='Internet']">
							<xsl:sort select="(Author[1]/Family | Editor[1]/Family | Organization)[1]"/>
							<div>
								<xsl:choose>
									<xsl:when test="$ILIAS='Yes'">
										<xsl:attribute name="style">
											<xsl:text>font-family:verdana,arial,sans-serif; margin-bottom:12pt; margin-top:12pt;</xsl:text>
										</xsl:attribute>
									</xsl:when>
									<xsl:otherwise>
										<xsl:attribute name="class">
											<xsl:text>Paragraph</xsl:text>
										</xsl:attribute>
									</xsl:otherwise>
								</xsl:choose>
								<xsl:apply-templates select="."/>
							</div>
						</xsl:for-each>
					</xsl:if>
					<xsl:if test="Bibitem/@Type='Journalarticle'">
						<xsl:choose>
							<xsl:when test="../MetaData/General/Language='de'">
								<h3>
									<xsl:if test="$ILIAS='Yes'">
										<xsl:attribute name="style">
											<xsl:text>font-family:verdana,arial,sans-serif;</xsl:text>
										</xsl:attribute>
									</xsl:if>
									<xsl:text>Zeitschriftenartikel</xsl:text>
								</h3>
							</xsl:when>
							<xsl:when test="../MetaData/General/Language='en'">
								<h3>
									<xsl:if test="$ILIAS='Yes'">
										<xsl:attribute name="style">
											<xsl:text>font-family:verdana,arial,sans-serif;</xsl:text>
										</xsl:attribute>
									</xsl:if>
									<xsl:text>Journalarticle</xsl:text>
								</h3>
							</xsl:when>
						</xsl:choose>
						<xsl:for-each select="Bibitem[@Type='Journalarticle']">
							<xsl:sort select="(Author[1]/Family | Editor[1]/Family | Organization)[1]"/>
							<div>
								<xsl:choose>
									<xsl:when test="$ILIAS='Yes'">
										<xsl:attribute name="style">
											<xsl:text>font-family:verdana,arial,sans-serif; margin-bottom:12pt; margin-top:12pt;</xsl:text>
										</xsl:attribute>
									</xsl:when>
									<xsl:otherwise>
										<xsl:attribute name="class">
											<xsl:text>Paragraph</xsl:text>
										</xsl:attribute>
									</xsl:otherwise>
								</xsl:choose>
								<xsl:apply-templates select="."/>
							</div>
						</xsl:for-each>
					</xsl:if>
					<xsl:if test="Bibitem/@Type='Manual'">
						<xsl:choose>
							<xsl:when test="../MetaData/General/Language='de'">
								<h3>
									<xsl:if test="$ILIAS='Yes'">
										<xsl:attribute name="style">
											<xsl:text>font-family:verdana,arial,sans-serif;</xsl:text>
										</xsl:attribute>
									</xsl:if>
									<xsl:text>Handbuch</xsl:text>
								</h3>
							</xsl:when>
							<xsl:when test="../MetaData/General/Language='en'">
								<h3>
									<xsl:if test="$ILIAS='Yes'">
										<xsl:attribute name="style">
											<xsl:text>font-family:verdana,arial,sans-serif;</xsl:text>
										</xsl:attribute>
									</xsl:if>
									<xsl:text>Manual</xsl:text>
								</h3>
							</xsl:when>
						</xsl:choose>
						<xsl:for-each select="Bibitem[@Type='Manual']">
							<xsl:sort select="(Author[1]/Family | Editor[1]/Family | Organization)[1]"/>
							<div>
								<xsl:choose>
									<xsl:when test="$ILIAS='Yes'">
										<xsl:attribute name="style">
											<xsl:text>font-family:verdana,arial,sans-serif; margin-bottom:12pt; margin-top:12pt;</xsl:text>
										</xsl:attribute>
									</xsl:when>
									<xsl:otherwise>
										<xsl:attribute name="class">
											<xsl:text>Paragraph</xsl:text>
										</xsl:attribute>
									</xsl:otherwise>
								</xsl:choose>
								<xsl:apply-templates select="."/>
							</div>
						</xsl:for-each>
					</xsl:if>
					<xsl:if test="Bibitem/@Type='Mastersthesis'">
						<xsl:choose>
							<xsl:when test="../MetaData/General/Language='de'">
								<h3>
									<xsl:if test="$ILIAS='Yes'">
										<xsl:attribute name="style">
											<xsl:text>font-family:verdana,arial,sans-serif;</xsl:text>
										</xsl:attribute>
									</xsl:if>
									<xsl:text>Diplom- oder Magisterarbeiten</xsl:text>
								</h3>
							</xsl:when>
							<xsl:when test="../MetaData/General/Language='en'">
								<h3>
									<xsl:if test="$ILIAS='Yes'">
										<xsl:attribute name="style">
											<xsl:text>font-family:verdana,arial,sans-serif;</xsl:text>
										</xsl:attribute>
									</xsl:if>
									<xsl:text>Mastersthesis</xsl:text>
								</h3>
							</xsl:when>
						</xsl:choose>
						<xsl:for-each select="Bibitem[@Type='Mastersthesis']">
							<xsl:sort select="(Author[1]/Family | Editor[1]/Family | Organization)[1]"/>
							<div>
								<xsl:choose>
									<xsl:when test="$ILIAS='Yes'">
										<xsl:attribute name="style">
											<xsl:text>font-family:verdana,arial,sans-serif; margin-bottom:12pt; margin-top:12pt;</xsl:text>
										</xsl:attribute>
									</xsl:when>
									<xsl:otherwise>
										<xsl:attribute name="class">
											<xsl:text>Paragraph</xsl:text>
										</xsl:attribute>
									</xsl:otherwise>
								</xsl:choose>
								<xsl:apply-templates select="."/>
							</div>
						</xsl:for-each>
					</xsl:if>
					<xsl:if test="Bibitem/@Type='Newspaperarticle'">
						<xsl:choose>
							<xsl:when test="../MetaData/General/Language='de'">
								<h3>
									<xsl:if test="$ILIAS='Yes'">
										<xsl:attribute name="style">
											<xsl:text>font-family:verdana,arial,sans-serif;</xsl:text>
										</xsl:attribute>
									</xsl:if>
									<xsl:text>Zeitungsartikel</xsl:text>
								</h3>
							</xsl:when>
							<xsl:when test="../MetaData/General/Language='en'">
								<h3>
									<xsl:if test="$ILIAS='Yes'">
										<xsl:attribute name="style">
											<xsl:text>font-family:verdana,arial,sans-serif;</xsl:text>
										</xsl:attribute>
									</xsl:if>
									<xsl:text>Newspaperarticle</xsl:text>
								</h3>
							</xsl:when>
						</xsl:choose>
						<xsl:for-each select="Bibitem[@Type='Newspaperarticle']">
							<xsl:sort select="(Author[1]/Family | Editor[1]/Family | Organization)[1]"/>
							<div>
								<xsl:choose>
									<xsl:when test="$ILIAS='Yes'">
										<xsl:attribute name="style">
											<xsl:text>font-family:verdana,arial,sans-serif; margin-bottom:12pt; margin-top:12pt;</xsl:text>
										</xsl:attribute>
									</xsl:when>
									<xsl:otherwise>
										<xsl:attribute name="class">
											<xsl:text>Paragraph</xsl:text>
										</xsl:attribute>
									</xsl:otherwise>
								</xsl:choose>
								<xsl:apply-templates select="."/>
							</div>
						</xsl:for-each>
					</xsl:if>
					<xsl:if test="Bibitem/@Type='Phdthesis'">
						<xsl:choose>
							<xsl:when test="../MetaData/General/Language='de'">
								<h3>
									<xsl:if test="$ILIAS='Yes'">
										<xsl:attribute name="style">
											<xsl:text>font-family:verdana,arial,sans-serif;</xsl:text>
										</xsl:attribute>
									</xsl:if>
									<xsl:text>Doktorarbeiten</xsl:text>
								</h3>
							</xsl:when>
							<xsl:when test="../MetaData/General/Language='en'">
								<h3>
									<xsl:if test="$ILIAS='Yes'">
										<xsl:attribute name="style">
											<xsl:text>font-family:verdana,arial,sans-serif;</xsl:text>
										</xsl:attribute>
									</xsl:if>
									<xsl:text>Phdthesis</xsl:text>
								</h3>
							</xsl:when>
						</xsl:choose>
						<xsl:for-each select="Bibitem[@Type='Phdthesis']">
							<xsl:sort select="(Author[1]/Family | Editor[1]/Family | Organization)[1]"/>
							<div>
								<xsl:choose>
									<xsl:when test="$ILIAS='Yes'">
										<xsl:attribute name="style">
											<xsl:text>font-family:verdana,arial,sans-serif; margin-bottom:12pt; margin-top:12pt;</xsl:text>
										</xsl:attribute>
									</xsl:when>
									<xsl:otherwise>
										<xsl:attribute name="class">
											<xsl:text>Paragraph</xsl:text>
										</xsl:attribute>
									</xsl:otherwise>
								</xsl:choose>
								<xsl:apply-templates select="."/>
							</div>
						</xsl:for-each>
					</xsl:if>
					<xsl:if test="Bibitem/@Type='Proceedings'">
						<xsl:choose>
							<xsl:when test="../MetaData/General/Language='de'">
								<h3>
									<xsl:if test="$ILIAS='Yes'">
										<xsl:attribute name="style">
											<xsl:text>font-family:verdana,arial,sans-serif;</xsl:text>
										</xsl:attribute>
									</xsl:if>
									<xsl:text>Protokolle und Berichte</xsl:text>
								</h3>
							</xsl:when>
							<xsl:when test="../MetaData/General/Language='en'">
								<h3>
									<xsl:if test="$ILIAS='Yes'">
										<xsl:attribute name="style">
											<xsl:text>font-family:verdana,arial,sans-serif;</xsl:text>
										</xsl:attribute>
									</xsl:if>
									<xsl:text>Proceedings</xsl:text>
								</h3>
							</xsl:when>
						</xsl:choose>
						<xsl:for-each select="Bibitem[@Type='Proceedings']">
							<xsl:sort select="(Author[1]/Family | Editor[1]/Family | Organization)[1]"/>
							<div>
								<xsl:choose>
									<xsl:when test="$ILIAS='Yes'">
										<xsl:attribute name="style">
											<xsl:text>font-family:verdana,arial,sans-serif; margin-bottom:12pt; margin-top:12pt;</xsl:text>
										</xsl:attribute>
									</xsl:when>
									<xsl:otherwise>
										<xsl:attribute name="class">
											<xsl:text>Paragraph</xsl:text>
										</xsl:attribute>
									</xsl:otherwise>
								</xsl:choose>
								<xsl:apply-templates select="."/>
							</div>
						</xsl:for-each>
					</xsl:if>
					<xsl:if test="Bibitem/@Type='Techreport'">
						<xsl:choose>
							<xsl:when test="../MetaData/General/Language='de'">
								<h3>
									<xsl:if test="$ILIAS='Yes'">
										<xsl:attribute name="style">
											<xsl:text>font-family:verdana,arial,sans-serif;</xsl:text>
										</xsl:attribute>
									</xsl:if>
									<xsl:text>Technische Reports</xsl:text>
								</h3>
							</xsl:when>
							<xsl:when test="../MetaData/General/Language='en'">
								<h3>
									<xsl:if test="$ILIAS='Yes'">
										<xsl:attribute name="style">
											<xsl:text>font-family:verdana,arial,sans-serif;</xsl:text>
										</xsl:attribute>
									</xsl:if>
									<xsl:text>Techreport</xsl:text>
								</h3>
							</xsl:when>
						</xsl:choose>
						<xsl:for-each select="Bibitem[@Type='Techreport']">
							<xsl:sort select="(Author[1]/Family | Editor[1]/Family | Organization)[1]"/>
							<div>
								<xsl:choose>
									<xsl:when test="$ILIAS='Yes'">
										<xsl:attribute name="style">
											<xsl:text>font-family:verdana,arial,sans-serif; margin-bottom:12pt; margin-top:12pt;</xsl:text>
										</xsl:attribute>
									</xsl:when>
									<xsl:otherwise>
										<xsl:attribute name="class">
											<xsl:text>Paragraph</xsl:text>
										</xsl:attribute>
									</xsl:otherwise>
								</xsl:choose>
								<xsl:apply-templates select="."/>
							</div>
						</xsl:for-each>
					</xsl:if>
					<xsl:if test="Bibitem/@Type='Unpublished'">
						<xsl:choose>
							<xsl:when test="../MetaData/General/Language='de'">
								<h3>
									<xsl:if test="$ILIAS='Yes'">
										<xsl:attribute name="style">
											<xsl:text>font-family:verdana,arial,sans-serif;</xsl:text>
										</xsl:attribute>
									</xsl:if>
									<xsl:text>Unveröffentlicht</xsl:text>
								</h3>
							</xsl:when>
							<xsl:when test="../MetaData/General/Language='en'">
								<h3>
									<xsl:if test="$ILIAS='Yes'">
										<xsl:attribute name="style">
											<xsl:text>font-family:verdana,arial,sans-serif;</xsl:text>
										</xsl:attribute>
									</xsl:if>
									<xsl:text>Unpublished</xsl:text>
								</h3>
							</xsl:when>
						</xsl:choose>
						<xsl:for-each select="Bibitem[@Type='Unpublished']">
							<xsl:sort select="(Author[1]/Family | Editor[1]/Family | Organization)[1]"/>
							<div>
								<xsl:choose>
									<xsl:when test="$ILIAS='Yes'">
										<xsl:attribute name="style">
											<xsl:text>font-family:verdana,arial,sans-serif; margin-bottom:12pt; margin-top:12pt;</xsl:text>
										</xsl:attribute>
									</xsl:when>
									<xsl:otherwise>
										<xsl:attribute name="class">
											<xsl:text>Paragraph</xsl:text>
										</xsl:attribute>
									</xsl:otherwise>
								</xsl:choose>
								<xsl:apply-templates select="."/>
							</div>
						</xsl:for-each>
					</xsl:if>
				</body>
			</html>
		</xsl:result-document>
	</xsl:template>

	<xsl:template match="Bibitem">
		<xsl:choose>
			<!-- bibliographisch selbständig -->
			<xsl:when test="@Type='AV' or @Type='Book' or @Type='Dissertation' or @Type='Internet' or @Type='Manual' or @Type='Mastersthesis' or @Type='Phdthesis' or @Type='Techreport'">
				<!-- Formatierung für Monografien und Sammelwerke nach DIN 1505, Teil 2 -->
				<!-- Verfasserangabe ; Herausgeber (Hrsg.) ; wichtige Mitarbeiter, Bearbeiter (Mitarb.) ; Körperschaftl. Urheber (Hrsg.): Sachtitel [kursiv] : Zusatz zum Sachtitel [kursiv] / weniger wichtige beteiligte Personen (Bearb.). Bandangabe, Teilbandzählung : Sachtitel d. Bandes [kursiv]. Auflage. erster Erscheinungsort : erster Verlag, Erscheinungsjahr Gesamttitel mit Zählung. - ergänzende Angaben. - ISBN -->
				<a>
					<xsl:attribute name="id">
						<xsl:value-of select="@Label"/>
					</xsl:attribute>
					<!-- Verfasser -->
					<xsl:choose>
						<xsl:when test="Author and Editor">
							<xsl:call-template name="Authors"/>
							<xsl:text> ; </xsl:text>
							<xsl:call-template name="Editors"/>
						</xsl:when>
						<xsl:when test="Editor and not(Author)">
							<xsl:call-template name="Editors"/>
						</xsl:when>
						<xsl:when test="Author and not(Editor)">
							<xsl:call-template name="Authors"/>
						</xsl:when>
					</xsl:choose>
				</a>
				<!-- Mitarbeiter kennt die DTD nicht -->
				<!-- Körperschaftliche Herausgeber -->
				<xsl:if test="Organization">
					<xsl:if test="preceding-sibling::Author | Editor">
						<xsl:text> ; </xsl:text>
					</xsl:if>
					<xsl:apply-templates select="Organization"/>
					<xsl:text> (Hrsg.)</xsl:text>
				</xsl:if>
				<!-- Sachtitel -->
				<xsl:text>: </xsl:text>
				<em>
					<xsl:apply-templates select="Title"/>
				</em>
				<!-- Zusatz zum Sachtitel kennt die DTD nicht -->
				<!-- Bearbeiter/weniger wichtige beteiligte Personen kennt die DTD nicht -->
				<!-- Bandangabe -->
				<xsl:if test="Volume">
					<xsl:text>. </xsl:text>
					<xsl:apply-templates select="Volume"/>
				</xsl:if>
				<xsl:if test="Number">
					<xsl:text>, </xsl:text>
					<xsl:choose>
						<xsl:when test="ancestor::LearningObject[1]/MetaData/General/Language='de'">
							<xsl:text>Nr. </xsl:text>
							<xsl:apply-templates select="Number"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:text>No. </xsl:text>
							<xsl:apply-templates select="Number"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:if>
				<!-- Sachtitel des Teilbandes -->
				<xsl:if test="Booktitle">
					<xsl:text> : </xsl:text>
					<em>
						<xsl:apply-templates select="Booktitle"/>
					</em>
				</xsl:if>
				<!-- Auflage -->
				<xsl:if test="Edition">
					<xsl:text>. </xsl:text>
					<xsl:value-of select="Edition"/>
				</xsl:if>
				<!-- erster Erscheinungsort -->
				<xsl:if test="Address">
					<xsl:text>. </xsl:text>
					<xsl:value-of select="Address[1]"/>
				</xsl:if>
				<!-- erster Verlag -->
				<xsl:if test="Publisher">
					<xsl:text> : </xsl:text>
					<xsl:value-of select="Publisher[1]"/>
				</xsl:if>
				<!-- Erscheinungsjahr -->
				<xsl:text>, </xsl:text>
				<xsl:value-of select="Year"/>
				<!-- ISBN -->
				<xsl:if test="ISBN">
					<xsl:text>. - ISBN </xsl:text>
					<xsl:value-of select="ISBN"/>
				</xsl:if>
				<!-- URL -->
				<xsl:for-each select="URL">
					<br/>
					<a>
						<xsl:attribute name="href">
							<xsl:value-of select="."/>
						</xsl:attribute>
						<xsl:value-of select="."/>
					</a>
					<xsl:if test="position()!=last()">
						<xsl:text>, </xsl:text>
					</xsl:if>
				</xsl:for-each>
			</xsl:when>
			<!-- bibliographisch unselbständig -->
			<xsl:when test="@Type='Article' or @Type='Inbook' or @Type='Incollection' or @Type='Inproceedings' or @Type='Journalarticle' or @Type='Newspaperarticle' or @Type='Proceedings' or @Type='Unpublished'">
				<a>
					<xsl:attribute name="id">
						<xsl:value-of select="@Label"/>
					</xsl:attribute>
					<!-- Verfasser -->
					<xsl:choose>
						<xsl:when test="Author and Editor">
							<xsl:call-template name="Authors"/>
							<!-- Sachtitel -->
							<xsl:text>: </xsl:text>
							<em>
								<xsl:apply-templates select="Title"/>
							</em>
							<xsl:choose>
								<xsl:when test="Booktitle">
									<xsl:text>. In: </xsl:text>
									<xsl:call-template name="Editors"/>
									<xsl:text> </xsl:text>
									<em>
										<xsl:apply-templates select="Booktitle"/>
									</em>
								</xsl:when>
								<xsl:when test="Journal">
									<xsl:text>. In: </xsl:text>
									<em>
										<xsl:apply-templates select="Journal"/>
									</em>
									<!-- Bandangabe -->
									<xsl:if test="Volume">
										<xsl:text>. </xsl:text>
										<xsl:apply-templates select="Volume"/>
									</xsl:if>
									<xsl:if test="Number">
										<xsl:text> </xsl:text>
										<xsl:choose>
											<xsl:when test="ancestor::LearningObject[1]/MetaData/General/Language='de'">
												<xsl:text>Nr. </xsl:text>
												<xsl:apply-templates select="Number"/>
											</xsl:when>
											<xsl:otherwise>
												<xsl:text>No. </xsl:text>
												<xsl:apply-templates select="Number"/>
											</xsl:otherwise>
										</xsl:choose>
									</xsl:if>
								</xsl:when>
							</xsl:choose>
						</xsl:when>
						<xsl:when test="Editor and not(Author)">
							<xsl:call-template name="Editors"/>
							<!-- Sachtitel -->
							<xsl:text>: </xsl:text>
							<em>
								<xsl:apply-templates select="Title"/>
							</em>
							<xsl:choose>
								<xsl:when test="Booktitle">
									<xsl:text>. In: </xsl:text>
									<xsl:call-template name="Editors"/>
									<xsl:text> </xsl:text>
									<em>
										<xsl:apply-templates select="Booktitle"/>
									</em>
								</xsl:when>
								<xsl:when test="Journal">
									<xsl:text>. In: </xsl:text>
									<em>
										<xsl:apply-templates select="Journal"/>
									</em>
									<!-- Bandangabe -->
									<xsl:if test="Volume">
										<xsl:text>. </xsl:text>
										<xsl:apply-templates select="Volume"/>
									</xsl:if>
									<xsl:if test="Number">
										<xsl:text> </xsl:text>
										<xsl:choose>
											<xsl:when test="ancestor::LearningObject[1]/MetaData/General/Language='de'">
												<xsl:text>Nr. </xsl:text>
												<xsl:apply-templates select="Number"/>
											</xsl:when>
											<xsl:otherwise>
												<xsl:text>No. </xsl:text>
												<xsl:apply-templates select="Number"/>
											</xsl:otherwise>
										</xsl:choose>
									</xsl:if>
								</xsl:when>
							</xsl:choose>
						</xsl:when>
						<xsl:when test="Author and not(Editor)">
							<xsl:call-template name="Authors"/>
							<!-- Sachtitel -->
							<xsl:text>: </xsl:text>
							<em>
								<xsl:apply-templates select="Title"/>
							</em>
							<xsl:choose>
								<xsl:when test="Booktitle">
									<xsl:text>. In: </xsl:text>
									<xsl:call-template name="Editors"/>
									<xsl:text> </xsl:text>
									<em>
										<xsl:apply-templates select="Booktitle"/>
									</em>
								</xsl:when>
								<xsl:when test="Journal">
									<xsl:text>. In: </xsl:text>
									<em>
										<xsl:apply-templates select="Journal"/>
									</em>
									<!-- Bandangabe -->
									<xsl:if test="Volume">
										<xsl:text>. </xsl:text>
										<xsl:apply-templates select="Volume"/>
									</xsl:if>
									<xsl:if test="Number">
										<xsl:text> </xsl:text>
										<xsl:choose>
											<xsl:when test="ancestor::LearningObject[1]/MetaData/General/Language='de'">
												<xsl:text>Nr. </xsl:text>
												<xsl:apply-templates select="Number"/>
											</xsl:when>
											<xsl:otherwise>
												<xsl:text>No. </xsl:text>
												<xsl:apply-templates select="Number"/>
											</xsl:otherwise>
										</xsl:choose>
									</xsl:if>
								</xsl:when>
							</xsl:choose>
						</xsl:when>
					</xsl:choose>
				</a>				
				<!-- Zusatz zum Sachtitel kennt die DTD nicht -->
				<!-- Angabe des Teils kennt die DTD nicht -->
				<!-- Gesamttitelangabe kennt die DTD nicht -->				
				<!-- Erscheinungsjahr -->
				<!-- erster Erscheinungsort -->
				<xsl:if test="Address">
					<xsl:text>. </xsl:text>
					<xsl:value-of select="Address[1]"/>
				</xsl:if>
				<!-- erster Verlag -->
				<xsl:if test="Publisher">
					<xsl:text> : </xsl:text>
					<xsl:value-of select="Publisher[1]"/>
				</xsl:if>
				<xsl:text>, </xsl:text>
				<xsl:value-of select="Year"/>
				<!-- Seitenzählung -->
				<xsl:if test="Pages">
					<xsl:text>, </xsl:text>
					<xsl:choose>
						<xsl:when test="ancestor::LearningObject[1]/MetaData/General/Language='de'">
							<xsl:text>S. </xsl:text>
							<xsl:apply-templates select="Pages"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:text>pp </xsl:text>
							<xsl:apply-templates select="Pages"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:if>
				<xsl:for-each select="URL">
					<br/>
					<a>
						<xsl:attribute name="href">
							<xsl:value-of select="."/>
						</xsl:attribute>
						<xsl:value-of select="."/>
					</a>
					<xsl:if test="position()!=last()">
						<xsl:text>, </xsl:text>
					</xsl:if>
				</xsl:for-each>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="Authors">
		<xsl:for-each select="Author">
			<xsl:apply-templates select="Family"/>
			<xsl:if test="Given | Other | Suffix">
				<xsl:text>, </xsl:text>
				<xsl:apply-templates select="Given"/>
				<xsl:if test="Other">
					<xsl:text> </xsl:text>
					<xsl:apply-templates select="Other"/>
				</xsl:if>
				<xsl:if test="Suffix">
					<xsl:text>, </xsl:text>
					<xsl:apply-templates select="Suffix"/>
				</xsl:if>
			</xsl:if>
			<xsl:if test="position()!=last()">
				<xsl:text> ; </xsl:text>
			</xsl:if>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template name="Editors">
		<xsl:for-each select="Editor">
			<xsl:apply-templates select="Family"/>
			<xsl:if test="Given | Other | Suffix">
				<xsl:text>, </xsl:text>
				<xsl:apply-templates select="Given"/>
				<xsl:if test="Other">
					<xsl:text> </xsl:text>
					<xsl:apply-templates select="Other"/>
				</xsl:if>
				<xsl:if test="Suffix">
					<xsl:text>, </xsl:text>
					<xsl:apply-templates select="Suffix"/>
				</xsl:if>
			</xsl:if>
			<xsl:choose>
				<xsl:when test="position()=last()">
					<xsl:choose>
						<xsl:when test="ancestor::LearningObject[1]/MetaData/General/Language='de'">
							<xsl:text> (Hrsg.)</xsl:text>
						</xsl:when>
						<xsl:otherwise>
							<xsl:text> (Ed.)</xsl:text>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:when>
				<xsl:otherwise>
					<xsl:text> ; </xsl:text>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template name="Authors_and_Editors">
<!-- Anmerkung: Template ist evtl. noch anzupassen. Im schlimmsten Fall werden je 2 Autoren und 2 Editoren angegeben, bevor abgekürzt wird. -->
		<xsl:choose>
			<xsl:when test="id(@Reference_to)/Author and id(@Reference_to)/Editor">
				<!-- erst die Autoren -->
				<xsl:choose>
					<xsl:when test="id(@Reference_to)/Author[last()>2]">
						<xsl:apply-templates select="id(@Reference_to)/Author[1]/Family"/>
						<xsl:if test="id(@Reference_to)/Author[1]/Given | id(@Reference_to)/Author[1]/Other | id(@Reference_to)/Author[1]/Suffix">
							<xsl:text>, </xsl:text>
							<xsl:apply-templates select="id(@Reference_to)/Author[1]/Given"/>
							<xsl:if test="id(@Reference_to)/Author/Other">
								<xsl:text> </xsl:text>
								<xsl:apply-templates select="id(@Reference_to)/Author[1]/Other"/>
							</xsl:if>
							<xsl:if test="id(@Reference_to)/Author/Suffix">
								<xsl:text>, </xsl:text>
								<xsl:apply-templates select="id(@Reference_to)/Author[1]/Suffix"/>
							</xsl:if>
						</xsl:if>
						<xsl:text> ; </xsl:text>
						<xsl:apply-templates select="id(@Reference_to)/Author[2]/Family"/>
						<xsl:if test="id(@Reference_to)/Author[2]/Given | id(@Reference_to)/Author[2]/Other | id(@Reference_to)/Author[2]/Suffix">
							<xsl:text>, </xsl:text>
							<xsl:apply-templates select="id(@Reference_to)/Author[2]/Given"/>
							<xsl:if test="id(@Reference_to)/Author[2]/Other">
								<xsl:text> </xsl:text>
								<xsl:apply-templates select="id(@Reference_to)/Author[2]/Other"/>
							</xsl:if>
							<xsl:if test="id(@Reference_to)/Author[2]/Suffix">
								<xsl:text>, </xsl:text>
								<xsl:apply-templates select="id(@Reference_to)/Author[2]/Suffix"/>
							</xsl:if>
						</xsl:if>		
						<xsl:text> et al.</xsl:text>
					</xsl:when>
					<xsl:otherwise>
						<xsl:for-each select="id(@Reference_to)/Author">
							<xsl:apply-templates select="Family"/>
							<xsl:if test="Given | Other | Suffix">
								<xsl:text>, </xsl:text>
								<xsl:apply-templates select="Given"/>
								<xsl:if test="Other">
									<xsl:text> </xsl:text>
									<xsl:apply-templates select="Other"/>
								</xsl:if>
								<xsl:if test="Suffix">
									<xsl:text>, </xsl:text>
									<xsl:apply-templates select="Suffix"/>
								</xsl:if>
							</xsl:if>
							<xsl:if test="position()!=last()">
								<xsl:text> ; </xsl:text>
							</xsl:if>
						</xsl:for-each>
					</xsl:otherwise>
				</xsl:choose>
				<xsl:text> in: </xsl:text>
				<!-- jetzt die Editoren -->
				<xsl:choose>
					<xsl:when test="id(@Reference_to)/Editor[last()>2]">
						<xsl:apply-templates select="id(@Reference_to)/Editor[1]/Family"/>
						<xsl:if test="id(@Reference_to)/Editor[1]/Given | id(@Reference_to)/Editor[1]/Other | id(@Reference_to)/Editor[1]/Suffix">
							<xsl:text>, </xsl:text>
							<xsl:apply-templates select="id(@Reference_to)/Editor[1]/Given"/>
							<xsl:if test="id(@Reference_to)/Editor/Other">
								<xsl:text> </xsl:text>
								<xsl:apply-templates select="id(@Reference_to)/Editor[1]/Other"/>
							</xsl:if>
							<xsl:if test="id(@Reference_to)/Editor/Suffix">
								<xsl:text>, </xsl:text>
								<xsl:apply-templates select="id(@Reference_to)/Editor[1]/Suffix"/>
							</xsl:if>
						</xsl:if>
						<xsl:text> ; </xsl:text>
						<xsl:apply-templates select="id(@Reference_to)/Editor[2]/Family"/>
						<xsl:if test="id(@Reference_to)/Editor[2]/Given | id(@Reference_to)/Editor[2]/Other | id(@Reference_to)/Editor[2]/Suffix">
							<xsl:text>, </xsl:text>
							<xsl:apply-templates select="id(@Reference_to)/Editor[2]/Given"/>
							<xsl:if test="id(@Reference_to)/Editor[2]/Other">
								<xsl:text> </xsl:text>
								<xsl:apply-templates select="id(@Reference_to)/Editor[2]/Other"/>
							</xsl:if>
							<xsl:if test="id(@Reference_to)/Editor[2]/Suffix">
								<xsl:text>, </xsl:text>
								<xsl:apply-templates select="id(@Reference_to)/Editor[2]/Suffix"/>
							</xsl:if>
						</xsl:if>
						<xsl:choose>
							<xsl:when test="ancestor::LearningObject[1]/MetaData/General/Language='de'">
								<xsl:text> et al. (Hrsg.)</xsl:text>
							</xsl:when>
							<xsl:otherwise>
								<xsl:text> et al. (Ed.)</xsl:text>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<xsl:for-each select="id(@Reference_to)/Editor">
							<xsl:apply-templates select="Family"/>
							<xsl:if test="Given | Other | Suffix">
								<xsl:text>, </xsl:text>
								<xsl:apply-templates select="Given"/>
								<xsl:if test="Other">
									<xsl:text> </xsl:text>
									<xsl:apply-templates select="Other"/>
								</xsl:if>
								<xsl:if test="Suffix">
									<xsl:text>, </xsl:text>
									<xsl:apply-templates select="Suffix"/>
								</xsl:if>
							</xsl:if>
							<xsl:choose>
								<xsl:when test="position()=last()">
									<xsl:choose>
										<xsl:when test="ancestor::LearningObject[1]/MetaData/General/Language='de'">
											<xsl:text> (Hrsg.)</xsl:text>
										</xsl:when>
										<xsl:otherwise>
											<xsl:text> (Ed.)</xsl:text>
										</xsl:otherwise>
									</xsl:choose>
								</xsl:when>
								<xsl:otherwise>
									<xsl:text> ; </xsl:text>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:for-each>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:when test="id(@Reference_to)/Editor and not(id(@Reference_to)/Author)">
				<!-- die Editoren -->
				<xsl:choose>
					<xsl:when test="id(@Reference_to)/Editor[last()>2]">
						<xsl:apply-templates select="id(@Reference_to)/Editor[1]/Family"/>
						<xsl:if test="id(@Reference_to)/Editor[1]/Given | id(@Reference_to)/Editor[1]/Other | id(@Reference_to)/Editor[1]/Suffix">
							<xsl:text>, </xsl:text>
							<xsl:apply-templates select="id(@Reference_to)/Editor[1]/Given"/>
							<xsl:if test="id(@Reference_to)/Editor/Other">
								<xsl:text> </xsl:text>
								<xsl:apply-templates select="id(@Reference_to)/Editor[1]/Other"/>
							</xsl:if>
							<xsl:if test="id(@Reference_to)/Editor/Suffix">
								<xsl:text>, </xsl:text>
								<xsl:apply-templates select="id(@Reference_to)/Editor[1]/Suffix"/>
							</xsl:if>
						</xsl:if>
						<xsl:text> ; </xsl:text>
						<xsl:apply-templates select="id(@Reference_to)/Editor[2]/Family"/>
						<xsl:if test="id(@Reference_to)/Editor[2]/Given | id(@Reference_to)/Editor[2]/Other | id(@Reference_to)/Editor[2]/Suffix">
							<xsl:text>, </xsl:text>
							<xsl:apply-templates select="id(@Reference_to)/Editor[2]/Given"/>
							<xsl:if test="id(@Reference_to)/Editor[2]/Other">
								<xsl:text> </xsl:text>
								<xsl:apply-templates select="id(@Reference_to)/Editor[2]/Other"/>
							</xsl:if>
							<xsl:if test="id(@Reference_to)/Editor[2]/Suffix">
								<xsl:text>, </xsl:text>
								<xsl:apply-templates select="id(@Reference_to)/Editor[2]/Suffix"/>
							</xsl:if>
						</xsl:if>
						<xsl:choose>
							<xsl:when test="ancestor::LearningObject[1]/MetaData/General/Language='de'">
								<xsl:text> et al. (Hrsg.)</xsl:text>
							</xsl:when>
							<xsl:otherwise>
								<xsl:text> et al. (Ed.)</xsl:text>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<xsl:for-each select="id(@Reference_to)/Editor">
							<xsl:apply-templates select="Family"/>
							<xsl:if test="Given | Other | Suffix">
								<xsl:text>, </xsl:text>
								<xsl:apply-templates select="Given"/>
								<xsl:if test="Other">
									<xsl:text> </xsl:text>
									<xsl:apply-templates select="Other"/>
								</xsl:if>
								<xsl:if test="Suffix">
									<xsl:text>, </xsl:text>
									<xsl:apply-templates select="Suffix"/>
								</xsl:if>
							</xsl:if>
							<xsl:choose>
								<xsl:when test="position()=last()">
									<xsl:choose>
										<xsl:when test="ancestor::LearningObject[1]/MetaData/General/Language='de'">
											<xsl:text> (Hrsg.)</xsl:text>
										</xsl:when>
										<xsl:otherwise>
											<xsl:text> (Ed.)</xsl:text>
										</xsl:otherwise>
									</xsl:choose>
								</xsl:when>
								<xsl:otherwise>
									<xsl:text> ; </xsl:text>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:for-each>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:when test="id(@Reference_to)/Author and not(id(@Reference_to)/Editor)">
				<!-- nur die Autoren -->
				<xsl:choose>
					<xsl:when test="id(@Reference_to)/Author[last()>2]">
						<xsl:apply-templates select="id(@Reference_to)/Author[1]/Family"/>
						<xsl:if test="id(@Reference_to)/Author[1]/Given | id(@Reference_to)/Author[1]/Other | id(@Reference_to)/Author[1]/Suffix">
							<xsl:text>, </xsl:text>
							<xsl:apply-templates select="id(@Reference_to)/Author[1]/Given"/>
							<xsl:if test="id(@Reference_to)/Author/Other">
								<xsl:text> </xsl:text>
								<xsl:apply-templates select="id(@Reference_to)/Author[1]/Other"/>
							</xsl:if>
							<xsl:if test="id(@Reference_to)/Author/Suffix">
								<xsl:text>, </xsl:text>
								<xsl:apply-templates select="id(@Reference_to)/Author[1]/Suffix"/>
							</xsl:if>
						</xsl:if>
						<xsl:text> ; </xsl:text>
						<xsl:apply-templates select="id(@Reference_to)/Author[2]/Family"/>
						<xsl:if test="id(@Reference_to)/Author[2]/Given | id(@Reference_to)/Author[2]/Other | id(@Reference_to)/Author[2]/Suffix">
							<xsl:text>, </xsl:text>
							<xsl:apply-templates select="id(@Reference_to)/Author[2]/Given"/>
							<xsl:if test="id(@Reference_to)/Author[2]/Other">
								<xsl:text> </xsl:text>
								<xsl:apply-templates select="id(@Reference_to)/Author[2]/Other"/>
							</xsl:if>
							<xsl:if test="id(@Reference_to)/Author[2]/Suffix">
								<xsl:text>, </xsl:text>
								<xsl:apply-templates select="id(@Reference_to)/Author[2]/Suffix"/>
							</xsl:if>
						</xsl:if>
						<xsl:text> et al.</xsl:text>
					</xsl:when>
					<xsl:otherwise>
						<xsl:for-each select="id(@Reference_to)/Author">
							<xsl:apply-templates select="Family"/>
							<xsl:if test="Given | Other | Suffix">
								<xsl:text>, </xsl:text>
								<xsl:apply-templates select="Given"/>
								<xsl:if test="Other">
									<xsl:text> </xsl:text>
									<xsl:apply-templates select="Other"/>
								</xsl:if>
								<xsl:if test="Suffix">
									<xsl:text>, </xsl:text>
									<xsl:apply-templates select="Suffix"/>
								</xsl:if>
							</xsl:if>
							<xsl:if test="position()!=last()">
								<xsl:text> ; </xsl:text>
							</xsl:if>
						</xsl:for-each>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:when test="id(@Reference_to)/Organization and not(id(@Reference_to)/Editor) and not(id(@Reference_to)/Author)">
				<xsl:for-each select="id(@Reference_to)/Organization">
					<xsl:apply-templates select="."/>
					<xsl:choose>
						<xsl:when test="position()=last()">
							<xsl:choose>
								<xsl:when test="ancestor::LearningObject[1]/MetaData/General/Language='de'">
									<xsl:text> (Hrsg.)</xsl:text>
								</xsl:when>
								<xsl:otherwise>
									<xsl:text> (Ed.)</xsl:text>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:when>
						<xsl:otherwise>
							<xsl:text> ; </xsl:text>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:for-each>
			</xsl:when>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="pretty-print">
		<xsl:param name="input"/>
		<xsl:analyze-string select="." regex="[&lt;&gt;]">
			<xsl:matching-substring>
				<span style="color:blue">
					<xsl:value-of select="."/>
				</span>
			</xsl:matching-substring>
			<xsl:non-matching-substring>
				<xsl:call-template name="name">
					<xsl:with-param name="input" select="."/>
				</xsl:call-template>
			</xsl:non-matching-substring>
		</xsl:analyze-string>
	</xsl:template>

	<xsl:template name="name">
		<xsl:param name="input"/>
		<xsl:analyze-string select="$input" regex="([#!][A-Z]*)">
			<xsl:matching-substring>
				<span style="color:red">
					<xsl:value-of select="regex-group(1)"/>
				</span>
			</xsl:matching-substring>
			<xsl:non-matching-substring>
				<xsl:value-of select="."/>
			</xsl:non-matching-substring>
		</xsl:analyze-string>
	</xsl:template>

<!-- nur fuer interne Testzwecke -->

	<xsl:template match="Test">
		<xsl:if test="TestItem">
			<xsl:choose>
				<xsl:when test="ancestor::LearningObject[1]/MetaData/General/Language='de'">
					<h3>
						<xsl:if test="$ILIAS='Yes'">
							<xsl:attribute name="style">
								<xsl:text>font-family:verdana,arial,sans-serif;</xsl:text>
							</xsl:attribute>
						</xsl:if>
						<xsl:text>Übungsaufgaben</xsl:text>
					</h3>
				</xsl:when>
				<xsl:otherwise>
					<h3>
						<xsl:if test="$ILIAS='Yes'">
							<xsl:attribute name="style">
								<xsl:text>font-family:verdana,arial,sans-serif;</xsl:text>
							</xsl:attribute>
						</xsl:if>
						<xsl:text>Exercise</xsl:text>
					</h3>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
		<ol>
			<xsl:if test="$ILIAS='Yes'">
				<xsl:attribute name="style">
					<xsl:text>font-family:verdana,arial,sans-serif;</xsl:text>
				</xsl:attribute>
			</xsl:if>
			<xsl:for-each select="TestItem">
				<li>
					<xsl:apply-templates select="Question"/>
					<xsl:if test="Hint">
						<xsl:choose>
							<xsl:when test="ancestor::LearningObject[1]/MetaData/General/Language='de'">
								<b>Hinweis:</b>								
							</xsl:when>
							<xsl:otherwise>
								<b>Hint:</b>
							</xsl:otherwise>
						</xsl:choose>
						<xsl:for-each select="Hint">
							<div>
								<xsl:if test="$ILIAS='Yes'">
									<xsl:attribute name="style">
										<xsl:text>font-family:verdana,arial,sans-serif; margin-bottom:12pt; margin-top:12pt;</xsl:text>
									</xsl:attribute>
								</xsl:if>
								<xsl:apply-templates/>
							</div>
						</xsl:for-each>
					</xsl:if>
				</li>
			</xsl:for-each>
		</ol>
	</xsl:template>

	<xsl:template match="Comment">
		<span>
			<xsl:choose>
				<xsl:when test="$ILIAS='Yes'">
					<xsl:attribute name="style">
						<xsl:text>background-color:yellow; text-align:justify;</xsl:text>
					</xsl:attribute>
				</xsl:when>
				<xsl:otherwise>
					<xsl:attribute name="class">
						<xsl:text>Comment</xsl:text>
					</xsl:attribute>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:apply-templates/>
			<xsl:if test="@Annotator">
				<strong>
					<xsl:text> Anmerkung von: </xsl:text>
					<xsl:value-of select="@Annotator"/>
				</strong>
			</xsl:if>
		</span>
	</xsl:template>

</xsl:stylesheet>